@@ -1,20 +1,20 @@
 /*
-    File                 : DatapickerCurve.cpp
-    Project              : LabPlot
-    Description          : container for Curve-Point and Datasheet/Spreadsheet
-    of datapicker
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : DatapickerCurve.cpp
+	Project              : LabPlot
+	Description          : container for Curve-Point and Datasheet/Spreadsheet
+	of datapicker
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "DatapickerCurve.h"
-#include "backend/datapicker/DatapickerCurvePrivate.h"
 #include "backend/datapicker/Datapicker.h"
+#include "backend/datapicker/DatapickerCurvePrivate.h"
 #include "backend/datapicker/DatapickerPoint.h"
-#include "backend/lib/commandtemplates.h"
 #include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/commandtemplates.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
@@ -23,8 +23,8 @@
 #include <QVector3D>
 
 #include <KConfig>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
 /**
  * \class DatapickerCurve
@@ -32,15 +32,15 @@
  * \ingroup backend
  */
 
-DatapickerCurve::DatapickerCurve(const QString &name)
-	: AbstractAspect(name, AspectType::DatapickerCurve), d_ptr(new DatapickerCurvePrivate(this)) {
-
+DatapickerCurve::DatapickerCurve(const QString& name)
+	: AbstractAspect(name, AspectType::DatapickerCurve)
+	, d_ptr(new DatapickerCurvePrivate(this)) {
 	init();
 }
 
-DatapickerCurve::DatapickerCurve(const QString &name, DatapickerCurvePrivate *dd)
-	: AbstractAspect(name, AspectType::DatapickerCurve), d_ptr(dd) {
-
+DatapickerCurve::DatapickerCurve(const QString& name, DatapickerCurvePrivate* dd)
+	: AbstractAspect(name, AspectType::DatapickerCurve)
+	, d_ptr(dd) {
 	init();
 }
 
@@ -56,36 +56,41 @@ void DatapickerCurve::init() {
 	group = config.group("DatapickerCurve");
 	d->pointVisibility = group.readEntry("PointVisibility", true);
 
-	//error bars
-	d->curveErrorTypes.x = (ErrorType) group.readEntry("CurveErrorType_X", static_cast<int>(ErrorType::NoError));
-	d->curveErrorTypes.y = (ErrorType) group.readEntry("CurveErrorType_Y", static_cast<int>(ErrorType::NoError));
+	// error bars
+	d->curveErrorTypes.x = (ErrorType)group.readEntry("CurveErrorType_X", static_cast<int>(ErrorType::NoError));
+	d->curveErrorTypes.y = (ErrorType)group.readEntry("CurveErrorType_Y", static_cast<int>(ErrorType::NoError));
 	d->pointErrorBarSize = group.readEntry("ErrorBarSize", Worksheet::convertToSceneUnits(8, Worksheet::Unit::Point));
-	d->pointErrorBarBrush.setStyle( (Qt::BrushStyle)group.readEntry("ErrorBarFillingStyle", (int)Qt::NoBrush) );
-	d->pointErrorBarBrush.setColor( group.readEntry("ErrorBarFillingColor", QColor(Qt::black)) );
-	d->pointErrorBarPen.setStyle( (Qt::PenStyle)group.readEntry("ErrorBarBorderStyle", (int)Qt::SolidLine) );
-	d->pointErrorBarPen.setColor( group.readEntry("ErrorBarBorderColor", QColor(Qt::black)) );
-	d->pointErrorBarPen.setWidthF( group.readEntry("ErrorBarBorderWidth", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Point)) );
+	d->pointErrorBarBrush.setStyle((Qt::BrushStyle)group.readEntry("ErrorBarFillingStyle", (int)Qt::NoBrush));
+	d->pointErrorBarBrush.setColor(group.readEntry("ErrorBarFillingColor", QColor(Qt::black)));
+	d->pointErrorBarPen.setStyle((Qt::PenStyle)group.readEntry("ErrorBarBorderStyle", (int)Qt::SolidLine));
+	d->pointErrorBarPen.setColor(group.readEntry("ErrorBarBorderColor", QColor(Qt::black)));
+	d->pointErrorBarPen.setWidthF(group.readEntry("ErrorBarBorderWidth", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Point)));
 
-	//initialize the symbol
+	// initialize the symbol
 	d->symbol = new Symbol(QString());
 	addChild(d->symbol);
 	d->symbol->setHidden(true);
-	connect(d->symbol, &Symbol::updateRequested, [=]{d->retransform();});
-	connect(d->symbol, &Symbol::updatePixmapRequested, [=]{d->retransform();});
+	connect(d->symbol, &Symbol::updateRequested, [=] {
+		d->retransform();
+	});
+	connect(d->symbol, &Symbol::updatePixmapRequested, [=] {
+		d->retransform();
+	});
 	d->symbol->init(group);
 }
 
 /*!
-    Returns an icon to be used in the project explorer.
+	Returns an icon to be used in the project explorer.
 */
 QIcon DatapickerCurve::icon() const {
-	return QIcon::fromTheme("labplot-xy-curve");
+	return QIcon::fromTheme(QStringLiteral("labplot-xy-curve"));
 }
 
 Column* DatapickerCurve::appendColumn(const QString& name) {
 	auto* col = new Column(name);
 	col->insertRows(0, m_datasheet->rowCount());
 	col->setFixed(true);
+	col->setUndoAware(false);
 	m_datasheet->addChild(col);
 
 	return col;
@@ -154,7 +159,7 @@ void DatapickerCurve::addDatasheet(DatapickerImage::GraphType type) {
 	QString yLabel;
 
 	switch (type) {
-	case DatapickerImage::GraphType::Cartesian: {
+	case DatapickerImage::GraphType::Linear: {
 		xLabel = QLatin1Char('x');
 		yLabel = QLatin1Char('y');
 		break;
@@ -169,12 +174,32 @@ void DatapickerCurve::addDatasheet(DatapickerImage::GraphType type) {
 		yLabel = QLatin1String("y(rad)");
 		break;
 	}
-	case DatapickerImage::GraphType::LogarithmicX: {
+	case DatapickerImage::GraphType::LnXY: {
+		xLabel = QLatin1String("ln(x)");
+		yLabel = QLatin1String("ln(y)");
+		break;
+	}
+	case DatapickerImage::GraphType::LnX: {
+		xLabel = QLatin1String("ln(x)");
+		yLabel = QLatin1String("y");
+		break;
+	}
+	case DatapickerImage::GraphType::LnY: {
+		xLabel = QLatin1String("x");
+		yLabel = QLatin1String("ln(y)");
+		break;
+	}
+	case DatapickerImage::GraphType::Log10XY: {
+		xLabel = QLatin1String("log(x)");
+		yLabel = QLatin1String("log(y)");
+		break;
+	}
+	case DatapickerImage::GraphType::Log10X: {
 		xLabel = QLatin1String("log(x)");
 		yLabel = QLatin1String("y");
 		break;
 	}
-	case DatapickerImage::GraphType::LogarithmicY: {
+	case DatapickerImage::GraphType::Log10Y: {
 		xLabel = QLatin1String("x");
 		yLabel = QLatin1String("log(y)");
 		break;
@@ -186,8 +211,8 @@ void DatapickerCurve::addDatasheet(DatapickerImage::GraphType type) {
 	}
 	}
 
-	//the default spreadsheet can have arbitrary number of colums as per user's default template.
-	//make sure we have the columns for x and y only
+	// the default spreadsheet can have arbitrary number of colums as per user's default template.
+	// make sure we have the columns for x and y only
 	if (m_datasheet->columnCount() < 1)
 		appendColumn(xLabel);
 	if (m_datasheet->columnCount() < 2)
@@ -195,7 +220,7 @@ void DatapickerCurve::addDatasheet(DatapickerImage::GraphType type) {
 	if (m_datasheet->columnCount() > 2)
 		m_datasheet->setColumnCount(2);
 
-	//add the third column for Ternary
+	// add the third column for Ternary
 	if (type == DatapickerImage::GraphType::Ternary)
 		d->posZColumn = appendColumn(QLatin1String("c"));
 
@@ -203,11 +228,13 @@ void DatapickerCurve::addDatasheet(DatapickerImage::GraphType type) {
 	d->posXColumn->setName(xLabel);
 	d->posXColumn->setPlotDesignation(AbstractColumn::PlotDesignation::X);
 	d->posXColumn->setFixed(true);
+	d->posXColumn->setUndoAware(false);
 
 	d->posYColumn = m_datasheet->column(1);
 	d->posYColumn->setName(yLabel);
-	d->posXColumn->setPlotDesignation(AbstractColumn::PlotDesignation::Y);
+	d->posYColumn->setPlotDesignation(AbstractColumn::PlotDesignation::Y);
 	d->posYColumn->setFixed(true);
+	d->posYColumn->setUndoAware(false);
 }
 
 STD_SETTER_CMD_IMPL_S(DatapickerCurve, SetCurveErrorTypes, DatapickerCurve::Errors, curveErrorTypes)
@@ -217,30 +244,30 @@ void DatapickerCurve::setCurveErrorTypes(const DatapickerCurve::Errors errors) {
 		beginMacro(i18n("%1: set xy-error type", name()));
 		exec(new DatapickerCurveSetCurveErrorTypesCmd(d, errors, ki18n("%1: set xy-error type")));
 
-		if ( errors.x != ErrorType::NoError && !d->plusDeltaXColumn )
+		if (errors.x != ErrorType::NoError && !d->plusDeltaXColumn)
 			setPlusDeltaXColumn(appendColumn(QLatin1String("+delta_x")));
-		else if ( d->plusDeltaXColumn && errors.x ==ErrorType:: NoError ) {
+		else if (d->plusDeltaXColumn && errors.x == ErrorType::NoError) {
 			d->plusDeltaXColumn->remove();
 			d->plusDeltaXColumn = nullptr;
 		}
 
-		if ( errors.x == ErrorType::AsymmetricError && !d->minusDeltaXColumn )
+		if (errors.x == ErrorType::AsymmetricError && !d->minusDeltaXColumn)
 			setMinusDeltaXColumn(appendColumn(QLatin1String("-delta_x")));
-		else if ( d->minusDeltaXColumn && errors.x != ErrorType::AsymmetricError ) {
+		else if (d->minusDeltaXColumn && errors.x != ErrorType::AsymmetricError) {
 			d->minusDeltaXColumn->remove();
 			d->minusDeltaXColumn = nullptr;
 		}
 
-		if ( errors.y != ErrorType::NoError && !d->plusDeltaYColumn )
+		if (errors.y != ErrorType::NoError && !d->plusDeltaYColumn)
 			setPlusDeltaYColumn(appendColumn(QLatin1String("+delta_y")));
-		else if ( d->plusDeltaYColumn && errors.y == ErrorType::NoError ) {
+		else if (d->plusDeltaYColumn && errors.y == ErrorType::NoError) {
 			d->plusDeltaYColumn->remove();
 			d->plusDeltaYColumn = nullptr;
 		}
 
-		if ( errors.y == ErrorType::AsymmetricError && !d->minusDeltaYColumn )
+		if (errors.y == ErrorType::AsymmetricError && !d->minusDeltaYColumn)
 			setMinusDeltaYColumn(appendColumn(QLatin1String("-delta_y")));
-		else if ( d->minusDeltaYColumn && errors.y != ErrorType::AsymmetricError ) {
+		else if (d->minusDeltaYColumn && errors.y != ErrorType::AsymmetricError) {
 			d->minusDeltaYColumn->remove();
 			d->minusDeltaYColumn = nullptr;
 		}
@@ -306,14 +333,14 @@ void DatapickerCurve::setPointErrorBarSize(qreal size) {
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointErrorBarBrush, QBrush, pointErrorBarBrush, retransform)
-void DatapickerCurve::setPointErrorBarBrush(const QBrush &brush) {
+void DatapickerCurve::setPointErrorBarBrush(const QBrush& brush) {
 	Q_D(DatapickerCurve);
 	if (brush != d->pointErrorBarBrush)
 		exec(new DatapickerCurveSetPointErrorBarBrushCmd(d, brush, ki18n("%1: set error bar filling")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerCurve, SetPointErrorBarPen, QPen, pointErrorBarPen, retransform)
-void DatapickerCurve::setPointErrorBarPen(const QPen &pen) {
+void DatapickerCurve::setPointErrorBarPen(const QPen& pen) {
 	Q_D(DatapickerCurve);
 	if (pen != d->pointErrorBarPen)
 		exec(new DatapickerCurveSetPointErrorBarPenCmd(d, pen, ki18n("%1: set error bar outline style")));
@@ -332,8 +359,8 @@ void DatapickerCurve::setPrinting(bool on) {
 }
 
 /*!
-    Selects or deselects the Datapicker/Curve in the project explorer.
-    This function is called in \c DatapickerImageView.
+	Selects or deselects the Datapicker/Curve in the project explorer.
+	This function is called in \c DatapickerImageView.
 */
 void DatapickerCurve::setSelectedInView(bool b) {
 	if (b)
@@ -351,23 +378,23 @@ void DatapickerCurve::updatePoints() {
 }
 
 /*!
-    Update datasheet for corresponding curve-point,
-    it is called every time whenever there is any change in position
-    of curve-point or its error-bar so keep it undo unaware
-    no need to create extra entry in undo stack
+	Update datasheet for corresponding curve-point,
+	it is called every time whenever there is any change in position
+	of curve-point or its error-bar so keep it undo unaware
+	no need to create extra entry in undo stack
 */
 void DatapickerCurve::updatePoint(const DatapickerPoint* point) {
 	Q_D(DatapickerCurve);
 
-	//TODO: this check shouldn't be required.
-	//redesign the retransform()-call in load() to avoid it.
+	// TODO: this check shouldn't be required.
+	// redesign the retransform()-call in load() to avoid it.
 	if (!parentAspect())
 		return;
 
 	auto* datapicker = static_cast<Datapicker*>(parentAspect());
 	int row = indexOfChild<DatapickerPoint>(point, ChildIndexFlag::IncludeHidden);
 
-	//resize the spreadsheet if needed (row starts with 0, add 1 when comparing with rowCount())
+	// resize the spreadsheet if needed (row starts with 0, add 1 when comparing with rowCount())
 	if (m_datasheet->rowCount() < row + 1)
 		m_datasheet->setRowCount(row + 1);
 
@@ -384,29 +411,30 @@ void DatapickerCurve::updatePoint(const DatapickerPoint* point) {
 
 	if (d->plusDeltaXColumn) {
 		data = datapicker->mapSceneLengthToLogical(QPointF(point->plusDeltaXPos().x(), 0));
-		d->plusDeltaXColumn->setValueAt(row, qAbs(data.x()));
+		d->plusDeltaXColumn->setValueAt(row, std::abs(data.x()));
 	}
 
 	if (d->minusDeltaXColumn) {
 		data = datapicker->mapSceneLengthToLogical(QPointF(point->minusDeltaXPos().x(), 0));
-		d->minusDeltaXColumn->setValueAt(row, qAbs(data.x()));
+		d->minusDeltaXColumn->setValueAt(row, std::abs(data.x()));
 	}
 
 	if (d->plusDeltaYColumn) {
 		data = datapicker->mapSceneLengthToLogical(QPointF(0, point->plusDeltaYPos().y()));
-		d->plusDeltaYColumn->setValueAt(row, qAbs(data.y()));
+		d->plusDeltaYColumn->setValueAt(row, std::abs(data.y()));
 	}
 
 	if (d->minusDeltaYColumn) {
 		data = datapicker->mapSceneLengthToLogical(QPointF(0, point->minusDeltaYPos().y()));
-		d->minusDeltaYColumn->setValueAt(row, qAbs(data.y()));
+		d->minusDeltaYColumn->setValueAt(row, std::abs(data.y()));
 	}
 }
 
 //##############################################################################
 //####################### Private implementation ###############################
 //##############################################################################
-DatapickerCurvePrivate::DatapickerCurvePrivate(DatapickerCurve *curve) : q(curve) {
+DatapickerCurvePrivate::DatapickerCurvePrivate(DatapickerCurve* curve)
+	: q(curve) {
 }
 
 QString DatapickerCurvePrivate::name() const {
@@ -428,12 +456,12 @@ void DatapickerCurvePrivate::retransform() {
 void DatapickerCurve::save(QXmlStreamWriter* writer) const {
 	Q_D(const DatapickerCurve);
 
-	writer->writeStartElement("datapickerCurve");
+	writer->writeStartElement(QStringLiteral("datapickerCurve"));
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
-	//general
-	writer->writeStartElement("general");
+	// general
+	writer->writeStartElement(QStringLiteral("general"));
 	WRITE_COLUMN(d->posXColumn, posXColumn);
 	WRITE_COLUMN(d->posYColumn, posYColumn);
 	WRITE_COLUMN(d->posZColumn, posZColumn);
@@ -441,22 +469,22 @@ void DatapickerCurve::save(QXmlStreamWriter* writer) const {
 	WRITE_COLUMN(d->minusDeltaXColumn, minusDeltaXColumn);
 	WRITE_COLUMN(d->plusDeltaYColumn, plusDeltaYColumn);
 	WRITE_COLUMN(d->minusDeltaYColumn, minusDeltaYColumn);
-	writer->writeAttribute( "curveErrorType_X", QString::number(static_cast<int>(d->curveErrorTypes.x)) );
-	writer->writeAttribute( "curveErrorType_Y", QString::number(static_cast<int>(d->curveErrorTypes.y)) );
-	writer->writeAttribute( "vibible", QString::number(d->pointVisibility) );
+	writer->writeAttribute(QStringLiteral("curveErrorType_X"), QString::number(static_cast<int>(d->curveErrorTypes.x)));
+	writer->writeAttribute(QStringLiteral("curveErrorType_Y"), QString::number(static_cast<int>(d->curveErrorTypes.y)));
+	writer->writeAttribute(QStringLiteral("vibible"), QString::number(d->pointVisibility));
 	writer->writeEndElement();
 
-	//Symbols
+	// Symbols
 	d->symbol->save(writer);
 
-	//error bar properties
-	writer->writeStartElement("errorBarProperties");
-	writer->writeAttribute( "pointErrorBarSize", QString::number(d->pointErrorBarSize) );
+	// error bar properties
+	writer->writeStartElement(QStringLiteral("errorBarProperties"));
+	writer->writeAttribute(QStringLiteral("pointErrorBarSize"), QString::number(d->pointErrorBarSize));
 	WRITE_QBRUSH(d->pointErrorBarBrush);
 	WRITE_QPEN(d->pointErrorBarPen);
 	writer->writeEndElement();
 
-	//serialize all children
+	// serialize all children
 	for (auto* child : children<AbstractAspect>(ChildIndexFlag::IncludeHidden))
 		child->save(writer);
 
@@ -476,15 +504,16 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "datapickerCurve")
+		if (reader->isEndElement() && reader->name() == QLatin1String("datapickerCurve"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "comment") {
-			if (!readCommentElement(reader)) return false;
-		} else if (!preview && reader->name() == "general") {
+		if (reader->name() == QLatin1String("comment")) {
+			if (!readCommentElement(reader))
+				return false;
+		} else if (!preview && reader->name() == QLatin1String("general")) {
 			attribs = reader->attributes();
 
 			READ_INT_VALUE("visible", pointVisibility, bool);
@@ -498,112 +527,112 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_COLUMN(minusDeltaXColumn);
 			READ_COLUMN(plusDeltaYColumn);
 			READ_COLUMN(minusDeltaYColumn);
-		} else if (!preview && reader->name() == "symbolProperties") {
-			//old serialization that was used before the switch to Symbol::load().
-			//in the old serialization the symbol properties and "point visibility" where saved
-			//under "symbolProperties".
+		} else if (!preview && reader->name() == QLatin1String("symbolProperties")) {
+			// old serialization that was used before the switch to Symbol::load().
+			// in the old serialization the symbol properties and "point visibility" where saved
+			// under "symbolProperties".
 			attribs = reader->attributes();
 
-			str = attribs.value("pointRotationAngle").toString();
+			str = attribs.value(QStringLiteral("pointRotationAngle")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointRotationAngle").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointRotationAngle")).toString());
 			else
 				d->symbol->setRotationAngle(str.toDouble());
 
-			str = attribs.value("pointOpacity").toString();
+			str = attribs.value(QStringLiteral("pointOpacity")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointOpacity").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointOpacity")).toString());
 			else
 				d->symbol->setOpacity(str.toDouble());
 
-			str = attribs.value("pointSize").toString();
+			str = attribs.value(QStringLiteral("pointSize")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointSize").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointSize")).toString());
 			else
 				d->symbol->setSize(str.toDouble());
 
-			str = attribs.value("pointStyle").toString();
+			str = attribs.value(QStringLiteral("pointStyle")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointStyle").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointStyle")).toString());
 			else
 				d->symbol->setStyle(static_cast<Symbol::Style>(str.toInt()));
 
-			//brush
+			// brush
 			QBrush brush;
-			str = attribs.value("brush_style").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_style").toString());
+			str = attribs.value(QStringLiteral("brush_style")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_style")).toString());
 			else
-				brush.setStyle( static_cast<Qt::BrushStyle>(str.toInt()) );
+				brush.setStyle(static_cast<Qt::BrushStyle>(str.toInt()));
 
 			QColor color;
-			str = attribs.value("brush_color_r").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_color_r").toString());
+			str = attribs.value(QStringLiteral("brush_color_r")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_color_r")).toString());
 			else
 				color.setRed(str.toInt());
 
-			str = attribs.value("brush_color_g").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_color_g").toString());
+			str = attribs.value(QStringLiteral("brush_color_g")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_color_g")).toString());
 			else
 				color.setGreen(str.toInt());
 
-			str = attribs.value("brush_color_b").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_color_b").toString());
+			str = attribs.value(QStringLiteral("brush_color_b")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_color_b")).toString());
 			else
 				color.setBlue(str.toInt());
 
 			brush.setColor(color);
 			d->symbol->setBrush(brush);
 
-			//pen
+			// pen
 			QPen pen;
-			str = attribs.value("style").toString();
+			str = attribs.value(QStringLiteral("style")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("style").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("style")).toString());
 			else
-				pen.setStyle( static_cast<Qt::PenStyle>(str.toInt()) );
+				pen.setStyle(static_cast<Qt::PenStyle>(str.toInt()));
 
-			str = attribs.value("color_r").toString();
+			str = attribs.value(QStringLiteral("color_r")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("color_r").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("color_r")).toString());
 			else
-				color.setRed( str.toInt() );
+				color.setRed(str.toInt());
 
-			str = attribs.value("color_g").toString();
+			str = attribs.value(QStringLiteral("color_g")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("color_g").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("color_g")).toString());
 			else
-				color.setGreen( str.toInt() );
+				color.setGreen(str.toInt());
 
-			str = attribs.value("color_b").toString();
+			str = attribs.value(QStringLiteral("color_b")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("color_b").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("color_b")).toString());
 			else
-				color.setBlue( str.toInt() );
+				color.setBlue(str.toInt());
 
 			pen.setColor(color);
 
-			str = attribs.value("width").toString();
+			str = attribs.value(QStringLiteral("width")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("width").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("width")).toString());
 			else
-				pen.setWidthF( str.toDouble() );
+				pen.setWidthF(str.toDouble());
 
 			d->symbol->setPen(pen);
 
 			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
-		} else if (!preview && reader->name() == "symbols") {
+		} else if (!preview && reader->name() == QLatin1String("symbols")) {
 			d->symbol->load(reader, preview);
-		} else if (!preview && reader->name() == "errorBarProperties") {
+		} else if (!preview && reader->name() == QLatin1String("errorBarProperties")) {
 			attribs = reader->attributes();
 
 			READ_DOUBLE_VALUE("pointErrorBarSize", pointErrorBarSize);
 			READ_QBRUSH(d->pointErrorBarBrush);
 			READ_QPEN(d->pointErrorBarPen);
-		} else if (reader->name() == "datapickerPoint") {
+		} else if (reader->name() == QLatin1String("datapickerPoint")) {
 			auto* curvePoint = new DatapickerPoint(QString());
 			curvePoint->setHidden(true);
 			if (!curvePoint->load(reader, preview)) {
@@ -613,8 +642,8 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 				addChild(curvePoint);
 				curvePoint->initErrorBar(curveErrorTypes());
 			}
-		} else if (reader->name() == "spreadsheet") {
-			auto* datasheet = new Spreadsheet("spreadsheet", true);
+		} else if (reader->name() == QLatin1String("spreadsheet")) {
+			auto* datasheet = new Spreadsheet(QStringLiteral("spreadsheet"), true);
 			if (!datasheet->load(reader, preview)) {
 				delete datasheet;
 				return false;
@@ -628,7 +657,8 @@ bool DatapickerCurve::load(XmlStreamReader* reader, bool preview) {
 			}
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-			if (!reader->skipToEndElement()) return false;
+			if (!reader->skipToEndElement())
+				return false;
 		}
 	}
 
