@@ -1,33 +1,34 @@
 /*
-    File                 : DatapickerImage.cpp
-    Project              : LabPlot
-    Description          : Worksheet for Datapicker
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+	File                 : DatapickerImage.cpp
+	Project              : LabPlot
+	Description          : Worksheet for Datapicker
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "DatapickerImage.h"
 #include "DatapickerImagePrivate.h"
-#include "backend/datapicker/ImageEditor.h"
-#include "backend/lib/commandtemplates.h"
-#include "backend/lib/XmlStreamReader.h"
+#include "backend/core/Project.h"
 #include "backend/datapicker/DatapickerPoint.h"
+#include "backend/datapicker/ImageEditor.h"
 #include "backend/datapicker/Segments.h"
-#include "backend/worksheet/plots/cartesian/Symbol.h"
+#include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/commandtemplates.h"
+#include "backend/lib/trace.h"
 #include "backend/worksheet/Worksheet.h"
+#include "backend/worksheet/plots/cartesian/Symbol.h"
 #include "commonfrontend/datapicker/DatapickerImageView.h"
 #include "kdefrontend/worksheet/ExportWorksheetDialog.h"
-#include "backend/lib/trace.h"
 
 #include <QDesktopWidget>
 #include <QGraphicsScene>
 #include <QMenu>
-#include <QPrinter>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
+#include <QPrinter>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -41,33 +42,36 @@
  *
  * * \ingroup datapicker
  */
-DatapickerImage::DatapickerImage(const QString& name, bool loading) :
-	AbstractPart(name, AspectType::DatapickerImage),
-	foregroundBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Foreground) + 1]),
-	hueBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Hue) + 1]),
-	saturationBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Saturation) + 1]),
-	valueBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Value) + 1]),
-	intensityBins( new int[ImageEditor::colorAttributeMax(ColorAttributes::Intensity) + 1]),
-	d(new DatapickerImagePrivate(this)),
-	m_segments(new Segments(this)) {
-
+DatapickerImage::DatapickerImage(const QString& name, bool loading)
+	: AbstractPart(name, AspectType::DatapickerImage)
+	, foregroundBins(new int[ImageEditor::colorAttributeMax(ColorAttributes::Foreground) + 1])
+	, hueBins(new int[ImageEditor::colorAttributeMax(ColorAttributes::Hue) + 1])
+	, saturationBins(new int[ImageEditor::colorAttributeMax(ColorAttributes::Saturation) + 1])
+	, valueBins(new int[ImageEditor::colorAttributeMax(ColorAttributes::Value) + 1])
+	, intensityBins(new int[ImageEditor::colorAttributeMax(ColorAttributes::Intensity) + 1])
+	, d(new DatapickerImagePrivate(this))
+	, m_segments(new Segments(this)) {
 	if (!loading)
 		init();
 	else {
 		d->symbol = new Symbol(QString());
 		addChild(d->symbol);
 		d->symbol->setHidden(true);
-		connect(d->symbol, &Symbol::updateRequested, [=]{d->retransform();});
-		connect(d->symbol, &Symbol::updatePixmapRequested, [=]{d->retransform();});
+		connect(d->symbol, &Symbol::updateRequested, [=] {
+			d->retransform();
+		});
+		connect(d->symbol, &Symbol::updatePixmapRequested, [=] {
+			d->retransform();
+		});
 	}
 }
 
 DatapickerImage::~DatapickerImage() {
-	delete [] hueBins;
-	delete [] saturationBins;
-	delete [] valueBins;
-	delete [] intensityBins;
-	delete [] foregroundBins;
+	delete[] hueBins;
+	delete[] saturationBins;
+	delete[] valueBins;
+	delete[] intensityBins;
+	delete[] foregroundBins;
 	delete m_segments;
 	delete d;
 }
@@ -76,46 +80,50 @@ void DatapickerImage::init() {
 	KConfig config;
 	KConfigGroup group = config.group("DatapickerImage");
 
-	//general properties
+	// general properties
 	d->fileName = group.readEntry("FileName", QString());
 	d->rotationAngle = group.readEntry("RotationAngle", 0.0);
 	d->minSegmentLength = group.readEntry("MinSegmentLength", 30);
 	d->pointSeparation = group.readEntry("PointSeparation", 30);
-	d->axisPoints.type = (DatapickerImage::GraphType) group.readEntry("GraphType", static_cast<int>(DatapickerImage::GraphType::Cartesian));
+	d->axisPoints.type = static_cast<GraphType>(group.readEntry("GraphType", static_cast<int>(GraphType::Linear)));
 	d->axisPoints.ternaryScale = group.readEntry("TernaryScale", 1);
 
-	//edit image settings
+	// edit image settings
 	d->plotImageType = DatapickerImage::PlotImageType::OriginalImage;
-	d->settings.foregroundThresholdHigh = group.readEntry("ForegroundThresholdHigh", 90);
-	d->settings.foregroundThresholdLow = group.readEntry("ForegroundThresholdLow", 30);
-	d->settings.hueThresholdHigh = group.readEntry("HueThresholdHigh", 360);
-	d->settings.hueThresholdLow = group.readEntry("HueThresholdLow", 0);
-	d->settings.intensityThresholdHigh = group.readEntry("IntensityThresholdHigh", 100);
-	d->settings.intensityThresholdLow = group.readEntry("IntensityThresholdLow", 20);
-	d->settings.saturationThresholdHigh = group.readEntry("SaturationThresholdHigh", 100);
-	d->settings.saturationThresholdLow = group.readEntry("SaturationThresholdLow", 30);
-	d->settings.valueThresholdHigh = group.readEntry("ValueThresholdHigh", 90);
-	d->settings.valueThresholdLow = group.readEntry("ValueThresholdLow", 30);
+	d->settings.foregroundThresholdHigh = group.readEntry("ForegroundThresholdHigh", d->settings.foregroundThresholdHigh);
+	d->settings.foregroundThresholdLow = group.readEntry("ForegroundThresholdLow", d->settings.foregroundThresholdLow);
+	d->settings.hueThresholdHigh = group.readEntry("HueThresholdHigh", d->settings.hueThresholdHigh);
+	d->settings.hueThresholdLow = group.readEntry("HueThresholdLow", d->settings.hueThresholdLow);
+	d->settings.intensityThresholdHigh = group.readEntry("IntensityThresholdHigh", d->settings.intensityThresholdHigh);
+	d->settings.intensityThresholdLow = group.readEntry("IntensityThresholdLow", d->settings.intensityThresholdLow);
+	d->settings.saturationThresholdHigh = group.readEntry("SaturationThresholdHigh", d->settings.saturationThresholdHigh);
+	d->settings.saturationThresholdLow = group.readEntry("SaturationThresholdLow", d->settings.saturationThresholdLow);
+	d->settings.valueThresholdHigh = group.readEntry("ValueThresholdHigh", d->settings.valueThresholdHigh);
+	d->settings.valueThresholdLow = group.readEntry("ValueThresholdLow", d->settings.valueThresholdLow);
 
 	// reference point symbol properties
 	d->symbol = new Symbol(QString());
 	addChild(d->symbol);
 	d->symbol->setHidden(true);
-	connect(d->symbol, &Symbol::updateRequested, [=]{d->retransform();});
-	connect(d->symbol, &Symbol::updatePixmapRequested, [=]{d->retransform();});
+	connect(d->symbol, &Symbol::updateRequested, [=] {
+		d->retransform();
+	});
+	connect(d->symbol, &Symbol::updatePixmapRequested, [=] {
+		d->retransform();
+	});
 	d->symbol->init(group);
 	d->pointVisibility = group.readEntry("PointVisibility", true);
 }
 
 /*!
-    Returns an icon to be used in the project explorer.
+	Returns an icon to be used in the project explorer.
 */
 QIcon DatapickerImage::icon() const {
-	return QIcon::fromTheme("image-x-generic");
+	return QIcon::fromTheme(QStringLiteral("image-x-generic"));
 }
 
 /*!
-    Return a new context menu
+	Return a new context menu
 */
 QMenu* DatapickerImage::createContextMenu() {
 	QMenu* menu = new QMenu(nullptr);
@@ -134,7 +142,7 @@ void DatapickerImage::createContextMenu(QMenu* menu) {
  */
 QWidget* DatapickerImage::view() const {
 	if (!m_partView) {
-		m_view = new DatapickerImageView(const_cast<DatapickerImage *>(this));
+		m_view = new DatapickerImageView(const_cast<DatapickerImage*>(this));
 		m_partView = m_view;
 		connect(m_view, &DatapickerImageView::statusInfo, this, &DatapickerImage::statusInfo);
 	}
@@ -143,9 +151,10 @@ QWidget* DatapickerImage::view() const {
 
 bool DatapickerImage::exportView() const {
 	auto* dlg = new ExportWorksheetDialog(m_view);
+	dlg->setProjectFileName(const_cast<DatapickerImage*>(this)->project()->fileName());
 	dlg->setFileName(name());
 	bool ret;
-	if ( (ret = (dlg->exec() == QDialog::Accepted)) ) {
+	if ((ret = (dlg->exec() == QDialog::Accepted))) {
 		const QString path = dlg->path();
 		const auto format = dlg->exportFormat();
 		const int resolution = dlg->exportResolution();
@@ -163,7 +172,7 @@ bool DatapickerImage::printView() {
 	auto* dlg = new QPrintDialog(&printer, m_view);
 	bool ret;
 	dlg->setWindowTitle(i18nc("@title:window", "Print Datapicker Image"));
-	if ( (ret = (dlg->exec() == QDialog::Accepted)) )
+	if ((ret = (dlg->exec() == QDialog::Accepted)))
 		m_view->print(&printer);
 
 	delete dlg;
@@ -177,10 +186,10 @@ bool DatapickerImage::printPreview() const {
 }
 
 /*!
-    Selects or deselects the Datapicker/DatapickerImage in the project explorer.
-    This function is called in \c DatapickerImageView.
-    The DatapickerImage gets deselected if there are selected items in the view,
-    and selected if there are no selected items in the view.
+	Selects or deselects the Datapicker/DatapickerImage in the project explorer.
+	This function is called in \c DatapickerImageView.
+	The DatapickerImage gets deselected if there are selected items in the view,
+	and selected if there are no selected items in the view.
 */
 void DatapickerImage::setSelectedInView(const bool b) {
 	if (b)
@@ -209,6 +218,10 @@ void DatapickerImage::setPlotImageType(const DatapickerImage::PlotImageType type
 	Q_EMIT requestUpdate();
 }
 
+int DatapickerImage::currentSelectedReferencePoint() {
+	return m_currentRefPoint;
+}
+
 DatapickerImage::PlotImageType DatapickerImage::plotImageType() {
 	return d->plotImageType;
 }
@@ -222,9 +235,9 @@ BASIC_D_READER_IMPL(DatapickerImage, DatapickerImage::PointsType, plotPointsType
 BASIC_D_READER_IMPL(DatapickerImage, int, pointSeparation, pointSeparation)
 BASIC_D_READER_IMPL(DatapickerImage, int, minSegmentLength, minSegmentLength)
 
-//symbols
+// symbols
 Symbol* DatapickerImage::symbol() const {
-// 	Q_D(const DatapickerImage);
+	// 	Q_D(const DatapickerImage);
 	return d->symbol;
 }
 
@@ -232,7 +245,7 @@ BASIC_D_READER_IMPL(DatapickerImage, bool, pointVisibility, pointVisibility)
 /* ============================ setter methods and undo commands  for background options  ================= */
 STD_SETTER_CMD_IMPL_F_S(DatapickerImage, SetFileName, QString, fileName, updateFileName)
 void DatapickerImage::setFileName(const QString& fileName) {
-	if (fileName!= d->fileName) {
+	if (fileName != d->fileName) {
 		beginMacro(i18n("%1: upload new image", name()));
 		exec(new DatapickerImageSetFileNameCmd(d, fileName, ki18n("%1: upload image")));
 		endMacro();
@@ -247,7 +260,7 @@ void DatapickerImage::setRotationAngle(float angle) {
 
 STD_SETTER_CMD_IMPL_S(DatapickerImage, SetAxisPoints, DatapickerImage::ReferencePoints, axisPoints)
 void DatapickerImage::setAxisPoints(const DatapickerImage::ReferencePoints& points) {
-	if (memcmp(&points, &d->axisPoints, sizeof(points)) != 0)
+	if (memcmp(&points, &d->axisPoints, sizeof(points)) != 0) // valgrind: Conditional jump or move depends on uninitialised value(s)
 		exec(new DatapickerImageSetAxisPointsCmd(d, points, ki18n("%1: set Axis points")));
 }
 
@@ -260,7 +273,8 @@ void DatapickerImage::setSettings(const DatapickerImage::EditorSettings& editorS
 STD_SETTER_CMD_IMPL_F_S(DatapickerImage, SetMinSegmentLength, int, minSegmentLength, makeSegments)
 void DatapickerImage::setminSegmentLength(const int value) {
 	if (d->minSegmentLength != value)
-		exec(new DatapickerImageSetMinSegmentLengthCmd(d, value, ki18n("%1: set minimum segment length")));        ;
+		exec(new DatapickerImageSetMinSegmentLengthCmd(d, value, ki18n("%1: set minimum segment length")));
+	;
 }
 
 STD_SETTER_CMD_IMPL_F_S(DatapickerImage, SetPointVisibility, bool, pointVisibility, retransform)
@@ -282,7 +296,7 @@ void DatapickerImage::setPlotPointsType(const PointsType pointsType) {
 	d->plotPointsType = pointsType;
 
 	if (pointsType == DatapickerImage::PointsType::AxisPoints) {
-		//clear image
+		// clear image
 		auto points = children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
 		if (!points.isEmpty()) {
 			beginMacro(i18n("%1: remove all axis points", name()));
@@ -295,7 +309,7 @@ void DatapickerImage::setPlotPointsType(const PointsType pointsType) {
 	} else if (pointsType == DatapickerImage::PointsType::CurvePoints) {
 		m_segments->setSegmentsVisible(false);
 
-		//make the reference points non-interactive
+		// make the reference points non-interactive
 		const auto& points = children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
 		for (auto* point : points) {
 			auto* item = point->graphicsItem();
@@ -314,12 +328,25 @@ void DatapickerImage::setPointSeparation(const int value) {
 	d->pointSeparation = value;
 }
 
+void DatapickerImage::referencePointSelected(const DatapickerPoint* point) {
+	const auto points = children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
+	for (int i = 0; i < points.count(); i++) {
+		if (points.at(i) == point) {
+			m_currentRefPoint = i;
+			emit referencePointSelected(i);
+			return;
+		}
+	}
+	m_currentRefPoint = -1;
+}
+
 //##############################################################################
 //######################  Private implementation ###############################
 //##############################################################################
-DatapickerImagePrivate::DatapickerImagePrivate(DatapickerImage *owner) : q(owner),
-	pageRect(0, 0, 1000, 1000),
-	m_scene(new QGraphicsScene(pageRect)) {
+DatapickerImagePrivate::DatapickerImagePrivate(DatapickerImage* owner)
+	: q(owner)
+	, pageRect(0, 0, 1000, 1000)
+	, m_scene(new QGraphicsScene(pageRect)) {
 }
 
 QString DatapickerImagePrivate::name() const {
@@ -337,14 +364,14 @@ void DatapickerImagePrivate::retransform() {
 bool DatapickerImagePrivate::uploadImage(const QString& address) {
 	bool rc = q->originalPlotImage.load(address);
 	if (rc) {
-		//convert the image to 32bit-format if this is not the case yet
+		// convert the image to 32bit-format if this is not the case yet
 		QImage::Format format = q->originalPlotImage.format();
 		if (format != QImage::Format_RGB32 && format != QImage::Format_ARGB32 && format != QImage::Format_ARGB32_Premultiplied)
 			q->originalPlotImage = q->originalPlotImage.convertToFormat(QImage::Format_RGB32);
 
 		q->processedPlotImage = q->originalPlotImage;
 		q->background = ImageEditor::findBackgroundColor(&q->originalPlotImage);
-		//upload Histogram
+		// upload Histogram
 		ImageEditor::uploadHistogram(q->intensityBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Intensity);
 		ImageEditor::uploadHistogram(q->foregroundBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Foreground);
 		ImageEditor::uploadHistogram(q->hueBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Hue);
@@ -352,9 +379,9 @@ bool DatapickerImagePrivate::uploadImage(const QString& address) {
 		ImageEditor::uploadHistogram(q->valueBins, &q->originalPlotImage, q->background, DatapickerImage::ColorAttributes::Value);
 		discretize();
 
-		//resize the screen
-		double w = Worksheet::convertToSceneUnits(q->originalPlotImage.width(), Worksheet::Unit::Inch)/QApplication::desktop()->physicalDpiX();
-		double h = Worksheet::convertToSceneUnits(q->originalPlotImage.height(), Worksheet::Unit::Inch)/QApplication::desktop()->physicalDpiX();
+		// resize the screen
+		double w = Worksheet::convertToSceneUnits(q->originalPlotImage.width(), Worksheet::Unit::Inch) / QApplication::desktop()->physicalDpiX();
+		double h = Worksheet::convertToSceneUnits(q->originalPlotImage.height(), Worksheet::Unit::Inch) / QApplication::desktop()->physicalDpiX();
 		m_scene->setSceneRect(0, 0, w, h);
 		q->isLoaded = true;
 	}
@@ -362,7 +389,7 @@ bool DatapickerImagePrivate::uploadImage(const QString& address) {
 }
 
 void DatapickerImagePrivate::discretize() {
-	PERFTRACE("DatapickerImagePrivate::discretize()");
+	PERFTRACE(QLatin1String(Q_FUNC_INFO));
 	if (plotImageType != DatapickerImage::PlotImageType::ProcessedImage)
 		return;
 
@@ -378,7 +405,7 @@ void DatapickerImagePrivate::makeSegments() {
 	if (plotPointsType != DatapickerImage::PointsType::SegmentPoints)
 		return;
 
-	PERFTRACE("DatapickerImagePrivate::makeSegments()");
+	PERFTRACE(QLatin1String(Q_FUNC_INFO));
 	q->m_segments->makeSegments(q->processedPlotImage);
 	q->m_segments->setSegmentsVisible(true);
 	Q_EMIT q->requestUpdate();
@@ -397,7 +424,7 @@ void DatapickerImagePrivate::updateFileName() {
 		if (uploadImage(address))
 			fileName = address;
 	} else {
-		//hide segments if they are visible
+		// hide segments if they are visible
 		q->m_segments->setSegmentsVisible(false);
 	}
 
@@ -418,58 +445,58 @@ void DatapickerImagePrivate::updateFileName() {
 
 //! Save as XML
 void DatapickerImage::save(QXmlStreamWriter* writer) const {
-	writer->writeStartElement( "datapickerImage" );
+	writer->writeStartElement(QStringLiteral("datapickerImage"));
 	writeBasicAttributes(writer);
 
-	//general properties
-	writer->writeStartElement( "general" );
-	writer->writeAttribute( "fileName", d->fileName );
-	writer->writeAttribute( "plotPointsType", QString::number(static_cast<int>(d->plotPointsType)) );
-	writer->writeAttribute( "pointVisibility", QString::number(d->pointVisibility) );
+	// general properties
+	writer->writeStartElement(QStringLiteral("general"));
+	writer->writeAttribute(QStringLiteral("fileName"), d->fileName);
+	writer->writeAttribute(QStringLiteral("plotPointsType"), QString::number(static_cast<int>(d->plotPointsType)));
+	writer->writeAttribute(QStringLiteral("pointVisibility"), QString::number(d->pointVisibility));
 	writer->writeEndElement();
 
-	writer->writeStartElement( "axisPoint" );
-	writer->writeAttribute( "graphType", QString::number(static_cast<int>(d->axisPoints.type)) );
-	writer->writeAttribute( "ternaryScale", QString::number(d->axisPoints.ternaryScale) );
-	writer->writeAttribute( "axisPointLogicalX1", QString::number(d->axisPoints.logicalPos[0].x()) );
-	writer->writeAttribute( "axisPointLogicalY1", QString::number(d->axisPoints.logicalPos[0].y()) );
-	writer->writeAttribute( "axisPointLogicalX2", QString::number(d->axisPoints.logicalPos[1].x()) );
-	writer->writeAttribute( "axisPointLogicalY2", QString::number(d->axisPoints.logicalPos[1].y()) );
-	writer->writeAttribute( "axisPointLogicalX3", QString::number(d->axisPoints.logicalPos[2].x()) );
-	writer->writeAttribute( "axisPointLogicalY3", QString::number(d->axisPoints.logicalPos[2].y()) );
-	writer->writeAttribute( "axisPointLogicalZ1", QString::number(d->axisPoints.logicalPos[0].z()) );
-	writer->writeAttribute( "axisPointLogicalZ2", QString::number(d->axisPoints.logicalPos[1].z()) );
-	writer->writeAttribute( "axisPointLogicalZ3", QString::number(d->axisPoints.logicalPos[2].z()) );
-	writer->writeAttribute( "axisPointSceneX1", QString::number(d->axisPoints.scenePos[0].x()) );
-	writer->writeAttribute( "axisPointSceneY1", QString::number(d->axisPoints.scenePos[0].y()) );
-	writer->writeAttribute( "axisPointSceneX2", QString::number(d->axisPoints.scenePos[1].x()) );
-	writer->writeAttribute( "axisPointSceneY2", QString::number(d->axisPoints.scenePos[1].y()) );
-	writer->writeAttribute( "axisPointSceneX3", QString::number(d->axisPoints.scenePos[2].x()) );
-	writer->writeAttribute( "axisPointSceneY3", QString::number(d->axisPoints.scenePos[2].y()) );
+	writer->writeStartElement(QStringLiteral("axisPoint"));
+	writer->writeAttribute(QStringLiteral("graphType"), QString::number(static_cast<int>(d->axisPoints.type)));
+	writer->writeAttribute(QStringLiteral("ternaryScale"), QString::number(d->axisPoints.ternaryScale));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalX1"), QString::number(d->axisPoints.logicalPos[0].x()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalY1"), QString::number(d->axisPoints.logicalPos[0].y()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalX2"), QString::number(d->axisPoints.logicalPos[1].x()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalY2"), QString::number(d->axisPoints.logicalPos[1].y()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalX3"), QString::number(d->axisPoints.logicalPos[2].x()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalY3"), QString::number(d->axisPoints.logicalPos[2].y()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalZ1"), QString::number(d->axisPoints.logicalPos[0].z()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalZ2"), QString::number(d->axisPoints.logicalPos[1].z()));
+	writer->writeAttribute(QStringLiteral("axisPointLogicalZ3"), QString::number(d->axisPoints.logicalPos[2].z()));
+	writer->writeAttribute(QStringLiteral("axisPointSceneX1"), QString::number(d->axisPoints.scenePos[0].x()));
+	writer->writeAttribute(QStringLiteral("axisPointSceneY1"), QString::number(d->axisPoints.scenePos[0].y()));
+	writer->writeAttribute(QStringLiteral("axisPointSceneX2"), QString::number(d->axisPoints.scenePos[1].x()));
+	writer->writeAttribute(QStringLiteral("axisPointSceneY2"), QString::number(d->axisPoints.scenePos[1].y()));
+	writer->writeAttribute(QStringLiteral("axisPointSceneX3"), QString::number(d->axisPoints.scenePos[2].x()));
+	writer->writeAttribute(QStringLiteral("axisPointSceneY3"), QString::number(d->axisPoints.scenePos[2].y()));
 	writer->writeEndElement();
 
-	//editor and segment settings
-	writer->writeStartElement( "editorSettings" );
-	writer->writeAttribute( "plotImageType", QString::number(static_cast<int>(d->plotImageType)) );
-	writer->writeAttribute( "rotationAngle", QString::number(d->rotationAngle) );
-	writer->writeAttribute( "minSegmentLength", QString::number(d->minSegmentLength) );
-	writer->writeAttribute( "pointSeparation", QString::number(d->pointSeparation) );
-	writer->writeAttribute( "foregroundThresholdHigh", QString::number(d->settings.foregroundThresholdHigh) );
-	writer->writeAttribute( "foregroundThresholdLow", QString::number(d->settings.foregroundThresholdLow) );
-	writer->writeAttribute( "hueThresholdHigh", QString::number(d->settings.hueThresholdHigh) );
-	writer->writeAttribute( "hueThresholdLow", QString::number(d->settings.hueThresholdLow) );
-	writer->writeAttribute( "intensityThresholdHigh", QString::number(d->settings.intensityThresholdHigh) );
-	writer->writeAttribute( "intensityThresholdLow", QString::number(d->settings.intensityThresholdLow) );
-	writer->writeAttribute( "saturationThresholdHigh", QString::number(d->settings.saturationThresholdHigh) );
-	writer->writeAttribute( "saturationThresholdLow", QString::number(d->settings.saturationThresholdLow) );
-	writer->writeAttribute( "valueThresholdHigh", QString::number(d->settings.valueThresholdHigh) );
-	writer->writeAttribute( "valueThresholdLow", QString::number(d->settings.valueThresholdLow) );
+	// editor and segment settings
+	writer->writeStartElement(QStringLiteral("editorSettings"));
+	writer->writeAttribute(QStringLiteral("plotImageType"), QString::number(static_cast<int>(d->plotImageType)));
+	writer->writeAttribute(QStringLiteral("rotationAngle"), QString::number(d->rotationAngle));
+	writer->writeAttribute(QStringLiteral("minSegmentLength"), QString::number(d->minSegmentLength));
+	writer->writeAttribute(QStringLiteral("pointSeparation"), QString::number(d->pointSeparation));
+	writer->writeAttribute(QStringLiteral("foregroundThresholdHigh"), QString::number(d->settings.foregroundThresholdHigh));
+	writer->writeAttribute(QStringLiteral("foregroundThresholdLow"), QString::number(d->settings.foregroundThresholdLow));
+	writer->writeAttribute(QStringLiteral("hueThresholdHigh"), QString::number(d->settings.hueThresholdHigh));
+	writer->writeAttribute(QStringLiteral("hueThresholdLow"), QString::number(d->settings.hueThresholdLow));
+	writer->writeAttribute(QStringLiteral("intensityThresholdHigh"), QString::number(d->settings.intensityThresholdHigh));
+	writer->writeAttribute(QStringLiteral("intensityThresholdLow"), QString::number(d->settings.intensityThresholdLow));
+	writer->writeAttribute(QStringLiteral("saturationThresholdHigh"), QString::number(d->settings.saturationThresholdHigh));
+	writer->writeAttribute(QStringLiteral("saturationThresholdLow"), QString::number(d->settings.saturationThresholdLow));
+	writer->writeAttribute(QStringLiteral("valueThresholdHigh"), QString::number(d->settings.valueThresholdHigh));
+	writer->writeAttribute(QStringLiteral("valueThresholdLow"), QString::number(d->settings.valueThresholdLow));
 	writer->writeEndElement();
 
-	//Symbols
+	// Symbols
 	d->symbol->save(writer);
 
-	//serialize all children
+	// serialize all children
 	for (auto* child : children<AbstractAspect>(ChildIndexFlag::IncludeHidden))
 		child->save(writer);
 
@@ -487,117 +514,116 @@ bool DatapickerImage::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "datapickerImage")
+		if (reader->isEndElement() && reader->name() == QLatin1String("datapickerImage"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (!preview && reader->name() == "general") {
+		if (!preview && reader->name() == QLatin1String("general")) {
 			attribs = reader->attributes();
 
-			str = attribs.value("fileName").toString();
+			str = attribs.value(QStringLiteral("fileName")).toString();
 			d->fileName = str;
 
 			READ_INT_VALUE("plotPointsType", plotPointsType, DatapickerImage::PointsType);
 			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
-		} else if (!preview && reader->name() == "axisPoint") {
+		} else if (!preview && reader->name() == QLatin1String("axisPoint")) {
 			attribs = reader->attributes();
-
-			READ_INT_VALUE("graphType", axisPoints.type, DatapickerImage::GraphType);
+			READ_INT_VALUE_DIRECT("graphType", d->axisPoints.type, GraphType);
 			READ_INT_VALUE("ternaryScale", axisPoints.ternaryScale, int);
 
-			str = attribs.value("axisPointLogicalX1").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalX1")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalX1").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalX1")).toString());
 			else
 				d->axisPoints.logicalPos[0].setX(str.toDouble());
 
-			str = attribs.value("axisPointLogicalY1").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalY1")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalY1").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalY1")).toString());
 			else
 				d->axisPoints.logicalPos[0].setY(str.toDouble());
 
-			str = attribs.value("axisPointLogicalZ1").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalZ1")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalZ1").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalZ1")).toString());
 			else
 				d->axisPoints.logicalPos[0].setZ(str.toDouble());
 
-			str = attribs.value("axisPointLogicalX2").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalX2")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalX2").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalX2")).toString());
 			else
 				d->axisPoints.logicalPos[1].setX(str.toDouble());
 
-			str = attribs.value("axisPointLogicalY2").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalY2")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalY2").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalY2")).toString());
 			else
 				d->axisPoints.logicalPos[1].setY(str.toDouble());
 
-			str = attribs.value("axisPointLogicalZ2").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalZ2")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalZ2").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalZ2")).toString());
 			else
 				d->axisPoints.logicalPos[1].setZ(str.toDouble());
 
-			str = attribs.value("axisPointLogicalX3").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalX3")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalX3").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalX3")).toString());
 			else
 				d->axisPoints.logicalPos[2].setX(str.toDouble());
 
-			str = attribs.value("axisPointLogicalY3").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalY3")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalY3").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalY3")).toString());
 			else
 				d->axisPoints.logicalPos[2].setY(str.toDouble());
 
-			str = attribs.value("axisPointLogicalZ3").toString();
+			str = attribs.value(QStringLiteral("axisPointLogicalZ3")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointLogicalZ3").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointLogicalZ3")).toString());
 			else
 				d->axisPoints.logicalPos[2].setZ(str.toDouble());
 
-			str = attribs.value("axisPointSceneX1").toString();
+			str = attribs.value(QStringLiteral("axisPointSceneX1")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointSceneX1").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointSceneX1")).toString());
 			else
 				d->axisPoints.scenePos[0].setX(str.toDouble());
 
-			str = attribs.value("axisPointSceneY1").toString();
+			str = attribs.value(QStringLiteral("axisPointSceneY1")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointSceneY1").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointSceneY1")).toString());
 			else
 				d->axisPoints.scenePos[0].setY(str.toDouble());
 
-			str = attribs.value("axisPointSceneX2").toString();
+			str = attribs.value(QStringLiteral("axisPointSceneX2")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointSceneX2").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointSceneX2")).toString());
 			else
 				d->axisPoints.scenePos[1].setX(str.toDouble());
 
-			str = attribs.value("axisPointSceneY2").toString();
+			str = attribs.value(QStringLiteral("axisPointSceneY2")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointSceneY2").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointSceneY2")).toString());
 			else
 				d->axisPoints.scenePos[1].setY(str.toDouble());
 
-			str = attribs.value("axisPointSceneX3").toString();
+			str = attribs.value(QStringLiteral("axisPointSceneX3")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointSceneX3").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointSceneX3")).toString());
 			else
 				d->axisPoints.scenePos[2].setX(str.toDouble());
 
-			str = attribs.value("axisPointSceneY3").toString();
+			str = attribs.value(QStringLiteral("axisPointSceneY3")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("axisPointSceneY3").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("axisPointSceneY3")).toString());
 			else
 				d->axisPoints.scenePos[2].setY(str.toDouble());
 
-		} else if (!preview && reader->name() == "editorSettings") {
+		} else if (!preview && reader->name() == QLatin1String("editorSettings")) {
 			attribs = reader->attributes();
 
 			READ_INT_VALUE("plotImageType", plotImageType, DatapickerImage::PlotImageType);
@@ -614,106 +640,106 @@ bool DatapickerImage::load(XmlStreamReader* reader, bool preview) {
 			READ_INT_VALUE("saturationThresholdLow", settings.saturationThresholdLow, int);
 			READ_INT_VALUE("valueThresholdHigh", settings.valueThresholdHigh, int);
 			READ_INT_VALUE("valueThresholdLow", settings.valueThresholdLow, int);
-		} else if (!preview && reader->name() == "symbolProperties") {
-			//old serialization that was used before the switch to Symbol::load().
-			//in the old serialization the symbol properties and "point visibility" where saved
-			//under "symbolProperties".
+		} else if (!preview && reader->name() == QLatin1String("symbolProperties")) {
+			// old serialization that was used before the switch to Symbol::load().
+			// in the old serialization the symbol properties and "point visibility" where saved
+			// under "symbolProperties".
 			attribs = reader->attributes();
 
-			str = attribs.value("pointRotationAngle").toString();
+			str = attribs.value(QStringLiteral("pointRotationAngle")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointRotationAngle").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointRotationAngle")).toString());
 			else
 				d->symbol->setRotationAngle(str.toDouble());
 
-			str = attribs.value("pointOpacity").toString();
+			str = attribs.value(QStringLiteral("pointOpacity")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointOpacity").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointOpacity")).toString());
 			else
 				d->symbol->setOpacity(str.toDouble());
 
-			str = attribs.value("pointSize").toString();
+			str = attribs.value(QStringLiteral("pointSize")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointSize").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointSize")).toString());
 			else
 				d->symbol->setSize(str.toDouble());
 
-			str = attribs.value("pointStyle").toString();
+			str = attribs.value(QStringLiteral("pointStyle")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("pointStyle").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("pointStyle")).toString());
 			else
 				d->symbol->setStyle(static_cast<Symbol::Style>(str.toInt()));
 
-			//brush
+			// brush
 			QBrush brush;
-			str = attribs.value("brush_style").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_style").toString());
+			str = attribs.value(QStringLiteral("brush_style")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_style")).toString());
 			else
-				brush.setStyle( static_cast<Qt::BrushStyle>(str.toInt()) );
+				brush.setStyle(static_cast<Qt::BrushStyle>(str.toInt()));
 
 			QColor color;
-			str = attribs.value("brush_color_r").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_color_r").toString());
+			str = attribs.value(QStringLiteral("brush_color_r")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_color_r")).toString());
 			else
 				color.setRed(str.toInt());
 
-			str = attribs.value("brush_color_g").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_color_g").toString());
+			str = attribs.value(QStringLiteral("brush_color_g")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_color_g")).toString());
 			else
 				color.setGreen(str.toInt());
 
-			str = attribs.value("brush_color_b").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("brush_color_b").toString());
+			str = attribs.value(QStringLiteral("brush_color_b")).toString();
+			if (str.isEmpty())
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("brush_color_b")).toString());
 			else
 				color.setBlue(str.toInt());
 
 			brush.setColor(color);
 			d->symbol->setBrush(brush);
 
-			//pen
+			// pen
 			QPen pen;
-			str = attribs.value("style").toString();
+			str = attribs.value(QStringLiteral("style")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("style").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("style")).toString());
 			else
-				pen.setStyle( static_cast<Qt::PenStyle>(str.toInt()) );
+				pen.setStyle(static_cast<Qt::PenStyle>(str.toInt()));
 
-			str = attribs.value("color_r").toString();
+			str = attribs.value(QStringLiteral("color_r")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("color_r").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("color_r")).toString());
 			else
-				color.setRed( str.toInt() );
+				color.setRed(str.toInt());
 
-			str = attribs.value("color_g").toString();
+			str = attribs.value(QStringLiteral("color_g")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("color_g").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("color_g")).toString());
 			else
-				color.setGreen( str.toInt() );
+				color.setGreen(str.toInt());
 
-			str = attribs.value("color_b").toString();
+			str = attribs.value(QStringLiteral("color_b")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("color_b").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("color_b")).toString());
 			else
-				color.setBlue( str.toInt() );
+				color.setBlue(str.toInt());
 
 			pen.setColor(color);
 
-			str = attribs.value("width").toString();
+			str = attribs.value(QStringLiteral("width")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("width").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("width")).toString());
 			else
-				pen.setWidthF( str.toDouble() );
+				pen.setWidthF(str.toDouble());
 
 			d->symbol->setPen(pen);
 
 			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
-		} else if (!preview && reader->name() == "symbols") {
+		} else if (!preview && reader->name() == QLatin1String("symbols")) {
 			d->symbol->load(reader, preview);
-		} else if (reader->name() == "datapickerPoint") {
+		} else if (reader->name() == QLatin1String("datapickerPoint")) {
 			auto* datapickerPoint = new DatapickerPoint(QString());
 			if (!datapickerPoint->load(reader, preview)) {
 				delete datapickerPoint;
@@ -725,7 +751,8 @@ bool DatapickerImage::load(XmlStreamReader* reader, bool preview) {
 			}
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-			if (!reader->skipToEndElement()) return false;
+			if (!reader->skipToEndElement())
+				return false;
 		}
 	}
 
