@@ -1,12 +1,12 @@
 /*
-    File                 : DatapickerImage.h
-    Project              : LabPlot
-    Description          : Worksheet for Datapicker
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+	File                 : DatapickerImage.h
+	Project              : LabPlot
+	Description          : Worksheet for Datapicker
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef DATAPICKERIMAGE_H
@@ -16,11 +16,12 @@
 #include "backend/lib/macros.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
 
-#include <QVector3D>
 #include <QPen>
+#include <QVector3D>
 
 class DatapickerImagePrivate;
 class DatapickerImageView;
+class DatapickerPoint;
 class Segments;
 
 class QGraphicsScene;
@@ -33,29 +34,29 @@ public:
 	explicit DatapickerImage(const QString& name, bool loading = false);
 	~DatapickerImage() override;
 
-	enum class GraphType {Cartesian, PolarInDegree, PolarInRadians, LogarithmicX, LogarithmicY, Ternary};
-	enum class ColorAttributes {None, Intensity, Foreground, Hue, Saturation, Value};
-	enum class PlotImageType {NoImage, OriginalImage, ProcessedImage};
-	enum class PointsType {AxisPoints, CurvePoints, SegmentPoints};
+	enum class GraphType { Linear, PolarInDegree, PolarInRadians, LnX, LnY, Ternary, LnXY, Log10XY, Log10X, Log10Y };
+	enum class ColorAttributes { None, Intensity, Foreground, Hue, Saturation, Value };
+	enum class PlotImageType { NoImage, OriginalImage, ProcessedImage };
+	enum class PointsType { AxisPoints, CurvePoints, SegmentPoints };
 
 	struct ReferencePoints {
-		GraphType type{GraphType::Cartesian};
+		GraphType type{GraphType::Linear};
 		QPointF scenePos[3];
 		QVector3D logicalPos[3];
 		double ternaryScale{1.0};
 	};
 
 	struct EditorSettings {
-		int intensityThresholdLow{20};
-		int intensityThresholdHigh{100};
-		int foregroundThresholdLow{30};
-		int foregroundThresholdHigh{90};
 		int hueThresholdLow{0};
 		int hueThresholdHigh{360};
-		int saturationThresholdLow{30};
+		int saturationThresholdLow{0};
 		int saturationThresholdHigh{100};
-		int valueThresholdLow{30};
-		int valueThresholdHigh{90};
+		int valueThresholdLow{0};
+		int valueThresholdHigh{100};
+		int intensityThresholdLow{0};
+		int intensityThresholdHigh{100};
+		int foregroundThresholdLow{20};
+		int foregroundThresholdHigh{100};
 	};
 
 	QIcon icon() const override;
@@ -72,23 +73,27 @@ public:
 
 	QRectF pageRect() const;
 	void setPageRect(const QRectF&);
-	QGraphicsScene *scene() const;
+	QGraphicsScene* scene() const;
 	void setPrinting(bool) const;
 	void setSelectedInView(const bool);
 	void setSegmentsHoverEvent(const bool);
+	int currentSelectedReferencePoint();
 
 	void setPlotImageType(const DatapickerImage::PlotImageType);
 	DatapickerImage::PlotImageType plotImageType();
 
+	static QString graphTypeToString(const GraphType);
+	static GraphType stringToGraphType(const QString&);
+
 	bool isLoaded{false};
 	QImage originalPlotImage;
 	QImage processedPlotImage;
 	QColor background;
-	int *foregroundBins;
-	int *hueBins;
-	int *saturationBins;
-	int *valueBins;
-	int *intensityBins;
+	int* foregroundBins;
+	int* hueBins;
+	int* saturationBins;
+	int* valueBins;
+	int* intensityBins;
 
 	QGraphicsPixmapItem* m_magnificationWindow{nullptr};
 
@@ -105,6 +110,9 @@ public:
 
 	typedef DatapickerImagePrivate Private;
 
+public Q_SLOTS:
+	void referencePointSelected(const DatapickerPoint*);
+
 private:
 	void init();
 
@@ -112,6 +120,7 @@ private:
 	mutable DatapickerImageView* m_view{nullptr};
 	friend class DatapickerImagePrivate;
 	Segments* m_segments;
+	int m_currentRefPoint{-1};
 
 Q_SIGNALS:
 	void requestProjectContextMenu(QMenu*);
@@ -130,5 +139,6 @@ Q_SIGNALS:
 	void pointBrushChanged(QBrush);
 	void pointPenChanged(const QPen&);
 	void pointVisibilityChanged(bool);
+	void referencePointSelected(int index);
 };
 #endif
