@@ -1,25 +1,25 @@
 /*
-    File                 : DatapickerPoint.cpp
-    Project              : LabPlot
-    Description          : Graphic Item for coordinate points of Datapicker
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : DatapickerPoint.cpp
+	Project              : LabPlot
+	Description          : Graphic Item for coordinate points of Datapicker
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "DatapickerPoint.h"
 #include "DatapickerPointPrivate.h"
-#include "backend/lib/commandtemplates.h"
-#include "backend/lib/XmlStreamReader.h"
 #include "backend/datapicker/DatapickerCurve.h"
+#include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/commandtemplates.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
 
-#include <QPainter>
 #include <QGraphicsScene>
-#include <QMenu>
 #include <QGraphicsSceneMouseEvent>
+#include <QMenu>
+#include <QPainter>
 
 #include <KConfig>
 #include <KConfigGroup>
@@ -30,11 +30,11 @@
  * \brief A customizable error-bar for DatapickerPoint.
  */
 
-ErrorBarItem::ErrorBarItem(DatapickerPoint* parent, ErrorBarType type) :
-	QGraphicsRectItem(parent->graphicsItem()),
-	barLineItem(new QGraphicsLineItem(parent->graphicsItem())),
-	m_type(type),
-	m_parentItem(parent) {
+ErrorBarItem::ErrorBarItem(DatapickerPoint* parent, ErrorBarType type)
+	: QGraphicsRectItem(parent->graphicsItem())
+	, barLineItem(new QGraphicsLineItem(parent->graphicsItem()))
+	, m_type(type)
+	, m_parentItem(parent) {
 	setFlag(QGraphicsItem::ItemIsMovable);
 	setFlag(QGraphicsItem::ItemIsSelectable);
 	setFlag(QGraphicsItem::ItemSendsGeometryChanges);
@@ -77,13 +77,13 @@ void ErrorBarItem::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
 }
 
 void ErrorBarItem::hoverEnterEvent(QGraphicsSceneHoverEvent*) {
-	if (m_type == ErrorBarType::PlusDeltaX ||m_type == ErrorBarType::MinusDeltaX)
+	if (m_type == ErrorBarType::PlusDeltaX || m_type == ErrorBarType::MinusDeltaX)
 		setCursor(Qt::SizeHorCursor);
 	else
 		setCursor(Qt::SizeVerCursor);
 }
 
-QVariant ErrorBarItem::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) {
+QVariant ErrorBarItem::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant& value) {
 	if (change == QGraphicsItem::ItemPositionChange) {
 		QPointF newPos = value.toPointF();
 		if (m_type == ErrorBarType::PlusDeltaX || m_type == ErrorBarType::MinusDeltaX) {
@@ -110,19 +110,19 @@ QVariant ErrorBarItem::itemChange(QGraphicsItem::GraphicsItemChange change, cons
  */
 
 DatapickerPoint::DatapickerPoint(const QString& name)
-	: AbstractAspect(name, AspectType::DatapickerPoint), d_ptr(new DatapickerPointPrivate(this)) {
-
+	: AbstractAspect(name, AspectType::DatapickerPoint)
+	, d_ptr(new DatapickerPointPrivate(this)) {
 	init();
 }
 
-DatapickerPoint::DatapickerPoint(const QString& name, DatapickerPointPrivate *dd)
-	: AbstractAspect(name, AspectType::DatapickerPoint), d_ptr(dd) {
-
+DatapickerPoint::DatapickerPoint(const QString& name, DatapickerPointPrivate* dd)
+	: AbstractAspect(name, AspectType::DatapickerPoint)
+	, d_ptr(dd) {
 	init();
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 DatapickerPoint::~DatapickerPoint() = default;
 
 void DatapickerPoint::init() {
@@ -131,8 +131,8 @@ void DatapickerPoint::init() {
 	KConfig config;
 	KConfigGroup group;
 	group = config.group("DatapickerPoint");
-	d->position.setX( group.readEntry("PositionXValue", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Centimeter)) );
-	d->position.setY( group.readEntry("PositionYValue", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Centimeter)) );
+	d->position.setX(group.readEntry("PositionXValue", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Centimeter)));
+	d->position.setY(group.readEntry("PositionYValue", Worksheet::convertToSceneUnits(1, Worksheet::Unit::Centimeter)));
 	d->plusDeltaXPos = group.readEntry("PlusDeltaXPos", QPointF(30, 0));
 	d->minusDeltaXPos = group.readEntry("MinusDeltaXPos", QPointF(-30, 0));
 	d->plusDeltaYPos = group.readEntry("PlusDeltaYPos", QPointF(0, -30));
@@ -150,7 +150,7 @@ void DatapickerPoint::initErrorBar(DatapickerCurve::Errors errors) {
 		minusDeltaXItem->setPosition(minusDeltaXPos());
 		connect(this, &DatapickerPoint::minusDeltaXPosChanged, minusDeltaXItem, &ErrorBarItem::setPosition);
 
-		m_errorBarItemList<<plusDeltaXItem<<minusDeltaXItem;
+		m_errorBarItemList << plusDeltaXItem << minusDeltaXItem;
 	}
 
 	if (errors.y != DatapickerCurve::ErrorType::NoError) {
@@ -162,17 +162,17 @@ void DatapickerPoint::initErrorBar(DatapickerCurve::Errors errors) {
 		minusDeltaYItem->setPosition(minusDeltaYPos());
 		connect(this, &DatapickerPoint::minusDeltaYPosChanged, minusDeltaYItem, &ErrorBarItem::setPosition);
 
-		m_errorBarItemList<<plusDeltaYItem<<minusDeltaYItem;
+		m_errorBarItemList << plusDeltaYItem << minusDeltaYItem;
 	}
 
 	retransform();
 }
 
 /*!
-    Returns an icon to be used in the project explorer.
+	Returns an icon to be used in the project explorer.
 */
 QIcon DatapickerPoint::icon() const {
-	return QIcon::fromTheme("draw-cross");
+	return QIcon::fromTheme(QStringLiteral("draw-cross"));
 }
 
 QMenu* DatapickerPoint::createContextMenu() {
@@ -195,9 +195,9 @@ void DatapickerPoint::retransform() {
 }
 
 /* ============================ getter methods ================= */
-//point
+// point
 BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, position, position)
-//error-bar
+// error-bar
 BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, plusDeltaXPos, plusDeltaXPos)
 BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, minusDeltaXPos, minusDeltaXPos)
 BASIC_SHARED_D_READER_IMPL(DatapickerPoint, QPointF, plusDeltaYPos, plusDeltaYPos)
@@ -222,7 +222,7 @@ void DatapickerPoint::setPlusDeltaXPos(QPointF pos) {
 		beginMacro(i18n("%1: set +delta_X position", name()));
 		if (curve->curveErrorTypes().x == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetPlusDeltaXPosCmd(d, pos, ki18n("%1: set +delta X position")));
-			setMinusDeltaXPos(QPointF(-qAbs(pos.x()), pos.y()));
+			setMinusDeltaXPos(QPointF(-std::abs(pos.x()), pos.y()));
 		} else
 			exec(new DatapickerPointSetPlusDeltaXPosCmd(d, pos, ki18n("%1: set +delta X position")));
 		endMacro();
@@ -240,7 +240,7 @@ void DatapickerPoint::setMinusDeltaXPos(QPointF pos) {
 		beginMacro(i18n("%1: set -delta_X position", name()));
 		if (curve->curveErrorTypes().x == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetMinusDeltaXPosCmd(d, pos, ki18n("%1: set -delta_X position")));
-			setPlusDeltaXPos(QPointF(qAbs(pos.x()), pos.y()));
+			setPlusDeltaXPos(QPointF(std::abs(pos.x()), pos.y()));
 		} else
 			exec(new DatapickerPointSetMinusDeltaXPosCmd(d, pos, ki18n("%1: set -delta_X position")));
 		endMacro();
@@ -258,7 +258,7 @@ void DatapickerPoint::setPlusDeltaYPos(QPointF pos) {
 		beginMacro(i18n("%1: set +delta_Y position", name()));
 		if (curve->curveErrorTypes().y == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetPlusDeltaYPosCmd(d, pos, ki18n("%1: set +delta_Y position")));
-			setMinusDeltaYPos(QPointF(pos.x(), qAbs(pos.y())));
+			setMinusDeltaYPos(QPointF(pos.x(), std::abs(pos.y())));
 		} else
 			exec(new DatapickerPointSetPlusDeltaYPosCmd(d, pos, ki18n("%1: set +delta_Y position")));
 		endMacro();
@@ -276,7 +276,7 @@ void DatapickerPoint::setMinusDeltaYPos(QPointF pos) {
 		beginMacro(i18n("%1: set -delta_Y position", name()));
 		if (curve->curveErrorTypes().y == DatapickerCurve::ErrorType::SymmetricError) {
 			exec(new DatapickerPointSetMinusDeltaYPosCmd(d, pos, ki18n("%1: set -delta_Y position")));
-			setPlusDeltaYPos(QPointF(pos.x(), -qAbs(pos.y())));
+			setPlusDeltaYPos(QPointF(pos.x(), -std::abs(pos.y())));
 		} else
 			exec(new DatapickerPointSetMinusDeltaYPosCmd(d, pos, ki18n("%1: set -delta_Y position")));
 		endMacro();
@@ -301,7 +301,8 @@ bool DatapickerPoint::isReferencePoint() const {
 //##############################################################################
 //####################### Private implementation ###############################
 //##############################################################################
-DatapickerPointPrivate::DatapickerPointPrivate(DatapickerPoint* owner) : q(owner) {
+DatapickerPointPrivate::DatapickerPointPrivate(DatapickerPoint* owner)
+	: q(owner) {
 	setFlag(QGraphicsItem::ItemIsMovable);
 	setFlag(QGraphicsItem::ItemSendsGeometryChanges);
 	setFlag(QGraphicsItem::ItemIsSelectable);
@@ -313,13 +314,17 @@ QString DatapickerPointPrivate::name() const {
 }
 
 /*!
-    calculates the position and the bounding box of the item/point. Called on geometry or properties changes.
+	calculates the position and the bounding box of the item/point. Called on geometry or properties changes.
  */
 void DatapickerPointPrivate::retransform() {
 	if (q->isLoading())
 		return;
-	updatePropeties();
+
 	setPos(position);
+	updatePoint();
+
+	updatePropeties();
+
 	QPainterPath path = Symbol::stylePath(pointStyle);
 	boundingRectangle = path.boundingRect();
 	recalcShapeAndBoundingRect();
@@ -374,14 +379,14 @@ void DatapickerPointPrivate::updatePropeties() {
 }
 
 /*!
-    Returns the outer bounds of the item as a rectangle.
+	Returns the outer bounds of the item as a rectangle.
  */
 QRectF DatapickerPointPrivate::boundingRect() const {
 	return transformedBoundingRectangle;
 }
 
 /*!
-    Returns the shape of this item as a QPainterPath in local coordinates.
+	Returns the shape of this item as a QPainterPath in local coordinates.
 */
 QPainterPath DatapickerPointPrivate::shape() const {
 	return itemShape;
@@ -415,6 +420,12 @@ void DatapickerPointPrivate::hoverLeaveEvent(QGraphicsSceneHoverEvent*) {
 	setCursor(Qt::CrossCursor);
 }
 
+QVariant DatapickerPointPrivate::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant& value) {
+	if (change == QGraphicsItem::GraphicsItemChange::ItemSelectedHasChanged && value.toBool())
+		emit q->pointSelected(q);
+	return QGraphicsItem::itemChange(change, value);
+}
+
 void DatapickerPointPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget*) {
 	QPainterPath path = Symbol::stylePath(pointStyle);
 	QTransform trafo;
@@ -433,8 +444,8 @@ void DatapickerPointPrivate::paint(QPainter* painter, const QStyleOptionGraphics
 	painter->restore();
 
 	if (isSelected() && !m_printing) {
-		//TODO: move the initialization of QPen to a parent class later so we don't
-		//need to create it in every paint() call.
+		// TODO: move the initialization of QPen to a parent class later so we don't
+		// need to create it in every paint() call.
 		painter->setPen(QPen(QApplication::palette().color(QPalette::Highlight), 1, Qt::SolidLine));
 		painter->drawPath(itemShape);
 	}
@@ -451,28 +462,26 @@ void DatapickerPointPrivate::contextMenuEvent(QGraphicsSceneContextMenuEvent* ev
 void DatapickerPoint::save(QXmlStreamWriter* writer) const {
 	Q_D(const DatapickerPoint);
 
-	writer->writeStartElement( "datapickerPoint" );
+	writer->writeStartElement(QStringLiteral("datapickerPoint"));
 	writeBasicAttributes(writer);
 
-	//geometry
-	writer->writeStartElement( "geometry" );
-	writer->writeAttribute( "x", QString::number(d->position.x()) );
-	writer->writeAttribute( "y", QString::number(d->position.y()) );
+	// geometry
+	writer->writeStartElement(QStringLiteral("geometry"));
+	writer->writeAttribute(QStringLiteral("x"), QString::number(d->position.x()));
+	writer->writeAttribute(QStringLiteral("y"), QString::number(d->position.y()));
 	writer->writeEndElement();
 
 	auto* curve = dynamic_cast<DatapickerCurve*>(parentAspect());
-	if (curve && (curve->curveErrorTypes().x != DatapickerCurve::ErrorType::NoError
-		|| curve->curveErrorTypes().y != DatapickerCurve::ErrorType::NoError)) {
-
-		writer->writeStartElement( "errorBar" );
-		writer->writeAttribute( "plusDeltaXPos_x", QString::number(d->plusDeltaXPos.x()) );
-		writer->writeAttribute( "plusDeltaXPos_y", QString::number(d->plusDeltaXPos.y()) );
-		writer->writeAttribute( "minusDeltaXPos_x", QString::number(d->minusDeltaXPos.x()) );
-		writer->writeAttribute( "minusDeltaXPos_y", QString::number(d->minusDeltaXPos.y()) );
-		writer->writeAttribute( "plusDeltaYPos_x", QString::number(d->plusDeltaYPos.x()) );
-		writer->writeAttribute( "plusDeltaYPos_y", QString::number(d->plusDeltaYPos.y()) );
-		writer->writeAttribute( "minusDeltaYPos_x", QString::number(d->minusDeltaYPos.x()) );
-		writer->writeAttribute( "minusDeltaYPos_y", QString::number(d->minusDeltaYPos.y()) );
+	if (curve && (curve->curveErrorTypes().x != DatapickerCurve::ErrorType::NoError || curve->curveErrorTypes().y != DatapickerCurve::ErrorType::NoError)) {
+		writer->writeStartElement(QStringLiteral("errorBar"));
+		writer->writeAttribute(QStringLiteral("plusDeltaXPos_x"), QString::number(d->plusDeltaXPos.x()));
+		writer->writeAttribute(QStringLiteral("plusDeltaXPos_y"), QString::number(d->plusDeltaXPos.y()));
+		writer->writeAttribute(QStringLiteral("minusDeltaXPos_x"), QString::number(d->minusDeltaXPos.x()));
+		writer->writeAttribute(QStringLiteral("minusDeltaXPos_y"), QString::number(d->minusDeltaXPos.y()));
+		writer->writeAttribute(QStringLiteral("plusDeltaYPos_x"), QString::number(d->plusDeltaYPos.x()));
+		writer->writeAttribute(QStringLiteral("plusDeltaYPos_y"), QString::number(d->plusDeltaYPos.y()));
+		writer->writeAttribute(QStringLiteral("minusDeltaYPos_x"), QString::number(d->minusDeltaYPos.x()));
+		writer->writeAttribute(QStringLiteral("minusDeltaYPos_y"), QString::number(d->minusDeltaYPos.y()));
 		writer->writeEndElement();
 	}
 
@@ -492,79 +501,80 @@ bool DatapickerPoint::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "datapickerPoint")
+		if (reader->isEndElement() && reader->name() == QLatin1String("datapickerPoint"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (!preview && reader->name() == "geometry") {
+		if (!preview && reader->name() == QLatin1String("geometry")) {
 			attribs = reader->attributes();
 
-			str = attribs.value("x").toString();
+			str = attribs.value(QStringLiteral("x")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("x").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("x")).toString());
 			else
 				d->position.setX(str.toDouble());
 
-			str = attribs.value("y").toString();
+			str = attribs.value(QStringLiteral("y")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("y").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("y")).toString());
 			else
 				d->position.setY(str.toDouble());
-		} else if (!preview && reader->name() == "errorBar") {
+		} else if (!preview && reader->name() == QLatin1String("errorBar")) {
 			attribs = reader->attributes();
 
-			str = attribs.value("plusDeltaXPos_x").toString();
+			str = attribs.value(QStringLiteral("plusDeltaXPos_x")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("plusDeltaXPos_x").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("plusDeltaXPos_x")).toString());
 			else
 				d->plusDeltaXPos.setX(str.toDouble());
 
-			str = attribs.value("plusDeltaXPos_y").toString();
+			str = attribs.value(QStringLiteral("plusDeltaXPos_y")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("plusDeltaXPos_y").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("plusDeltaXPos_y")).toString());
 			else
 				d->plusDeltaXPos.setY(str.toDouble());
 
-			str = attribs.value("minusDeltaXPos_x").toString();
+			str = attribs.value(QStringLiteral("minusDeltaXPos_x")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("minusDeltaXPos_x").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("minusDeltaXPos_x")).toString());
 			else
 				d->minusDeltaXPos.setX(str.toDouble());
 
-			str = attribs.value("minusDeltaXPos_y").toString();
+			str = attribs.value(QStringLiteral("minusDeltaXPos_y")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("minusDeltaXPos_y").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("minusDeltaXPos_y")).toString());
 			else
 				d->minusDeltaXPos.setY(str.toDouble());
 
-			str = attribs.value("plusDeltaYPos_x").toString();
+			str = attribs.value(QStringLiteral("plusDeltaYPos_x")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("plusDeltaYPos_x").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("plusDeltaYPos_x")).toString());
 			else
 				d->plusDeltaYPos.setX(str.toDouble());
 
-			str = attribs.value("plusDeltaYPos_y").toString();
+			str = attribs.value(QStringLiteral("plusDeltaYPos_y")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("plusDeltaYPos_y").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("plusDeltaYPos_y")).toString());
 			else
 				d->plusDeltaYPos.setY(str.toDouble());
 
-			str = attribs.value("minusDeltaYPos_x").toString();
+			str = attribs.value(QStringLiteral("minusDeltaYPos_x")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("minusDeltaYPos_x").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("minusDeltaYPos_x")).toString());
 			else
 				d->minusDeltaYPos.setX(str.toDouble());
 
-			str = attribs.value("minusDeltaYPos_y").toString();
+			str = attribs.value(QStringLiteral("minusDeltaYPos_y")).toString();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("minusDeltaYPos_y").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("minusDeltaYPos_y")).toString());
 			else
 				d->minusDeltaYPos.setY(str.toDouble());
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-			if (!reader->skipToEndElement()) return false;
+			if (!reader->skipToEndElement())
+				return false;
 		}
 	}
 
