@@ -1,19 +1,24 @@
 /*
-    File                 : DatapickerPointPrivate.h
-    Project              : LabPlot
-    Description          : Graphic Item for coordinate points of Datapicker
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : DatapickerPointPrivate.h
+	Project              : LabPlot
+	Description          : Graphic Item for coordinate points of Datapicker
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef DATAPICKERPOINTPRIVATE_H
 #define DATAPICKERPOINTPRIVATE_H
 
-class QGraphicsItem;
+#include "backend/worksheet/Worksheet.h"
 
-class DatapickerPointPrivate: public QGraphicsItem {
+#include <QBrush>
+#include <QGraphicsItem>
+#include <QPen>
+
+class DatapickerPoint;
+
+class DatapickerPointPrivate : public QGraphicsItem {
 public:
 	explicit DatapickerPointPrivate(DatapickerPoint*);
 
@@ -27,15 +32,15 @@ public:
 	bool m_printing{false};
 	bool isReferencePoint{false};
 
-	qreal rotationAngle;
+	qreal rotationAngle{0.0};
 	QPointF position;
 	QRectF boundingRectangle;
 	QRectF transformedBoundingRectangle;
-	Symbol::Style pointStyle;
+	Symbol::Style pointStyle{Symbol::Style::NoSymbols};
 	QBrush brush;
 	QPen pen;
-	qreal opacity;
-	qreal size;
+	qreal opacity{1.0};
+	qreal size{1.0};
 	QPainterPath itemShape;
 
 	QPointF plusDeltaXPos;
@@ -44,9 +49,9 @@ public:
 	QPointF minusDeltaYPos;
 	QBrush errorBarBrush;
 	QPen errorBarPen;
-	qreal errorBarSize;
+	qreal errorBarSize{Worksheet::convertToSceneUnits(8, Worksheet::Unit::Point)};
 
-	//reimplemented from QGraphicsItem
+	// reimplemented from QGraphicsItem
 	QRectF boundingRect() const override;
 	QPainterPath shape() const override;
 	void paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget* widget = nullptr) override;
@@ -58,6 +63,7 @@ private:
 	void mouseReleaseEvent(QGraphicsSceneMouseEvent*) override;
 	void hoverEnterEvent(QGraphicsSceneHoverEvent*) override;
 	void hoverLeaveEvent(QGraphicsSceneHoverEvent*) override;
+	QVariant itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant& value) override;
 };
 
 #endif
