@@ -1,22 +1,22 @@
 /*
-    File                 : Segment.cpp
-    Project              : LabPlot
-    Description          : Graphics-item for curve of Datapicker
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : Segment.cpp
+	Project              : LabPlot
+	Description          : Graphics-item for curve of Datapicker
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "Segment.h"
 #include "SegmentPrivate.h"
+#include "backend/datapicker/Datapicker.h"
 #include "backend/datapicker/DatapickerImage.h"
 #include "backend/datapicker/DatapickerPoint.h"
 #include "backend/worksheet/Worksheet.h"
-#include "backend/datapicker/Datapicker.h"
 
-#include <QPainter>
-#include <QGraphicsScene>
 #include <QDesktopWidget>
+#include <QGraphicsScene>
+#include <QPainter>
 
 #include <KLocalizedString>
 
@@ -25,7 +25,9 @@
  * \brief graphics-item class for curve-segment
  */
 
-Segment::Segment(DatapickerImage* image) : m_image(image), d_ptr(new SegmentPrivate(this)) {
+Segment::Segment(DatapickerImage* image)
+	: m_image(image)
+	, d_ptr(new SegmentPrivate(this)) {
 	m_image->scene()->addItem(this->graphicsItem());
 }
 
@@ -56,10 +58,9 @@ void Segment::setVisible(bool on) {
 //##############################################################################
 //####################### Private implementation ###############################
 //##############################################################################
-SegmentPrivate::SegmentPrivate(Segment *owner) :
-	scaleFactor(Worksheet::convertToSceneUnits(1, Worksheet::Unit::Inch)/QApplication::desktop()->physicalDpiX()),
-	q(owner) {
-
+SegmentPrivate::SegmentPrivate(Segment* owner)
+	: scaleFactor(Worksheet::convertToSceneUnits(1, Worksheet::Unit::Inch) / QApplication::desktop()->physicalDpiX())
+	, q(owner) {
 	setFlag(QGraphicsItem::ItemIsSelectable);
 	setFlag(QGraphicsItem::ItemSendsGeometryChanges);
 	setAcceptHoverEvents(true);
@@ -69,7 +70,7 @@ SegmentPrivate::SegmentPrivate(Segment *owner) :
 }
 
 /*!
-    calculates the position and the bounding box of the item. Called on geometry or properties changes.
+	calculates the position and the bounding box of the item. Called on geometry or properties changes.
  */
 void SegmentPrivate::retransform() {
 	QMatrix matrix;
@@ -83,14 +84,14 @@ void SegmentPrivate::retransform() {
 }
 
 /*!
-    Returns the outer bounds of the item as a rectangle.
+	Returns the outer bounds of the item as a rectangle.
  */
 QRectF SegmentPrivate::boundingRect() const {
 	return boundingRectangle;
 }
 
 /*!
-    Returns the shape of this item as a QPainterPath in local coordinates.
+	Returns the shape of this item as a QPainterPath in local coordinates.
 */
 QPainterPath SegmentPrivate::shape() const {
 	return itemShape;
@@ -115,11 +116,11 @@ void SegmentPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*
 		painter->drawPath(linePath);
 	}
 
-// 	if (isSelected()) {
-// 		painter->setPen(QPen(QApplication::palette().color(QPalette::Highlight), 2, Qt::SolidLine));
-// 		painter->setOpacity(selectedOpacity);
-// 		painter->drawPath(itemShape);
-// 	}
+	// 	if (isSelected()) {
+	// 		painter->setPen(QPen(QApplication::palette().color(QPalette::Highlight), 2, Qt::SolidLine));
+	// 		painter->setOpacity(selectedOpacity);
+	// 		painter->drawPath(itemShape);
+	// 	}
 }
 
 void SegmentPrivate::hoverEnterEvent(QGraphicsSceneHoverEvent*) {
@@ -136,7 +137,7 @@ void SegmentPrivate::hoverLeaveEvent(QGraphicsSceneHoverEvent*) {
 	}
 }
 
-QVariant SegmentPrivate::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant &value) {
+QVariant SegmentPrivate::itemChange(QGraphicsItem::GraphicsItemChange change, const QVariant& value) {
 	if (change == QGraphicsItem::ItemSelectedChange && value == true) {
 		auto* datapicker = static_cast<Datapicker*>(q->m_image->parentAspect());
 		if (datapicker->activeCurve()) {
@@ -144,20 +145,20 @@ QVariant SegmentPrivate::itemChange(QGraphicsItem::GraphicsItemChange change, co
 			QList<QPointF> posList;
 			posList.clear();
 			for (QLine* line : q->path) {
-				const int l = (line->y1() > line->y2())?line->y2():line->y1();
-				const int h = (line->y1() > line->y2())?line->y1():line->y2();
+				const int l = (line->y1() > line->y2()) ? line->y2() : line->y1();
+				const int h = (line->y1() > line->y2()) ? line->y1() : line->y2();
 
 				for (int i = l; i <= h; ++i) {
-					if (count%q->m_image->pointSeparation() == 0) {
+					if (count % q->m_image->pointSeparation() == 0) {
 						bool positionUsed = false;
 						const auto points = datapicker->activeCurve()->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
 						for (const auto* point : points) {
-							if (point->position() == QPoint(line->x1(), i)*scaleFactor)
+							if (point->position() == QPoint(line->x1(), i) * scaleFactor)
 								positionUsed = true;
 						}
 
 						if (!positionUsed)
-							posList<<QPoint(line->x1(), i)*scaleFactor;
+							posList << QPoint(line->x1(), i) * scaleFactor;
 					}
 					count++;
 				}
@@ -171,7 +172,7 @@ QVariant SegmentPrivate::itemChange(QGraphicsItem::GraphicsItemChange change, co
 			}
 		}
 
-		//no need to keep segment selected
+		// no need to keep segment selected
 		return false;
 	}
 
