@@ -1,19 +1,19 @@
 /*
-    File                 : OriginProjectParser.h
-    Project              : LabPlot
-    Description          : parser for Origin projects
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2018-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : OriginProjectParser.h
+	Project              : LabPlot
+	Description          : parser for Origin projects
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2018-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ORIGINPROJECTPARSER_H
 #define ORIGINPROJECTPARSER_H
 
-#include "backend/datasources/projects/ProjectParser.h"
-#include "backend/worksheet/WorksheetElement.h"
 #include "3rdparty/liborigin/OriginFile.h"
+#include "backend/datasources/projects/ProjectParser.h"
+#include "backend/worksheet/Background.h"
 
 class Axis;
 class Column;
@@ -36,6 +36,9 @@ public:
 	void setImportUnusedObjects(bool);
 	bool hasUnusedObjects();
 
+protected:
+	bool load(Project*, bool) override;
+
 private:
 	bool loadFolder(Folder*, tree<Origin::ProjectNode>::iterator, bool preview);
 	bool loadWorkbook(Workbook*, bool preview);
@@ -43,7 +46,7 @@ private:
 	void loadColumnNumericFormat(const Origin::SpreadColumn& originColumn, Column* column) const;
 	bool loadMatrixWorkbook(Workbook*, bool preview);
 	bool loadMatrix(Matrix*, bool preview, size_t sheetIndex = 0, const QString& mwbName = QString());
-	bool loadWorksheet(Worksheet*,  bool preview);
+	bool loadWorksheet(Worksheet*, bool preview);
 	void loadAxis(const Origin::GraphAxis&, Axis*, int index, const QString& axisTitle = QString()) const;
 	void loadCurve(const Origin::GraphCurve&, XYCurve*) const;
 	bool loadNote(Note*, bool preview);
@@ -58,7 +61,7 @@ private:
 	QString parseOriginTags(const QString&) const;
 	QDateTime creationTime(tree<Origin::ProjectNode>::iterator) const;
 	QColor color(Origin::Color) const;
-	WorksheetElement::BackgroundColorStyle backgroundColorStyle(Origin::ColorGradientDirection) const;
+	Background::ColorStyle backgroundColorStyle(Origin::ColorGradientDirection) const;
 
 	QList<QPair<QString, QString>> charReplacementList() const;
 	QString replaceSpecialChars(const QString&) const;
@@ -72,9 +75,6 @@ private:
 	bool m_importUnusedObjects{false};
 
 	friend class ProjectImportTest;
-
-protected:
-	bool load(Project*, bool) override;
 };
 
 #endif // ORIGINPROJECTPARSER_H
