@@ -1,22 +1,22 @@
 /*
-    File                 : WorksheetElementContainer.cpp
-    Project              : LabPlot
-    Description          : Worksheet element container - parent of multiple elements
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2012-2021 Alexander Semke <alexander.semke@web.de>
+	File                 : WorksheetElementContainer.cpp
+	Project              : LabPlot
+	Description          : Worksheet element container - parent of multiple elements
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2012-2021 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "backend/worksheet/WorksheetElementContainer.h"
-#include "backend/worksheet/WorksheetElementContainerPrivate.h"
-#include "backend/worksheet/ResizeItem.h"
-#include "backend/worksheet/Worksheet.h"
-#include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
 #include "backend/lib/trace.h"
+#include "backend/worksheet/ResizeItem.h"
+#include "backend/worksheet/Worksheet.h"
+#include "backend/worksheet/WorksheetElementContainerPrivate.h"
+#include "backend/worksheet/plots/cartesian/XYCurve.h"
 
 #include <QGraphicsScene>
 #include <QGraphicsSceneContextMenuEvent>
@@ -34,17 +34,17 @@
  */
 
 WorksheetElementContainer::WorksheetElementContainer(const QString& name, AspectType type)
-		: WorksheetElement(name, new WorksheetElementContainerPrivate(this), type) {
+	: WorksheetElement(name, new WorksheetElementContainerPrivate(this), type) {
 	connect(this, &WorksheetElementContainer::aspectAdded, this, &WorksheetElementContainer::handleAspectAdded);
 }
 
 WorksheetElementContainer::WorksheetElementContainer(const QString& name, WorksheetElementContainerPrivate* dd, AspectType type)
-		: WorksheetElement(name, dd, type) {
+	: WorksheetElement(name, dd, type) {
 	connect(this, &WorksheetElementContainer::aspectAdded, this, &WorksheetElementContainer::handleAspectAdded);
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 WorksheetElementContainer::~WorksheetElementContainer() = default;
 
 QGraphicsItem* WorksheetElementContainer::graphicsItem() const {
@@ -60,30 +60,30 @@ STD_SWAP_METHOD_SETTER_CMD_IMPL(WorksheetElementContainer, SetVisible, bool, swa
 void WorksheetElementContainer::setVisible(bool on) {
 	Q_D(WorksheetElementContainer);
 
-	//take care of proper ordering on the undo-stack,
-	//when making the container and all its children visible/invisible.
-	//if visible is set true, change the visibility of the container first
+	// take care of proper ordering on the undo-stack,
+	// when making the container and all its children visible/invisible.
+	// if visible is set true, change the visibility of the container first
 	if (on) {
-		beginMacro( i18n("%1: set visible", name()) );
-		exec( new WorksheetElementContainerSetVisibleCmd(d, on, ki18n("%1: set visible")) );
+		beginMacro(i18n("%1: set visible", name()));
+		exec(new WorksheetElementContainerSetVisibleCmd(d, on, ki18n("%1: set visible")));
 	} else
-		beginMacro( i18n("%1: set invisible", name()) );
+		beginMacro(i18n("%1: set invisible", name()));
 
-	//change the visibility of all children
+	// change the visibility of all children
 	const auto& elements = children<WorksheetElement>(AbstractAspect::ChildIndexFlag::IncludeHidden | AbstractAspect::ChildIndexFlag::Compress);
 	for (auto* elem : elements) {
 		auto* curve = dynamic_cast<XYCurve*>(elem);
 		if (curve) {
-			//making curves invisible triggers the recalculation of plot ranges if auto-scale is active.
-			//this should be avoided by supressing the retransformation in the curves.
-			curve->suppressRetransform(true);
+			// making curves invisible triggers the recalculation of plot ranges if auto-scale is active.
+			// this should be avoided by supressing the retransformation in the curves.
+			curve->setSuppressRetransform(true);
 			elem->setVisible(on);
-			curve->suppressRetransform(false);
+			curve->setSuppressRetransform(false);
 		} else if (elem)
 			elem->setVisible(on);
 	}
 
-	//if visible is set false, change the visibility of the container last
+	// if visible is set false, change the visibility of the container last
 	if (!on)
 		exec(new WorksheetElementContainerSetVisibleCmd(d, false, ki18n("%1: set invisible")));
 
@@ -119,11 +119,10 @@ void WorksheetElementContainer::retransform() {
 	if (isLoading())
 		return;
 
-	PERFTRACE("WorksheetElementContainer::retransform()");
+	PERFTRACE(QStringLiteral("WorksheetElementContainer::retransform()"));
 	Q_D(WorksheetElementContainer);
 
-	const auto& elements = children<WorksheetElement>(AbstractAspect::ChildIndexFlag::IncludeHidden
-													| AbstractAspect::ChildIndexFlag::Compress);
+	const auto& elements = children<WorksheetElement>(AbstractAspect::ChildIndexFlag::IncludeHidden | AbstractAspect::ChildIndexFlag::Compress);
 	for (auto* child : elements)
 		child->retransform();
 
@@ -149,8 +148,8 @@ void WorksheetElementContainer::handleResize(double horizontalRatio, double vert
 		rect.setHeight(d->rect.height() * verticalRatio);
 		setRect(rect);
 	} else {
-// 		for (auto* elem : children<WorksheetElement>(IncludeHidden))
-// 			elem->handleResize(horizontalRatio, verticalRatio);
+		// 		for (auto* elem : children<WorksheetElement>(IncludeHidden))
+		// 			elem->handleResize(horizontalRatio, verticalRatio);
 	}
 }
 
@@ -197,7 +196,9 @@ void WorksheetElementContainer::prepareGeometryChange() {
 //################################################################
 //################### Private implementation ##########################
 //################################################################
-WorksheetElementContainerPrivate::WorksheetElementContainerPrivate(WorksheetElementContainer *owner) : WorksheetElementPrivate(owner), q(owner) {
+WorksheetElementContainerPrivate::WorksheetElementContainerPrivate(WorksheetElementContainer* owner)
+	: WorksheetElementPrivate(owner)
+	, q(owner) {
 	setAcceptHoverEvents(true);
 }
 
@@ -223,31 +224,33 @@ void WorksheetElementContainerPrivate::hoverLeaveEvent(QGraphicsSceneHoverEvent*
 }
 
 void WorksheetElementContainerPrivate::prepareGeometryChangeRequested() {
-	prepareGeometryChange();	// this is not const!
+	prepareGeometryChange(); // this is not const!
 	recalcShapeAndBoundingRect();
 }
 
 void WorksheetElementContainerPrivate::recalcShapeAndBoundingRect() {
-// 	if (q->isLoading())
-// 		return;
+	// 	if (q->isLoading())
+	// 		return;
 
-	//old logic calculating the bounding box as the box covering all children.
-	//we might need this logic later once we implement something like selection of multiple plots, etc.
-// 	boundingRectangle = QRectF();
-// 	QVector<WorksheetElement*> childList = q->children<WorksheetElement>(AbstractAspect::IncludeHidden | AbstractAspect::Compress);
-// 	foreach (const WorksheetElement* elem, childList)
-// 		boundingRectangle |= elem->graphicsItem()->mapRectToParent(elem->graphicsItem()->boundingRect());
-//
+	// old logic calculating the bounding box as the box covering all children.
+	// we might need this logic later once we implement something like selection of multiple plots, etc.
+	// 	boundingRectangle = QRectF();
+	// 	QVector<WorksheetElement*> childList = q->children<WorksheetElement>(AbstractAspect::IncludeHidden | AbstractAspect::Compress);
+	// 	foreach (const WorksheetElement* elem, childList)
+	// 		boundingRectangle |= elem->graphicsItem()->mapRectToParent(elem->graphicsItem()->boundingRect());
+	//
 	qreal penWidth = 2.;
 	boundingRectangle = q->rect();
-	//QDEBUG(Q_FUNC_INFO << ", bound rect = " << boundingRectangle)
-	boundingRectangle = QRectF(-boundingRectangle.width()/2. - penWidth/2., -boundingRectangle.height()/2. - penWidth/2.,
-				  boundingRectangle.width() + penWidth, boundingRectangle.height() + penWidth);
+	// QDEBUG(Q_FUNC_INFO << ", bound rect = " << boundingRectangle)
+	boundingRectangle = QRectF(-boundingRectangle.width() / 2. - penWidth / 2.,
+							   -boundingRectangle.height() / 2. - penWidth / 2.,
+							   boundingRectangle.width() + penWidth,
+							   boundingRectangle.height() + penWidth);
 
 	QPainterPath path;
 	path.addRect(boundingRectangle);
 
-	//make the shape somewhat thicker then the hoveredPen to make the selection/hovering box more visible
+	// make the shape somewhat thicker then the hoveredPen to make the selection/hovering box more visible
 	containerShape = QPainterPath();
 	containerShape.addPath(WorksheetElement::shapeFromPath(path, QPen(QBrush(), penWidth)));
 }
@@ -273,4 +276,5 @@ void WorksheetElementContainerPrivate::paint(QPainter* painter, const QStyleOpti
 	}
 }
 
-void WorksheetElementContainerPrivate::retransform() {}
+void WorksheetElementContainerPrivate::retransform() {
+}
