@@ -1,12 +1,12 @@
 /*
-    File                 : MainWin.h
-    Project              : LabPlot
-    Description          : Main window of the application
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2011-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2008-2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : MainWin.h
+	Project              : LabPlot
+	Description          : Main window of the application
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2011-2023 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2008-2018 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef MAINWIN_H
 #define MAINWIN_H
@@ -28,47 +28,13 @@ class Datapicker;
 class Spreadsheet;
 class Matrix;
 class GuiObserver;
-class AspectDock;
-class AxisDock;
 class CursorDock;
-class InfoElementDock;
-class NoteDock;
-class CartesianPlotDock;
-class HistogramDock;
-class BoxPlotDock;
-class CartesianPlotLegendDock;
-class CustomPointDock;
-class ReferenceLineDock;
-class ColumnDock;
-class LiveDataDock;
-class MatrixDock;
-class ProjectDock;
-class SpreadsheetDock;
-class XYCurveDock;
-class XYEquationCurveDock;
-class XYDataReductionCurveDock;
-class XYDifferentiationCurveDock;
-class XYIntegrationCurveDock;
-class XYInterpolationCurveDock;
-class XYSmoothCurveDock;
-class XYFitCurveDock;
-class XYFourierFilterCurveDock;
-class XYFourierTransformCurveDock;
-class XYHilbertTransformCurveDock;
-class XYConvolutionCurveDock;
-class XYCorrelationCurveDock;
-class WorksheetDock;
-class ImageDock;
-class LabelWidget;
-class DatapickerImageWidget;
-class DatapickerCurveWidget;
 class MemoryWidget;
 class CartesianPlot;
 class InfoElementDialog;
 
 #ifdef HAVE_CANTOR_LIBS
 class CantorWorksheet;
-class CantorWorksheetDock;
 #endif
 
 class ImportDatasetWidget;
@@ -95,7 +61,7 @@ class KToggleFullScreenAction;
 #endif
 
 #ifdef HAVE_TOUCHBAR
-	class KDMacTouchBar;
+class KDMacTouchBar;
 #endif
 
 class MainWin : public KXmlGuiWindow {
@@ -109,12 +75,15 @@ public:
 	AspectTreeModel* model() const;
 	Project* project() const;
 	void addAspectToProject(AbstractAspect*);
+	static void updateLocale();
 
-	enum class LoadOnStart {Nothing, NewProject, NewProjectWorksheet, NewProjectSpreadsheet, LastProject, WelcomeScreen};
-	enum class TitleBarMode {ShowFilePath, ShowFileName, ShowProjectName};
+	enum class LoadOnStart { Nothing, NewProject, NewProjectWorksheet, NewProjectSpreadsheet, LastProject, WelcomeScreen };
+	enum class TitleBarMode { ShowFilePath, ShowFileName, ShowProjectName };
 
 #ifdef HAVE_KUSERFEEDBACK
-	KUserFeedback::Provider& userFeedbackProvider() {return m_userFeedbackProvider;}
+	KUserFeedback::Provider& userFeedbackProvider() {
+		return m_userFeedbackProvider;
+	}
 #endif
 
 private:
@@ -139,7 +108,7 @@ private:
 	MemoryWidget* m_memoryInfoWidget{nullptr};
 	QMdiSubWindow* m_welcomeWindow{nullptr};
 	QQuickWidget* m_welcomeWidget{nullptr};
-// 	WelcomeScreenHelper* m_welcomeScreenHelper{nullptr};
+	// 	WelcomeScreenHelper* m_welcomeScreenHelper{nullptr};
 	ImportDatasetWidget* m_importDatasetWidget{nullptr};
 	QString m_lastOpenFileFilter;
 	const Worksheet* m_lastWorksheet{nullptr};
@@ -147,7 +116,7 @@ private:
 	TitleBarMode m_titleBarMode{TitleBarMode::ShowFilePath};
 
 #ifdef HAVE_KUSERFEEDBACK
-    KUserFeedback::Provider m_userFeedbackProvider;
+	KUserFeedback::Provider m_userFeedbackProvider;
 #endif
 
 #ifdef Q_OS_MAC
@@ -194,77 +163,39 @@ private:
 	QAction* m_prevWindowAction;
 	QAction* m_newDatapickerAction;
 
-	//toggling dock widgets, status bar and full screen
+	// toggling dock widgets, status bar and full screen
 	QAction* m_toggleProjectExplorerDockAction;
 	QAction* m_togglePropertiesDockAction;
 	KToggleAction* m_toggleStatusBarAction;
 	QAction* m_toggleMemoryInfoAction;
 	KToggleFullScreenAction* m_toggleFullScreenAction;
 
-	//window visibility
+	// window visibility
 	QAction* m_visibilityFolderAction;
 	QAction* m_visibilitySubfolderAction;
 	QAction* m_visibilityAllAction;
 
-	//Menus
+	// Menus
 	QMenu* m_visibilityMenu{nullptr};
 	QMenu* m_newMenu{nullptr};
 	QMenu* m_importMenu{nullptr};
 	KHamburgerMenu* m_hamburgerMenu{nullptr};
 
-	//Docks
+	// Docks
 	QStackedWidget* stackedWidget{nullptr};
-	AspectDock* aspectDock{nullptr};
-	AxisDock* axisDock{nullptr};
 	QDockWidget* cursorDock{nullptr};
 	CursorDock* cursorWidget{nullptr};
-	NoteDock* notesDock{nullptr};
-	InfoElementDock* infoElementDock{nullptr};
-	CartesianPlotDock* cartesianPlotDock{nullptr};
-	CartesianPlotLegendDock* cartesianPlotLegendDock{nullptr};
-	ColumnDock* columnDock{nullptr};
-	LiveDataDock* m_liveDataDock{nullptr};
-	MatrixDock* matrixDock{nullptr};
-	SpreadsheetDock* spreadsheetDock{nullptr};
-	ProjectDock* projectDock{nullptr};
-	XYCurveDock* xyCurveDock{nullptr};
-	XYEquationCurveDock* xyEquationCurveDock{nullptr};
-	XYDataReductionCurveDock* xyDataReductionCurveDock{nullptr};
-	XYDifferentiationCurveDock* xyDifferentiationCurveDock{nullptr};
-	XYIntegrationCurveDock* xyIntegrationCurveDock{nullptr};
-	XYInterpolationCurveDock* xyInterpolationCurveDock{nullptr};
-	XYSmoothCurveDock* xySmoothCurveDock{nullptr};
-	XYFitCurveDock* xyFitCurveDock{nullptr};
-	XYFourierFilterCurveDock* xyFourierFilterCurveDock{nullptr};
-	XYFourierTransformCurveDock* xyFourierTransformCurveDock{nullptr};
-	XYHilbertTransformCurveDock* xyHilbertTransformCurveDock{nullptr};
-	XYConvolutionCurveDock* xyConvolutionCurveDock{nullptr};
-	XYCorrelationCurveDock* xyCorrelationCurveDock{nullptr};
-	HistogramDock* histogramDock{nullptr};
-	BoxPlotDock* boxPlotDock{nullptr};
-	WorksheetDock* worksheetDock{nullptr};
-	LabelWidget* textLabelDock{nullptr};
-	ImageDock* imageDock{nullptr};
-	CustomPointDock* customPointDock{nullptr};
-	ReferenceLineDock* referenceLineDock{nullptr};
-	DatapickerImageWidget* datapickerImageDock{nullptr};
-	DatapickerCurveWidget* datapickerCurveDock{nullptr};
 
 	void initActions();
 	void initMenus();
 	bool warnModified();
 	void activateSubWindowForAspect(const AbstractAspect*) const;
 	bool save(const QString&);
-// 	void toggleShowWidget(QWidget* widget, bool showToRight);
-// 	void toggleHideWidget(QWidget* widget, bool hideToLeft);
+	// 	void toggleShowWidget(QWidget* widget, bool showToRight);
+	// 	void toggleHideWidget(QWidget* widget, bool hideToLeft);
 
 	Spreadsheet* activeSpreadsheet() const;
 
-	//Cantor
-#ifdef HAVE_CANTOR_LIBS
-	CantorWorksheetDock* cantorWorksheetDock{nullptr};
-#endif
-
 	friend class GuiObserver;
 	GuiObserver* m_guiObserver{nullptr};
 
@@ -275,8 +206,8 @@ protected:
 
 private Q_SLOTS:
 	void initGUI(const QString&);
-// 	QQuickWidget* createWelcomeScreen();
-// 	void resetWelcomeScreen();
+	// 	QQuickWidget* createWelcomeScreen();
+	// 	void resetWelcomeScreen();
 	void createMdiArea();
 	void updateGUI();
 	void updateGUIOnProjectChanges();
@@ -308,7 +239,7 @@ private Q_SLOTS:
 	void colorSchemeChanged(QAction*);
 	void openDatasetExample();
 
-	//Cantor
+	// Cantor
 #ifdef HAVE_CANTOR_LIBS
 	void newCantorWorksheet(QAction* action);
 	void cantorSettingsDialog();
@@ -321,7 +252,7 @@ private Q_SLOTS:
 	void newWorksheet();
 	void newNotes();
 	void newDatapicker();
-	//TODO: void newScript();
+	// TODO: void newScript();
 	void newLiveDataSource();
 
 	void createContextMenu(QMenu*) const;
@@ -329,7 +260,7 @@ private Q_SLOTS:
 
 	void handleAspectAdded(const AbstractAspect*);
 	void handleAspectAboutToBeRemoved(const AbstractAspect*);
-	void handleAspectRemoved(const AbstractAspect*,const AbstractAspect*,const AbstractAspect*);
+	void handleAspectRemoved(const AbstractAspect*, const AbstractAspect*, const AbstractAspect*);
 	void handleCurrentAspectChanged(AbstractAspect*);
 	void handleCurrentSubWindowChanged(QMdiSubWindow*);
 	void handleShowSubWindowRequested();
