@@ -1,10 +1,10 @@
 /*
-    File                 : DatabaseManagerWidget.cpp
-    Project              : LabPlot
-    Description          : widget for managing database connections
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2017-2018 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : DatabaseManagerWidget.cpp
+	Project              : LabPlot
+	Description          : widget for managing database connections
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017-2018 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "DatabaseManagerWidget.h"
@@ -16,44 +16,45 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
-
-#include <QFileDialog>
-#include <QTimer>
-#include <QSqlDatabase>
-#include <QSqlError>
+#include <kcoreaddons_version.h>
 
 #ifdef HAVE_KF5_SYNTAX_HIGHLIGHTING
-#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Theme>
 #endif
 
+#include <QFileDialog>
+#include <QSqlDatabase>
+#include <QSqlError>
+#include <QTimer>
+
 /*!
    \class DatabaseManagerWidget
    \brief widget for managing database connections, embedded in \c DatabaseManagerDialog.
 
    \ingroup kdefrontend
 */
-DatabaseManagerWidget::DatabaseManagerWidget(QWidget* parent, QString conn) : QWidget(parent),
-	m_configPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).constFirst() +  "sql_connections"),
-	m_initConnName(std::move(conn)) {
-
+DatabaseManagerWidget::DatabaseManagerWidget(QWidget* parent, QString conn)
+	: QWidget(parent)
+	, m_configPath(QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).constFirst() + QStringLiteral("sql_connections"))
+	, m_initConnName(std::move(conn)) {
 	ui.setupUi(this);
 
-	ui.tbAdd->setIcon(QIcon::fromTheme("list-add"));
-	ui.tbDelete->setIcon(QIcon::fromTheme("list-remove"));
-	ui.bOpen->setIcon(QIcon::fromTheme("document-open"));
-	ui.bTestConnection->setIcon(QIcon::fromTheme("network-connect"));
+	ui.tbAdd->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
+	ui.tbDelete->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
+	ui.bOpen->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
+	ui.bTestConnection->setIcon(QIcon::fromTheme(QStringLiteral("network-connect")));
 
 	ui.tbAdd->setToolTip(i18n("Add new database connection"));
 	ui.tbDelete->setToolTip(i18n("Delete selected database connection"));
 	ui.bOpen->setToolTip(i18n("Open database file"));
 	ui.bTestConnection->setToolTip(i18n("Test selected database connection"));
 
-	//add the list of supported SQL drivers
+	// add the list of supported SQL drivers
 	ui.cbDriver->addItems(QSqlDatabase::drivers());
 
-	//SIGNALs/SLOTs
+	// SIGNALs/SLOTs
 	connect(ui.lwConnections, &QListWidget::currentRowChanged, this, &DatabaseManagerWidget::connectionChanged);
 	connect(ui.tbAdd, &QToolButton::clicked, this, &DatabaseManagerWidget::addConnection);
 	connect(ui.tbDelete, &QToolButton::clicked, this, &DatabaseManagerWidget::deleteConnection);
@@ -83,8 +84,7 @@ QString DatabaseManagerWidget::connection() const {
 	shows the settings of the currently selected connection
  */
 void DatabaseManagerWidget::connectionChanged(int index) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (index == -1) {
 		m_current_connection = nullptr;
@@ -92,20 +92,20 @@ void DatabaseManagerWidget::connectionChanged(int index) {
 	}
 
 	m_current_connection = &m_connections[index];
-	//show the settings for the selected connection
+	// show the settings for the selected connection
 	m_initializing = true;
 	const QString& driver = m_current_connection->driver;
 	ui.leName->setText(m_current_connection->name);
 	ui.cbDriver->setCurrentIndex(ui.cbDriver->findText(driver));
 	ui.leDatabase->setText(m_current_connection->dbName);
 
-	//no host and port number required for file DB and ODBC connections
+	// no host and port number required for file DB and ODBC connections
 	if (!isFileDB(driver) || !isODBC(driver)) {
 		ui.leHost->setText(m_current_connection->hostName);
 		ui.sbPort->setValue(m_current_connection->port);
 	}
 
-	//no credentials required for file DB
+	// no credentials required for file DB
 	if (!isFileDB(driver)) {
 		ui.leUserName->setText(m_current_connection->userName);
 		ui.lePassword->setText(m_current_connection->password);
@@ -119,7 +119,7 @@ void DatabaseManagerWidget::connectionChanged(int index) {
 }
 
 void DatabaseManagerWidget::nameChanged(const QString& name) {
-	//check uniqueness of the provided name
+	// check uniqueness of the provided name
 	bool unique = true;
 	for (int i = 0; i < ui.lwConnections->count(); ++i) {
 		if (ui.lwConnections->currentRow() == i)
@@ -146,7 +146,7 @@ void DatabaseManagerWidget::nameChanged(const QString& name) {
 }
 
 void DatabaseManagerWidget::driverChanged() {
-	//hide non-relevant fields (like host name, etc.) for file DBs and ODBC
+	// hide non-relevant fields (like host name, etc.) for file DBs and ODBC
 	const QString& driver = ui.cbDriver->currentText();
 
 	if (isFileDB(driver)) {
@@ -176,13 +176,12 @@ void DatabaseManagerWidget::driverChanged() {
 		ui.teCustomConnection->setVisible(customConnection);
 
 #ifdef HAVE_KF5_SYNTAX_HIGHLIGHTING
-		//syntax highlighting for custom ODBC string
+		// syntax highlighting for custom ODBC string
 		if (!m_highlighter) {
 			m_highlighter = new KSyntaxHighlighting::SyntaxHighlighter(ui.teCustomConnection->document());
-			m_highlighter->setDefinition(m_repository.definitionForName("INI Files"));
-			m_highlighter->setTheme(  (palette().color(QPalette::Base).lightness() < 128)
-										? m_repository.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
-										: m_repository.defaultTheme(KSyntaxHighlighting::Repository::LightTheme) );
+			m_highlighter->setDefinition(m_repository.definitionForName(QStringLiteral("INI Files")));
+			m_highlighter->setTheme(DARKMODE ? m_repository.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+											 : m_repository.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
 		}
 #endif
 	} else {
@@ -200,8 +199,7 @@ void DatabaseManagerWidget::driverChanged() {
 		ui.teCustomConnection->hide();
 	}
 
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_current_connection)
 		m_current_connection->driver = driver;
@@ -209,38 +207,36 @@ void DatabaseManagerWidget::driverChanged() {
 }
 
 void DatabaseManagerWidget::selectFile() {
-	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("DatabaseManagerWidget"));
-	QString dir = conf.readEntry(QLatin1String("LastDir"), "");
+	KConfigGroup conf(KSharedConfig::openConfig(), QStringLiteral("DatabaseManagerWidget"));
+	QString dir = conf.readEntry(QStringLiteral("LastDir"), "");
 	QString path = QFileDialog::getOpenFileName(this, i18nc("@title:window", "Select the Database File"), dir);
 	if (path.isEmpty())
-		return; //cancel was clicked in the file-dialog
+		return; // cancel was clicked in the file-dialog
 
-	int pos = path.lastIndexOf(QLatin1String("/"));
+	int pos = path.lastIndexOf(QLatin1Char('/'));
 	if (pos != -1) {
 		QString newDir = path.left(pos);
 		if (newDir != dir)
-			conf.writeEntry(QLatin1String("LastDir"), newDir);
+			conf.writeEntry(QStringLiteral("LastDir"), newDir);
 	}
 
 	ui.leDatabase->setText(path);
 }
 
 void DatabaseManagerWidget::hostChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_current_connection)
 		m_current_connection->hostName = ui.leHost->text();
 
-	//don't allow to try to connect if no hostname provided
-	ui.bTestConnection->setEnabled( !ui.leHost->text().simplified().isEmpty() );
+	// don't allow to try to connect if no hostname provided
+	ui.bTestConnection->setEnabled(!ui.leHost->text().simplified().isEmpty());
 
 	Q_EMIT changed();
 }
 
 void DatabaseManagerWidget::portChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_current_connection)
 		m_current_connection->port = ui.sbPort->value();
@@ -251,11 +247,11 @@ void DatabaseManagerWidget::databaseNameChanged() {
 	QString dbName{ui.leDatabase->text().simplified()};
 	if (isFileDB(ui.cbDriver->currentText())) {
 #ifdef HAVE_WINDOWS
-		if (!dbName.isEmpty() && dbName.at(1) != QLatin1String(":"))
+		if (!dbName.isEmpty() && dbName.at(1) != QLatin1Char(':'))
 #else
-		if (!dbName.isEmpty() && dbName.at(0) != QLatin1String("/"))
+		if (!dbName.isEmpty() && dbName.at(0) != QLatin1Char('/'))
 #endif
-			dbName = QDir::homePath() + QLatin1String("/") + dbName;
+			dbName = QDir::homePath() + QStringLiteral("/") + dbName;
 
 		if (!dbName.isEmpty()) {
 			bool fileExists = QFile::exists(dbName);
@@ -267,11 +263,10 @@ void DatabaseManagerWidget::databaseNameChanged() {
 		ui.leDatabase->setStyleSheet(QString());
 	}
 
-	//don't allow to try to connect if no database name was provided
+	// don't allow to try to connect if no database name was provided
 	ui.bTestConnection->setEnabled(!dbName.isEmpty());
 
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_current_connection)
 		m_current_connection->dbName = dbName;
@@ -279,9 +274,9 @@ void DatabaseManagerWidget::databaseNameChanged() {
 }
 
 void DatabaseManagerWidget::customConnectionEnabledChanged(bool state) {
-	//in case custom connection string is provided:
-	//disable the line edit for the database name
-	//and hide the textedit for the connection string
+	// in case custom connection string is provided:
+	// disable the line edit for the database name
+	// and hide the textedit for the connection string
 	ui.leDatabase->setEnabled(!state);
 	ui.teCustomConnection->setVisible(state);
 
@@ -302,8 +297,7 @@ void DatabaseManagerWidget::customConnectionChanged() {
 }
 
 void DatabaseManagerWidget::userNameChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_current_connection)
 		m_current_connection->userName = ui.leUserName->text();
@@ -311,8 +305,7 @@ void DatabaseManagerWidget::userNameChanged() {
 }
 
 void DatabaseManagerWidget::passwordChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_current_connection)
 		m_current_connection->password = ui.lePassword->text();
@@ -320,25 +313,25 @@ void DatabaseManagerWidget::passwordChanged() {
 }
 
 void DatabaseManagerWidget::addConnection() {
-	DEBUG("Adding new connection");
+	DEBUG(Q_FUNC_INFO);
 	SQLConnection conn;
 	conn.name = uniqueName();
 	conn.driver = ui.cbDriver->currentText();
-	conn.hostName = QLatin1String("localhost");
+	conn.hostName = QStringLiteral("localhost");
 
 	if (!isFileDB(conn.driver) && !isODBC(conn.driver))
 		conn.port = defaultPort(conn.driver);
 
 	m_connections.append(conn);
 	ui.lwConnections->addItem(conn.name);
-	ui.lwConnections->setCurrentRow(m_connections.size()-1);
+	ui.lwConnections->setCurrentRow(m_connections.size() - 1);
 
 	m_initializing = true;
-	//call this to properly update the widgets for the very first added connection
+	// call this to properly update the widgets for the very first added connection
 	driverChanged();
 	m_initializing = false;
 
-	//we have now more then one connection, enable widgets
+	// we have now more then one connection, enable widgets
 	ui.tbDelete->setEnabled(true);
 	ui.leName->setEnabled(true);
 	ui.leDatabase->setEnabled(true);
@@ -353,13 +346,22 @@ void DatabaseManagerWidget::addConnection() {
 	removes the current selected connection.
  */
 void DatabaseManagerWidget::deleteConnection() {
-	int ret = KMessageBox::questionYesNo(this,
-				i18n("Do you really want to delete the connection '%1'?", ui.lwConnections->currentItem()->text()),
-				i18n("Delete Connection"));
-	if (ret != KMessageBox::Yes)
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	auto status = KMessageBox::questionTwoActions(this,
+												  i18n("Do you really want to delete the connection '%1'?", ui.lwConnections->currentItem()->text()),
+												  i18n("Delete Connection"),
+												  KStandardGuiItem::del(),
+												  KStandardGuiItem::cancel());
+#else
+	auto status = KMessageBox::questionYesNo(this,
+											 i18n("Do you really want to delete the connection '%1'?", ui.lwConnections->currentItem()->text()),
+											 i18n("Delete Connection"));
+#endif
+
+	if (status != KMessageBox::Yes)
 		return;
 
-	//remove the current selected connection
+	// remove the current selected connection
 	int row = ui.lwConnections->currentRow();
 	if (row != -1) {
 		m_connections.removeAt(row);
@@ -368,10 +370,10 @@ void DatabaseManagerWidget::deleteConnection() {
 		m_initializing = false;
 	}
 
-	//show the connection for the item that was automatically selected afte the deletion
+	// show the connection for the item that was automatically selected afte the deletion
 	connectionChanged(ui.lwConnections->currentRow());
 
-	//disable widgets if there're no connections anymore
+	// disable widgets if there're no connections anymore
 	if (m_connections.size() == 0) {
 		m_initializing = true;
 		ui.tbDelete->setEnabled(false);
@@ -406,7 +408,7 @@ void DatabaseManagerWidget::loadConnections() {
 		const KConfigGroup& group = config.group(groupName);
 		SQLConnection conn;
 		conn.name = groupName;
-		conn.driver = group.readEntry("Driver","");
+		conn.driver = group.readEntry("Driver", "");
 		conn.dbName = group.readEntry("DatabaseName", "");
 		if (!isFileDB(conn.driver) && !isODBC(conn.driver)) {
 			conn.hostName = group.readEntry("HostName", "localhost");
@@ -425,37 +427,37 @@ void DatabaseManagerWidget::loadConnections() {
 		ui.lwConnections->addItem(conn.name);
 	}
 
-	//show the first connection if available, create a new connection otherwise
+	// show the first connection if available, create a new connection otherwise
 	if (m_connections.size()) {
 		if (!m_initConnName.isEmpty()) {
 			QListWidgetItem* item = ui.lwConnections->findItems(m_initConnName, Qt::MatchExactly).constFirst();
 			if (item)
 				ui.lwConnections->setCurrentItem(item);
 			else
-				ui.lwConnections->setCurrentRow(ui.lwConnections->count()-1);
+				ui.lwConnections->setCurrentRow(ui.lwConnections->count() - 1);
 		} else {
-			ui.lwConnections->setCurrentRow(ui.lwConnections->count()-1);
+			ui.lwConnections->setCurrentRow(ui.lwConnections->count() - 1);
 		}
 	} else
 		addConnection();
 
-	//show/hide the driver dependent options
+	// show/hide the driver dependent options
 	driverChanged();
 
 	m_initializing = false;
 
-	//show the settings of the current connection
+	// show the settings of the current connection
 	connectionChanged(ui.lwConnections->currentRow());
 }
 
 void DatabaseManagerWidget::saveConnections() {
-	QDEBUG("Saving connections to " + m_configPath);
-	//delete saved connections
+	QDEBUG(QStringLiteral("Saving connections to ") + m_configPath);
+	// delete saved connections
 	KConfig config(m_configPath, KConfig::SimpleConfig);
 	for (const auto& group : config.groupList())
 		config.deleteGroup(group);
 
-	//save connections
+	// save connections
 	for (const auto& conn : m_connections) {
 		KConfigGroup group = config.group(conn.name);
 		group.writeEntry("Driver", conn.driver);
@@ -483,19 +485,18 @@ void DatabaseManagerWidget::testConnection() {
 	if (!m_current_connection)
 		return;
 
-	//don't allow to test the connection for file DBs if the file doesn't exist
+	// don't allow to test the connection for file DBs if the file doesn't exist
 	if (isFileDB(ui.cbDriver->currentText())) {
 		QString fileName{ui.leDatabase->text()};
 #ifdef HAVE_WINDOWS
-		if ( !fileName.isEmpty() && fileName.at(1) != QLatin1String(":"))
+		if (!fileName.isEmpty() && fileName.at(1) != QLatin1Char(':'))
 #else
-		if ( !fileName.isEmpty() && fileName.at(0) != QLatin1String("/"))
+		if (!fileName.isEmpty() && fileName.at(0) != QLatin1Char('/'))
 #endif
-			fileName = QDir::homePath() + QLatin1String("/") + fileName;
+			fileName = QDir::homePath() + QStringLiteral("/") + fileName;
 
 		if (!QFile::exists(fileName)) {
-			KMessageBox::error(this, i18n("Failed to connect to the database '%1'.", m_current_connection->dbName),
-								 i18n("Connection Failed"));
+			KMessageBox::error(this, i18n("Failed to connect to the database '%1'.", m_current_connection->dbName), i18n("Connection Failed"));
 			return;
 		}
 	}
@@ -505,19 +506,19 @@ void DatabaseManagerWidget::testConnection() {
 	QSqlDatabase db = QSqlDatabase::addDatabase(driver);
 	db.close();
 
-	//db name or custom connection string for ODBC, if available
+	// db name or custom connection string for ODBC, if available
 	if (isODBC(driver) && m_current_connection->customConnectionEnabled)
 		db.setDatabaseName(m_current_connection->customConnectionString);
 	else
 		db.setDatabaseName(m_current_connection->dbName);
 
-	//host and port number, if required
+	// host and port number, if required
 	if (!isFileDB(driver) && !isODBC(driver)) {
 		db.setHostName(m_current_connection->hostName);
 		db.setPort(m_current_connection->port);
 	}
 
-	//authentication, if required
+	// authentication, if required
 	if (!isFileDB(driver)) {
 		db.setUserName(m_current_connection->userName);
 		db.setPassword(m_current_connection->password);
@@ -526,13 +527,13 @@ void DatabaseManagerWidget::testConnection() {
 	if (db.isValid() && db.open() && db.isOpen()) {
 		db.close();
 		RESET_CURSOR;
-		KMessageBox::information(this, i18n("Connection to the database '%1' was successful.", m_current_connection->dbName),
-								 i18n("Connection Successful"));
+		KMessageBox::information(this, i18n("Connection to the database '%1' was successful.", m_current_connection->dbName), i18n("Connection Successful"));
 	} else {
 		RESET_CURSOR;
-		KMessageBox::error(this, i18n("Failed to connect to the database '%1'.", m_current_connection->dbName) +
-								 QLatin1String("\n\n") + db.lastError().databaseText(),
-								 i18n("Connection Failed"));
+		KMessageBox::error(this,
+						   i18n("Failed to connect to the database '%1'.", m_current_connection->dbName) + QStringLiteral("\n\n")
+							   + db.lastError().databaseText(),
+						   i18n("Connection Failed"));
 	}
 }
 
@@ -543,19 +544,19 @@ void DatabaseManagerWidget::testConnection() {
  * used to show/hide relevant connection settings widgets.
  */
 bool DatabaseManagerWidget::isFileDB(const QString& driver) {
-	//QSQLITE, QSQLITE3
-	return driver.startsWith(QLatin1String("QSQLITE"));
+	// QSQLITE, QSQLITE3
+	return driver.startsWith(QStringLiteral("QSQLITE"));
 }
 
 bool DatabaseManagerWidget::isODBC(const QString& driver) {
-	//QODBC, QODBC3
-	return driver.startsWith(QLatin1String("QODBC"));
+	// QODBC, QODBC3
+	return driver.startsWith(QStringLiteral("QODBC"));
 }
 
 QString DatabaseManagerWidget::uniqueName() {
 	QString name = i18n("New connection");
 
-	//TODO
+	// TODO
 	QStringList connection_names;
 	for (int row = 0; row < ui.lwConnections->count(); row++)
 		connection_names << ui.lwConnections->item(row)->text();
@@ -565,12 +566,11 @@ QString DatabaseManagerWidget::uniqueName() {
 
 	QString base = name;
 	int last_non_digit;
-	for (last_non_digit = base.size()-1; last_non_digit>=0 &&
-	        base[last_non_digit].category() == QChar::Number_DecimalDigit; --last_non_digit)
+	for (last_non_digit = base.size() - 1; last_non_digit >= 0 && base[last_non_digit].category() == QChar::Number_DecimalDigit; --last_non_digit)
 		base.chop(1);
 
-	if (last_non_digit >=0 && base[last_non_digit].category() != QChar::Separator_Space)
-		base.append(" ");
+	if (last_non_digit >= 0 && base[last_non_digit].category() != QChar::Separator_Space)
+		base.append(QStringLiteral(" "));
 
 	int new_nr = name.rightRef(name.size() - base.size()).toInt();
 	QString new_name;
@@ -589,17 +589,17 @@ int DatabaseManagerWidget::defaultPort(const QString& driver) const {
 	// QODBC    Open Database Connectivity (ODBC) - Microsoft SQL Server and other ODBC-compliant databases
 	// QPSQL    PostgreSQL (versions 7.3 and above)
 
-	if (driver == "QDB2")
+	if (driver == QLatin1String("QDB2"))
 		return 50000;
-	else if (driver == "QIBASE")
+	else if (driver == QLatin1String("QIBASE"))
 		return 3050;
-	else if (driver == "QMYSQL3" || driver == "QMYSQL")
+	else if (driver == QLatin1String("QMYSQL3") || driver == QLatin1String("QMYSQL"))
 		return 3306;
-	else if (driver == "QOCI")
+	else if (driver == QLatin1String("QOCI"))
 		return 1521;
-	else if (driver == "QODBC")
+	else if (driver == QLatin1String("QODBC"))
 		return 1433;
-	else if (driver == "QPSQL")
+	else if (driver == QLatin1String("QPSQL"))
 		return 5432;
 	else
 		return 0;
