@@ -1,26 +1,26 @@
 /*
-    File                 : MQTTConnectionManagerWidget.cpp
-    Project              : LabPlot
-    Description          : widget for managing MQTT connections
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Ferencz Kovacs <kferike98@gmail.com>
-    SPDX-FileCopyrightText: 2018-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : MQTTConnectionManagerWidget.cpp
+	Project              : LabPlot
+	Description          : widget for managing MQTT connections
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Ferencz Kovacs <kferike98@gmail.com>
+	SPDX-FileCopyrightText: 2018-2019 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "MQTTConnectionManagerWidget.h"
-
 #include "backend/lib/macros.h"
 
+#include <QListWidgetItem>
+#include <QTimer>
+#include <QtMqtt>
+
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KSharedConfig>
-
-#include <QTimer>
-#include <QtMqtt>
-#include <QListWidgetItem>
+#include <kcoreaddons_version.h>
 
 /*!
    \class MQTTConnectionManagerWidget
@@ -28,9 +28,9 @@
 
    \ingroup kdefrontend
 */
-MQTTConnectionManagerWidget::MQTTConnectionManagerWidget(QWidget* parent, const QString& conn) : QWidget(parent),
-	m_initConnName(conn) {
-
+MQTTConnectionManagerWidget::MQTTConnectionManagerWidget(QWidget* parent, const QString& conn)
+	: QWidget(parent)
+	, m_initConnName(conn) {
 	ui.setupUi(this);
 
 	m_configPath = QStandardPaths::standardLocations(QStandardPaths::AppDataLocation).constFirst() + QStringLiteral("MQTT_connections");
@@ -42,7 +42,7 @@ MQTTConnectionManagerWidget::MQTTConnectionManagerWidget(QWidget* parent, const
 	ui.bRemove->setToolTip(i18n("Remove selected MQTT connection"));
 	ui.bTest->setIcon(QIcon::fromTheme(QStringLiteral("network-connect")));
 
-	//SIGNALs/SLOTs
+	// SIGNALs/SLOTs
 	connect(ui.leName, &QLineEdit::textChanged, this, &MQTTConnectionManagerWidget::nameChanged);
 	connect(ui.lwConnections, &QListWidget::currentRowChanged, this, &MQTTConnectionManagerWidget::connectionChanged);
 	connect(ui.bAdd, &QPushButton::clicked, this, &MQTTConnectionManagerWidget::addConnection);
@@ -91,8 +91,7 @@ QString MQTTConnectionManagerWidget::connection() const {
  * \param index the index of the new connection
  */
 void MQTTConnectionManagerWidget::connectionChanged(int index) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (index == -1) {
 		m_currentConnection = nullptr;
@@ -102,7 +101,7 @@ void MQTTConnectionManagerWidget::connectionChanged(int index) {
 	m_initializing = true;
 	m_currentConnection = &m_connections[index];
 
-	//show the settings for the selected connection
+	// show the settings for the selected connection
 	ui.leName->setText(m_currentConnection->name);
 	ui.leHost->setText(m_currentConnection->hostName);
 	ui.lePort->setText(QString::number(m_currentConnection->port));
@@ -129,12 +128,12 @@ void MQTTConnectionManagerWidget::connectionChanged(int index) {
  * \brief Called when the name is changed
  * Sets the name for the current connection
  */
-void MQTTConnectionManagerWidget::nameChanged(const QString &name) {
+void MQTTConnectionManagerWidget::nameChanged(const QString& name) {
 	if (name.isEmpty()) {
 		SET_WARNING_STYLE(ui.leName)
 		ui.leHost->setToolTip(i18n("Please set a valid name."));
 	} else {
-		//check uniqueness of the provided name
+		// check uniqueness of the provided name
 		bool unique = true;
 		for (int i = 0; i < ui.lwConnections->count(); ++i) {
 			if (ui.lwConnections->currentRow() == i)
@@ -172,9 +171,9 @@ void MQTTConnectionManagerWidget::hostChanged(const QString& hostName) {
 		ui.leHost->setToolTip(i18n("Please set a valid host name."));
 	} else {
 		m_currentConnection->hostName = hostName;
-		//check uniqueness of the provided host name
+		// check uniqueness of the provided host name
 		bool unique = true;
-		for (auto & c : m_connections) {
+		for (auto& c : m_connections) {
 			if (m_currentConnection == &c)
 				continue;
 
@@ -211,9 +210,9 @@ void MQTTConnectionManagerWidget::portChanged(const QString& portString) {
 		ui.leHost->setToolTip(i18n("Please set a valid port."));
 	} else {
 		m_currentConnection->port = portString.simplified().toInt();
-		//check uniqueness of the provided host name
+		// check uniqueness of the provided host name
 		bool unique = true;
-		for (auto & c : m_connections) {
+		for (auto& c : m_connections) {
 			if (m_currentConnection == &c)
 				continue;
 
@@ -238,7 +237,6 @@ void MQTTConnectionManagerWidget::portChanged(const QString& portString) {
 				Q_EMIT changed();
 		}
 	}
-
 }
 
 /*!
@@ -312,8 +310,7 @@ void MQTTConnectionManagerWidget::idChecked(bool state) {
  * \param state the state of the checkbox
  */
 void MQTTConnectionManagerWidget::retainChecked(bool state) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_currentConnection) {
 		if (state)
@@ -337,8 +334,7 @@ void MQTTConnectionManagerWidget::userNameChanged(const QString& userName) {
 		ui.leUserName->setToolTip(QString());
 	}
 
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_currentConnection)
 		m_currentConnection->userName = userName;
@@ -358,8 +354,7 @@ void MQTTConnectionManagerWidget::passwordChanged(const QString& password) {
 		ui.lePassword->setToolTip(QString());
 	}
 
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_currentConnection)
 		m_currentConnection->password = password;
@@ -379,8 +374,7 @@ void MQTTConnectionManagerWidget::clientIdChanged(const QString& clientID) {
 		ui.leID->setToolTip(QString());
 	}
 
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	if (m_currentConnection)
 		m_currentConnection->clientID = clientID;
@@ -401,7 +395,7 @@ void MQTTConnectionManagerWidget::addConnection() {
 	ui.lwConnections->addItem(conn.hostName);
 	ui.lwConnections->setCurrentRow(m_connections.size() - 1);
 
-	//we have now more than one connection, enable widgets
+	// we have now more than one connection, enable widgets
 	ui.bRemove->setEnabled(true);
 	ui.leHost->setEnabled(true);
 	ui.lePort->setEnabled(true);
@@ -416,22 +410,30 @@ void MQTTConnectionManagerWidget::addConnection() {
 		removes the current selected connection.
  */
 void MQTTConnectionManagerWidget::deleteConnection() {
-	int ret = KMessageBox::questionYesNo(this,
-										 i18n("Do you really want to delete the connection '%1'?", ui.lwConnections->currentItem()->text()),
-										 i18n("Delete Connection"));
-	if (ret != KMessageBox::Yes)
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+	auto status = KMessageBox::questionTwoActions(this,
+												  i18n("Do you really want to delete the connection '%1'?", ui.lwConnections->currentItem()->text()),
+												  i18n("Delete Connection"),
+												  KStandardGuiItem::del(),
+												  KStandardGuiItem::cancel());
+#else
+	auto status = KMessageBox::questionYesNo(this,
+											 i18n("Do you really want to delete the connection '%1'?", ui.lwConnections->currentItem()->text()),
+											 i18n("Delete Connection"));
+#endif
+	if (status != KMessageBox::Yes)
 		return;
 
-	//remove the current selected connection
+	// remove the current selected connection
 	m_connections.removeAt(ui.lwConnections->currentRow());
 	m_initializing = true;
 	delete ui.lwConnections->takeItem(ui.lwConnections->currentRow());
 	m_initializing = false;
 
-	//show the connection for the item that was automatically selected after the deletion
+	// show the connection for the item that was automatically selected after the deletion
 	connectionChanged(ui.lwConnections->currentRow());
 
-	//disable widgets if there are no connections anymore
+	// disable widgets if there are no connections anymore
 	if (!m_currentConnection) {
 		m_initializing = true;
 		ui.leName->clear();
@@ -484,7 +486,7 @@ void MQTTConnectionManagerWidget::loadConnections() {
 		ui.lwConnections->addItem(conn.name);
 	}
 
-	//show the first connection if available, create a new connection otherwise
+	// show the first connection if available, create a new connection otherwise
 	if (!m_connections.empty()) {
 		if (!m_initConnName.isEmpty()) {
 			auto items = ui.lwConnections->findItems(m_initConnName, Qt::MatchExactly);
@@ -501,7 +503,7 @@ void MQTTConnectionManagerWidget::loadConnections() {
 
 	m_initializing = false;
 
-	//show the settings of the current connection
+	// show the settings of the current connection
 	connectionChanged(ui.lwConnections->currentRow());
 }
 
@@ -510,12 +512,12 @@ void MQTTConnectionManagerWidget::loadConnections() {
  */
 void MQTTConnectionManagerWidget::saveConnections() {
 	qDebug() << "Saving connections to " << m_configPath;
-	//delete saved connections
+	// delete saved connections
 	KConfig config(m_configPath, KConfig::SimpleConfig);
 	for (const auto& group : config.groupList())
 		config.deleteGroup(group);
 
-	//save connections
+	// save connections
 	for (const auto& conn : m_connections) {
 		KConfigGroup group = config.group(conn.name);
 		group.writeEntry("Host", conn.hostName);
@@ -541,7 +543,7 @@ bool MQTTConnectionManagerWidget::checkConnections() {
 	bool connectionsOk = true;
 
 	for (int i = 0; i < m_connections.size(); ++i) {
-		auto & c1 = m_connections[i];
+		auto& c1 = m_connections[i];
 		QList<QListWidgetItem*> equalNames = ui.lwConnections->findItems(c1.name, Qt::MatchExactly);
 		bool nameOK = (!c1.name.isEmpty()) && (equalNames.size() == 1);
 
@@ -556,7 +558,7 @@ bool MQTTConnectionManagerWidget::checkConnections() {
 		for (int j = 0; j < m_connections.size(); ++j) {
 			if (i == j)
 				continue;
-			auto & c2 = m_connections[j];
+			auto& c2 = m_connections[j];
 
 			if (c2.hostName == c1.hostName && c2.port == c1.port) {
 				uniqueHost = false;
@@ -591,12 +593,11 @@ QString MQTTConnectionManagerWidget::uniqueName() {
 
 	QString base = name;
 	int lastNonDigit;
-	for (lastNonDigit = base.size()-1; lastNonDigit >= 0 &&
-		 base[lastNonDigit].category() == QChar::Number_DecimalDigit; --lastNonDigit)
+	for (lastNonDigit = base.size() - 1; lastNonDigit >= 0 && base[lastNonDigit].category() == QChar::Number_DecimalDigit; --lastNonDigit)
 		base.chop(1);
 
-	if (lastNonDigit >=0 && base[lastNonDigit].category() != QChar::Separator_Space)
-		base.append(' ');
+	if (lastNonDigit >= 0 && base[lastNonDigit].category() != QChar::Separator_Space)
+		base.append(QLatin1Char(' '));
 
 	int newNr = name.rightRef(name.size() - base.size()).toInt();
 	QString newName;
@@ -649,9 +650,9 @@ void MQTTConnectionManagerWidget::onConnect() {
 	RESET_CURSOR;
 	m_testTimer->stop();
 
-	KMessageBox::information(this, i18n("Connection to the broker '%1:%2' was successful.",
-	                               m_currentConnection->hostName, m_currentConnection->port),
-	                         i18n("Connection Successful"));
+	KMessageBox::information(this,
+							 i18n("Connection to the broker '%1:%2' was successful.", m_currentConnection->hostName, m_currentConnection->port),
+							 i18n("Connection Successful"));
 
 	m_client->disconnectFromHost();
 }
@@ -663,9 +664,9 @@ void MQTTConnectionManagerWidget::testTimeout() {
 	RESET_CURSOR;
 	m_testTimer->stop();
 
-	KMessageBox::error(this, i18n("Failed to connect to the broker '%1:%2'.",
-	                         m_currentConnection->hostName, m_currentConnection->port),
-	                   i18n("Connection Failed"));
+	KMessageBox::error(this,
+					   i18n("Failed to connect to the broker '%1:%2'.", m_currentConnection->hostName, m_currentConnection->port),
+					   i18n("Connection Failed"));
 
 	m_client->disconnectFromHost();
 }
@@ -676,9 +677,10 @@ void MQTTConnectionManagerWidget::testTimeout() {
 void MQTTConnectionManagerWidget::onDisconnect() {
 	RESET_CURSOR;
 	if (m_testTimer->isActive()) {
-		KMessageBox::error(this, i18n("Disconnected from the broker '%1:%2' before the connection was successful.",
-		                         m_currentConnection->hostName, m_currentConnection->port),
-		                   i18n("Connection Failed"));
+		KMessageBox::error(
+			this,
+			i18n("Disconnected from the broker '%1:%2' before the connection was successful.", m_currentConnection->hostName, m_currentConnection->port),
+			i18n("Connection Failed"));
 		m_testTimer->stop();
 	}
 }
