@@ -1,33 +1,34 @@
 /*
-    File                 : SpreadsheetDock.cpp
-    Project              : LabPlot
-    Description          : widget for spreadsheet properties
+	File                 : SpreadsheetDock.cpp
+	Project              : LabPlot
+	Description          : widget for spreadsheet properties
 	--------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2010-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2012-2013 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+	SPDX-FileCopyrightText: 2010-2019 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2012-2013 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "SpreadsheetDock.h"
-#include "commonfrontend/spreadsheet/SpreadsheetView.h"
 #include "backend/datapicker/DatapickerCurve.h"
 #include "backend/spreadsheet/Spreadsheet.h"
+#include "commonfrontend/spreadsheet/SpreadsheetView.h"
 #include "kdefrontend/TemplateHandler.h"
 
-#include <QDir>
-#include <KLocalizedString>
-#include <KConfigGroup>
 #include <KConfig>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <QDir>
 
- /*!
-  \class SpreadsheetDock
-  \brief Provides a widget for editing the properties of the spreadsheets currently selected in the project explorer.
+/*!
+ \class SpreadsheetDock
+ \brief Provides a widget for editing the properties of the spreadsheets currently selected in the project explorer.
 
-  \ingroup kdefrontend
+ \ingroup kdefrontend
 */
 
-SpreadsheetDock::SpreadsheetDock(QWidget* parent) : BaseDock(parent) {
+SpreadsheetDock::SpreadsheetDock(QWidget* parent)
+	: BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
 	m_teComment = ui.teComment;
@@ -51,13 +52,12 @@ SpreadsheetDock::SpreadsheetDock(QWidget* parent) : BaseDock(parent) {
 	set the current spreadsheet(s)
 */
 void SpreadsheetDock::setSpreadsheets(QList<Spreadsheet*> list) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	m_spreadsheetList = list;
 	m_spreadsheet = list.first();
-	m_aspect = list.first();
+	setAspects(list);
 
-
-	//check whether we have non-editable columns:
+	// check whether we have non-editable columns:
 	bool nonEditable = false;
 	for (auto* s : m_spreadsheetList) {
 		if (dynamic_cast<DatapickerCurve*>(s->parentAspect())) {
@@ -73,24 +73,24 @@ void SpreadsheetDock::setSpreadsheets(QList<Spreadsheet*> list) {
 		ui.leName->setText(m_spreadsheet->name());
 		ui.teComment->setText(m_spreadsheet->comment());
 	} else {
-		//disable the fields "Name" and "Comment" if there are more then one spreadsheet
+		// disable the fields "Name" and "Comment" if there are more then one spreadsheet
 		ui.leName->setEnabled(false);
 		ui.teComment->setEnabled(false);
 
 		ui.leName->setText(QString());
 		ui.teComment->setText(QString());
 	}
-	ui.leName->setStyleSheet("");
-	ui.leName->setToolTip("");
+	ui.leName->setStyleSheet(QString());
+	ui.leName->setToolTip(QString());
 
-	//show the properties of the first Spreadsheet in the list
+	// show the properties of the first Spreadsheet in the list
 	this->load();
 
 	// undo functions
 	connect(m_spreadsheet, &AbstractAspect::aspectDescriptionChanged, this, &SpreadsheetDock::aspectDescriptionChanged);
 	connect(m_spreadsheet, &Spreadsheet::rowCountChanged, this, &SpreadsheetDock::spreadsheetRowCountChanged);
 	connect(m_spreadsheet, &Spreadsheet::columnCountChanged, this, &SpreadsheetDock::spreadsheetColumnCountChanged);
-	//TODO: show comments
+	// TODO: show comments
 
 	ui.lDimensions->setVisible(!nonEditable);
 	ui.lRowCount->setVisible(!nonEditable);
@@ -100,24 +100,20 @@ void SpreadsheetDock::setSpreadsheets(QList<Spreadsheet*> list) {
 	ui.lFormat->setVisible(!nonEditable);
 	ui.lShowComments->setVisible(!nonEditable);
 	ui.cbShowComments->setVisible(!nonEditable);
-
-	m_initializing = false;
 }
 
 //*************************************************************
 //****** SLOTs for changes triggered in SpreadsheetDock *******
 //*************************************************************
 void SpreadsheetDock::rowCountChanged(int rows) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* spreadsheet : m_spreadsheetList)
 		spreadsheet->setRowCount(rows);
 }
 
 void SpreadsheetDock::columnCountChanged(int columns) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* spreadsheet : m_spreadsheetList)
 		spreadsheet->setColumnCount(columns);
@@ -127,8 +123,7 @@ void SpreadsheetDock::columnCountChanged(int columns) {
   enable/disable the comment header in the views of the selected spreadsheets.
 */
 void SpreadsheetDock::commentsShownChanged(bool state) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* spreadsheet : m_spreadsheetList)
 		static_cast<SpreadsheetView*>(spreadsheet->view())->showComments(state);
@@ -138,21 +133,18 @@ void SpreadsheetDock::commentsShownChanged(bool state) {
 //******** SLOTs for changes triggered in Spreadsheet *********
 //*************************************************************
 void SpreadsheetDock::spreadsheetRowCountChanged(int count) {
-	m_initializing = true;
-  	ui.sbRowCount->setValue(count);
-	m_initializing = false;
+	CONDITIONAL_LOCK_RETURN;
+	ui.sbRowCount->setValue(count);
 }
 
 void SpreadsheetDock::spreadsheetColumnCountChanged(int count) {
-	m_initializing = true;
-  	ui.sbColumnCount->setValue(count);
-	m_initializing = false;
+	CONDITIONAL_LOCK_RETURN;
+	ui.sbColumnCount->setValue(count);
 }
 
 void SpreadsheetDock::spreadsheetShowCommentsChanged(bool checked) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	ui.cbShowComments->setChecked(checked);
-	m_initializing = false;
 }
 
 //*************************************************************
@@ -167,9 +159,9 @@ void SpreadsheetDock::load() {
 }
 
 void SpreadsheetDock::loadConfigFromTemplate(KConfig& config) {
-	//extract the name of the template from the file name
+	// extract the name of the template from the file name
 	QString name;
-	const int index = config.name().lastIndexOf(QLatin1String("/"));
+	const int index = config.name().lastIndexOf(QLatin1Char('/'));
 	if (index != -1)
 		name = config.name().right(config.name().size() - index - 1);
 	else
@@ -190,7 +182,7 @@ void SpreadsheetDock::loadConfigFromTemplate(KConfig& config) {
 	loads saved spreadsheet properties from \c config.
  */
 void SpreadsheetDock::loadConfig(KConfig& config) {
-	KConfigGroup group = config.group( "Spreadsheet" );
+	KConfigGroup group = config.group("Spreadsheet");
 
 	ui.sbColumnCount->setValue(group.readEntry("ColumnCount", m_spreadsheet->columnCount()));
 	ui.sbRowCount->setValue(group.readEntry("RowCount", m_spreadsheet->rowCount()));
@@ -203,9 +195,9 @@ void SpreadsheetDock::loadConfig(KConfig& config) {
 	saves spreadsheet properties to \c config.
  */
 void SpreadsheetDock::saveConfigAsTemplate(KConfig& config) {
-	KConfigGroup group = config.group( "Spreadsheet" );
+	KConfigGroup group = config.group("Spreadsheet");
 	group.writeEntry("ColumnCount", ui.sbColumnCount->value());
 	group.writeEntry("RowCount", ui.sbRowCount->value());
-	group.writeEntry("ShowComments",ui.cbShowComments->isChecked());
+	group.writeEntry("ShowComments", ui.cbShowComments->isChecked());
 	config.sync();
 }
