@@ -1,36 +1,18 @@
-/***************************************************************************
-    File             : XYEquationCurveDock.cpp
-    Project          : LabPlot
-    --------------------------------------------------------------------
-    Copyright        : (C) 2014-2021 Alexander Semke (alexander.semke@web.de)
-    Description      : widget for editing properties of equation curves
+/*
+	File             : XYEquationCurveDock.cpp
+	Project          : LabPlot
+	Description      : widget for editing properties of equation curves
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014-2021 Alexander Semke <alexander.semke@web.de>
 
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+	SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "XYEquationCurveDock.h"
 #include "backend/core/AspectTreeModel.h"
 #include "backend/core/Project.h"
-#include "backend/worksheet/plots/cartesian/XYEquationCurve.h"
 #include "backend/gsl/ExpressionParser.h"
+#include "backend/worksheet/plots/cartesian/XYEquationCurve.h"
 #include "kdefrontend/widgets/ConstantsWidget.h"
 #include "kdefrontend/widgets/FunctionsWidget.h"
 
@@ -55,8 +37,9 @@
   \ingroup kdefrontend
 */
 
-XYEquationCurveDock::XYEquationCurveDock(QWidget *parent): XYCurveDock(parent) {
-	//remove the tab "Error bars"
+XYEquationCurveDock::XYEquationCurveDock(QWidget* parent)
+	: XYCurveDock(parent) {
+	// remove the tab "Error bars"
 	ui.tabWidget->removeTab(5);
 }
 
@@ -64,10 +47,11 @@ XYEquationCurveDock::XYEquationCurveDock(QWidget *parent): XYCurveDock(parent) {
  * 	// Tab "General"
  */
 void XYEquationCurveDock::setupGeneral() {
-	QWidget* generalTab = new QWidget(ui.tabGeneral);
+	auto* generalTab = new QWidget(ui.tabGeneral);
 	uiGeneralTab.setupUi(generalTab);
 	m_leName = uiGeneralTab.leName;
-	m_leComment = uiGeneralTab.leComment;
+	m_teComment = uiGeneralTab.teComment;
+	m_teComment->setFixedHeight(1.2 * m_leName->height());
 
 	auto* gridLayout = dynamic_cast<QGridLayout*>(generalTab->layout());
 	if (gridLayout) {
@@ -80,31 +64,30 @@ void XYEquationCurveDock::setupGeneral() {
 	layout->setMargin(0);
 	layout->addWidget(generalTab);
 
-	uiGeneralTab.tbConstants1->setIcon( QIcon::fromTheme("labplot-format-text-symbol") );
-	uiGeneralTab.tbFunctions1->setIcon( QIcon::fromTheme("preferences-desktop-font") );
+	uiGeneralTab.tbConstants1->setIcon(QIcon::fromTheme(QStringLiteral("labplot-format-text-symbol")));
+	uiGeneralTab.tbFunctions1->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-font")));
 
-	uiGeneralTab.tbConstants2->setIcon( QIcon::fromTheme("labplot-format-text-symbol") );
-	uiGeneralTab.tbFunctions2->setIcon( QIcon::fromTheme("preferences-desktop-font") );
+	uiGeneralTab.tbConstants2->setIcon(QIcon::fromTheme(QStringLiteral("labplot-format-text-symbol")));
+	uiGeneralTab.tbFunctions2->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-font")));
 
 	uiGeneralTab.cbType->addItem(i18n("Cartesian"));
 	uiGeneralTab.cbType->addItem(i18n("Polar"));
 	uiGeneralTab.cbType->addItem(i18n("Parametric"));
-// 	uiGeneralTab.cbType->addItem(i18n("Implicit"));
+	// 	uiGeneralTab.cbType->addItem(i18n("Implicit"));
 
-	uiGeneralTab.pbRecalculate->setIcon(QIcon::fromTheme("run-build"));
+	uiGeneralTab.pbRecalculate->setIcon(QIcon::fromTheme(QStringLiteral("run-build")));
 
 	uiGeneralTab.teEquation2->setExpressionType(XYEquationCurve::EquationType::Parametric);
 
-// 	uiGeneralTab.teEquation1->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
-// 	uiGeneralTab.teEquation2->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
+	// 	uiGeneralTab.teEquation1->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
+	// 	uiGeneralTab.teEquation2->setMaximumHeight(uiGeneralTab.leName->sizeHint().height()*2);
 	uiGeneralTab.teMin->setMaximumHeight(uiGeneralTab.leName->sizeHint().height());
 	uiGeneralTab.teMax->setMaximumHeight(uiGeneralTab.leName->sizeHint().height());
 
-	//Slots
+	// Slots
 	connect(uiGeneralTab.leName, &QLineEdit::textChanged, this, &XYEquationCurveDock::nameChanged);
-	connect(uiGeneralTab.leComment, &QLineEdit::textChanged, this, &XYEquationCurveDock::commentChanged);
+	connect(uiGeneralTab.teComment, &QTextEdit::textChanged, this, &XYEquationCurveDock::commentChanged);
 	connect(uiGeneralTab.chkVisible, &QCheckBox::clicked, this, &XYEquationCurveDock::visibilityChanged);
-
 	connect(uiGeneralTab.cbType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &XYEquationCurveDock::typeChanged);
 	connect(uiGeneralTab.teEquation1, &ExpressionTextEdit::expressionChanged, this, &XYEquationCurveDock::enableRecalculate);
 	connect(uiGeneralTab.teEquation2, &ExpressionTextEdit::expressionChanged, this, &XYEquationCurveDock::enableRecalculate);
@@ -116,48 +99,31 @@ void XYEquationCurveDock::setupGeneral() {
 	connect(uiGeneralTab.teMax, &ExpressionTextEdit::expressionChanged, this, &XYEquationCurveDock::enableRecalculate);
 	connect(uiGeneralTab.sbCount, QOverload<int>::of(&QSpinBox::valueChanged), this, &XYEquationCurveDock::enableRecalculate);
 	connect(uiGeneralTab.pbRecalculate, &QPushButton::clicked, this, &XYEquationCurveDock::recalculateClicked);
-}
-
-/*!
-  sets the curves. The properties of the curves in the list \c list can be edited in this widget.
-*/
-void XYEquationCurveDock::setCurves(QList<XYCurve*> list) {
-	m_initializing = true;
-	m_curvesList = list;
-	m_curve = list.first();
-	m_aspect = list.first();
-	m_equationCurve = dynamic_cast<XYEquationCurve*>(m_curve);
-	Q_ASSERT(m_equationCurve);
-	m_aspectTreeModel =  new AspectTreeModel(m_curve->project());
-	XYCurveDock::setModel();
-	initGeneralTab();
-	initTabs();
-	uiGeneralTab.pbRecalculate->setEnabled(false);
-	m_initializing = false;
+	connect(uiGeneralTab.cbPlotRanges, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &XYEquationCurveDock::plotRangeChanged);
 }
 
 void XYEquationCurveDock::initGeneralTab() {
-	//if there are more then one curve in the list, disable the tab "general"
+	// if there are more then one curve in the list, disable the tab "general"
 	if (m_curvesList.size() == 1) {
 		uiGeneralTab.lName->setEnabled(true);
 		uiGeneralTab.leName->setEnabled(true);
 		uiGeneralTab.lComment->setEnabled(true);
-		uiGeneralTab.leComment->setEnabled(true);
+		uiGeneralTab.teComment->setEnabled(true);
 
 		uiGeneralTab.leName->setText(m_curve->name());
-		uiGeneralTab.leComment->setText(m_curve->comment());
+		uiGeneralTab.teComment->setText(m_curve->comment());
 	} else {
 		uiGeneralTab.lName->setEnabled(false);
 		uiGeneralTab.leName->setEnabled(false);
 		uiGeneralTab.lComment->setEnabled(false);
-		uiGeneralTab.leComment->setEnabled(false);
+		uiGeneralTab.teComment->setEnabled(false);
 
 		uiGeneralTab.leName->setText(QString());
-		uiGeneralTab.leComment->setText(QString());
+		uiGeneralTab.teComment->setText(QString());
 	}
 
-	//show the properties of the first curve
-	const auto* equationCurve = dynamic_cast<const XYEquationCurve*>(m_curve);
+	// show the properties of the first curve
+	const auto* equationCurve = static_cast<const XYEquationCurve*>(m_curve);
 	Q_ASSERT(equationCurve);
 	const XYEquationCurve::EquationData& data = equationCurve->equationData();
 	uiGeneralTab.cbType->setCurrentIndex(static_cast<int>(data.type));
@@ -168,13 +134,37 @@ void XYEquationCurveDock::initGeneralTab() {
 	uiGeneralTab.teMax->setText(data.max);
 	uiGeneralTab.sbCount->setValue(data.count);
 
-	uiGeneralTab.chkVisible->setChecked( m_curve->isVisible() );
+	uiGeneralTab.chkVisible->setChecked(m_curve->isVisible());
 
-	//Slots
-	connect(m_equationCurve, &XYEquationCurve::aspectDescriptionChanged,
-			this, &XYEquationCurveDock::curveDescriptionChanged);
-	connect(m_equationCurve, &XYEquationCurve::equationDataChanged,
-			this, &XYEquationCurveDock::curveEquationDataChanged);
+	// Slots
+	connect(m_equationCurve, &XYEquationCurve::aspectDescriptionChanged, this, &XYEquationCurveDock::aspectDescriptionChanged);
+	connect(m_equationCurve, &XYEquationCurve::equationDataChanged, this, &XYEquationCurveDock::curveEquationDataChanged);
+	connect(m_equationCurve, &WorksheetElement::plotRangeListChanged, this, &XYEquationCurveDock::updatePlotRanges);
+}
+
+/*!
+  sets the curves. The properties of the curves in the list \c list can be edited in this widget.
+*/
+void XYEquationCurveDock::setCurves(QList<XYCurve*> list) {
+	CONDITIONAL_LOCK_RETURN;
+	m_curvesList = list;
+	m_curve = list.first();
+	setAspects(list);
+	m_equationCurve = static_cast<XYEquationCurve*>(m_curve);
+	Q_ASSERT(m_equationCurve);
+	m_aspectTreeModel = new AspectTreeModel(m_curve->project());
+	XYCurveDock::setModel();
+	initGeneralTab();
+	initTabs();
+	setSymbols(list);
+
+	updatePlotRanges();
+
+	uiGeneralTab.pbRecalculate->setEnabled(false);
+}
+
+void XYEquationCurveDock::updatePlotRanges() {
+	updatePlotRangeList(uiGeneralTab.cbPlotRanges);
 }
 
 //*************************************************************
@@ -183,7 +173,7 @@ void XYEquationCurveDock::initGeneralTab() {
 void XYEquationCurveDock::typeChanged(int index) {
 	const auto type{XYEquationCurve::EquationType(index)};
 	if (type == XYEquationCurve::EquationType::Cartesian) {
-		uiGeneralTab.lEquation1->setText("y=f(x)");
+		uiGeneralTab.lEquation1->setText(QStringLiteral("y=f(x)"));
 		uiGeneralTab.lEquation2->hide();
 		uiGeneralTab.teEquation2->hide();
 		uiGeneralTab.tbFunctions2->hide();
@@ -207,8 +197,8 @@ void XYEquationCurveDock::typeChanged(int index) {
 		uiGeneralTab.lMin->setText(i18n("φ, min"));
 		uiGeneralTab.lMax->setText(i18n("φ, max"));
 	} else if (type == XYEquationCurve::EquationType::Parametric) {
-		uiGeneralTab.lEquation1->setText("x=f(t)");
-		uiGeneralTab.lEquation2->setText("y=f(t)");
+		uiGeneralTab.lEquation1->setText(QStringLiteral("x=f(t)"));
+		uiGeneralTab.lEquation2->setText(QStringLiteral("y=f(t)"));
 		uiGeneralTab.lEquation2->show();
 		uiGeneralTab.teEquation2->show();
 		uiGeneralTab.tbFunctions2->show();
@@ -220,7 +210,7 @@ void XYEquationCurveDock::typeChanged(int index) {
 		uiGeneralTab.lMin->setText(i18n("t, min"));
 		uiGeneralTab.lMax->setText(i18n("t, max"));
 	} else if (type == XYEquationCurve::EquationType::Implicit) {
-		uiGeneralTab.lEquation1->setText("f(x,y)");
+		uiGeneralTab.lEquation1->setText(QStringLiteral("f(x,y)"));
 		uiGeneralTab.lEquation2->hide();
 		uiGeneralTab.teEquation2->hide();
 		uiGeneralTab.tbFunctions2->hide();
@@ -248,6 +238,7 @@ void XYEquationCurveDock::recalculateClicked() {
 		static_cast<XYEquationCurve*>(curve)->setEquationData(data);
 
 	uiGeneralTab.pbRecalculate->setEnabled(false);
+	updatePlotRanges(); // axes range may change when range on auto scale
 }
 
 void XYEquationCurveDock::showConstants() {
@@ -267,10 +258,10 @@ void XYEquationCurveDock::showConstants() {
 	menu.addAction(widgetAction);
 
 	if (QObject::sender() == uiGeneralTab.tbConstants1) {
-		QPoint pos(-menu.sizeHint().width()+uiGeneralTab.tbConstants1->width(),-menu.sizeHint().height());
+		QPoint pos(-menu.sizeHint().width() + uiGeneralTab.tbConstants1->width(), -menu.sizeHint().height());
 		menu.exec(uiGeneralTab.tbConstants1->mapToGlobal(pos));
 	} else {
-		QPoint pos(-menu.sizeHint().width()+uiGeneralTab.tbConstants2->width(),-menu.sizeHint().height());
+		QPoint pos(-menu.sizeHint().width() + uiGeneralTab.tbConstants2->width(), -menu.sizeHint().height());
 		menu.exec(uiGeneralTab.tbConstants2->mapToGlobal(pos));
 	}
 }
@@ -291,10 +282,10 @@ void XYEquationCurveDock::showFunctions() {
 	menu.addAction(widgetAction);
 
 	if (QObject::sender() == uiGeneralTab.tbFunctions1) {
-		QPoint pos(-menu.sizeHint().width()+uiGeneralTab.tbFunctions1->width(),-menu.sizeHint().height());
+		QPoint pos(-menu.sizeHint().width() + uiGeneralTab.tbFunctions1->width(), -menu.sizeHint().height());
 		menu.exec(uiGeneralTab.tbFunctions1->mapToGlobal(pos));
 	} else {
-		QPoint pos(-menu.sizeHint().width()+uiGeneralTab.tbFunctions2->width(),-menu.sizeHint().height());
+		QPoint pos(-menu.sizeHint().width() + uiGeneralTab.tbFunctions2->width(), -menu.sizeHint().height());
 		menu.exec(uiGeneralTab.tbFunctions2->mapToGlobal(pos));
 	}
 }
@@ -317,11 +308,10 @@ void XYEquationCurveDock::insertConstant2(const QString& constantsName) {
 	uiGeneralTab.teEquation2->insertPlainText(constantsName);
 }
 
-void XYEquationCurveDock::enableRecalculate() const {
-	if (m_initializing)
-		return;
+void XYEquationCurveDock::enableRecalculate() {
+	CONDITIONAL_RETURN_NO_LOCK;
 
-	//check whether the formular expressions are correct
+	// check whether the formula expressions are correct
 	bool valid = false;
 	const auto type = XYEquationCurve::EquationType(uiGeneralTab.cbType->currentIndex());
 	if (type != XYEquationCurve::EquationType::Parametric)
@@ -331,25 +321,16 @@ void XYEquationCurveDock::enableRecalculate() const {
 
 	valid = (valid && uiGeneralTab.teMin->isValid() && uiGeneralTab.teMax->isValid());
 	uiGeneralTab.pbRecalculate->setEnabled(valid);
+
+	updatePlotRanges();
 }
 
 //*************************************************************
 //*********** SLOTs for changes triggered in XYCurve **********
 //*************************************************************
-//General-Tab
-void XYEquationCurveDock::curveDescriptionChanged(const AbstractAspect* aspect) {
-	if (m_curve != aspect)
-		return;
-
-	const Lock lock(m_initializing);
-	if (aspect->name() != uiGeneralTab.leName->text())
-		uiGeneralTab.leName->setText(aspect->name());
-	else if (aspect->comment() != uiGeneralTab.leComment->text())
-		uiGeneralTab.leComment->setText(aspect->comment());
-}
-
+// General-Tab
 void XYEquationCurveDock::curveEquationDataChanged(const XYEquationCurve::EquationData& data) {
-	const Lock lock(m_initializing);
+	CONDITIONAL_LOCK_RETURN;
 	uiGeneralTab.cbType->setCurrentIndex(static_cast<int>(data.type));
 	uiGeneralTab.teEquation1->setText(data.expression1);
 	uiGeneralTab.teEquation2->setText(data.expression2);
