@@ -1,13 +1,12 @@
 /*
-    File                 : ExportSpreadsheetDialog.h
-    Project              : LabPlot
-    Description          : export spreadsheet dialog
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2014-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ExportSpreadsheetDialog.h
+	Project              : LabPlot
+	Description          : export spreadsheet dialog
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef EXPORTSPREADSHEETDIALOG_H
 #define EXPORTSPREADSHEETDIALOG_H
 
@@ -15,7 +14,7 @@
 #include <QLocale>
 
 namespace Ui {
-	class ExportSpreadsheetWidget;
+class ExportSpreadsheetWidget;
 }
 
 class QPushButton;
@@ -29,6 +28,7 @@ public:
 	~ExportSpreadsheetDialog() override;
 
 	QString path() const;
+	void setProjectFileName(const QString&);
 	void setFileName(const QString&);
 	void setMatrixMode(bool);
 	void setExportSelection(bool);
@@ -48,19 +48,16 @@ public:
 	void setExportTo(const QStringList& to);
 	void setExportToImage(bool possible);
 
-	enum class Format {
-		ASCII,
-		LaTeX,
-		FITS,
-		SQLite
-	};
+	enum class Format { ASCII, LaTeX, FITS, Excel, SQLite };
 
 	Format format() const;
+
 private:
 	Ui::ExportSpreadsheetWidget* ui;
 	bool m_showOptions{true};
 	bool m_matrixMode{false};
 	Format m_format{Format::ASCII};
+	QString m_projectPath;
 
 	QPushButton* m_showOptionsButton;
 	QPushButton* m_okButton;
