@@ -1,24 +1,29 @@
 /*
-    File                 : DatapickerImageWidget.cpp
-    Project              : LabPlot
-    Description          : widget for datapicker properties
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015-2016 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+	File                 : DatapickerImageWidget.cpp
+	Project              : LabPlot
+	Description          : widget for datapicker properties
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015-2016 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "DatapickerImageWidget.h"
 #include "backend/datapicker/DatapickerPoint.h"
-#include "commonfrontend/widgets/qxtspanslider.h"
 #include "backend/datapicker/ImageEditor.h"
+#include "commonfrontend/widgets/qxtspanslider.h"
 #include "kdefrontend/GuiTools.h"
 #include "kdefrontend/widgets/SymbolWidget.h"
 
 #include <QCompleter>
 #include <QDir>
+// see https://gitlab.kitware.com/cmake/cmake/-/issues/21609
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+#include <QFileSystemModel>
+#else
 #include <QDirModel>
+#endif
 #include <QGraphicsScene>
 #include <QPainter>
 
@@ -28,12 +33,12 @@
 
 #include <cmath>
 
-HistogramView::HistogramView(QWidget* parent, int range) : QGraphicsView(parent),
-	m_scene(new QGraphicsScene()),
-	m_range(range) {
-
+HistogramView::HistogramView(QWidget* parent, int range)
+	: QGraphicsView(parent)
+	, m_scene(new QGraphicsScene())
+	, m_range(range) {
 	setTransform(QTransform());
-	QRectF pageRect( 0, 0, 1000, 100 );
+	QRectF pageRect(0, 0, 1000, 100);
 	m_scene->setSceneRect(pageRect);
 	setScene(m_scene);
 	setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -55,21 +60,21 @@ HistogramView::HistogramView(QWidget* parent, int range) : QGraphicsView(parent)
 void HistogramView::setScalePixmap(const QString& file) {
 	// scene rect is 1000*100 where upper 1000*80 is for histogram graph
 	// and lower 1000*20 is for histogram scale
-	auto* pixmap = new QGraphicsPixmapItem(QPixmap(file).scaled( 1000, 20, Qt::IgnoreAspectRatio), nullptr);
+	auto* pixmap = new QGraphicsPixmapItem(QPixmap(file).scaled(1000, 20, Qt::IgnoreAspectRatio), nullptr);
 	pixmap->setZValue(-1);
 	pixmap->setPos(0, 90);
 	m_scene->addItem(pixmap);
 }
 
 void HistogramView::setSpan(int l, int h) {
-	l = l*1000/m_range;
-	h = h*1000/m_range;
+	l = l * 1000 / m_range;
+	h = h * 1000 / m_range;
 	m_lowerSlider->setPos(QPointF(l - 1000, 0));
 	m_upperSlider->setPos(QPointF(h, 0));
 	invalidateScene(sceneRect(), QGraphicsScene::BackgroundLayer);
 }
 
-void HistogramView::resizeEvent(QResizeEvent *event) {
+void HistogramView::resizeEvent(QResizeEvent* event) {
 	fitInView(m_scene->sceneRect(), Qt::IgnoreAspectRatio);
 	QGraphicsView::resizeEvent(event);
 }
@@ -82,18 +87,18 @@ void HistogramView::drawBackground(QPainter* painter, const QRectF& rect) {
 	painter->setRenderHint(QPainter::Antialiasing, true);
 	int max = 1;
 	for (int i = 0; i <= m_range; i++)
-		if (bins [i] > max)
-			max = bins [i];
+		if (bins[i] > max)
+			max = bins[i];
 
 	// convert y-scale count to log scale so small counts are still visible
 	// scene rect is 1000*100 where upper 1000*80 is for histogram graph
 	// and lower 1000*20 is for histogram scale
-	QPainterPath path(QPointF(0, (log(bins[0])*100/log(max))));
+	QPainterPath path(QPointF(0, (log(bins[0]) * 100 / log(max))));
 	for (int i = 1; i <= m_range; i++) {
-		int x = i*1000/m_range;
+		int x = i * 1000 / m_range;
 		int y = 80;
-		if ( bins[i] > 1 )
-			y = 80 - (log(bins[i])*80/log(max));
+		if (bins[i] > 1)
+			y = 80 - (log(bins[i]) * 80 / log(max));
 
 		path.lineTo(QPointF(x, y));
 	}
@@ -103,7 +108,9 @@ void HistogramView::drawBackground(QPainter* painter, const QRectF& rect) {
 	painter->restore();
 }
 
-DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent), m_image(nullptr) {
+DatapickerImageWidget::DatapickerImageWidget(QWidget* parent)
+	: BaseDock(parent)
+	, m_image(nullptr) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
 	m_teComment = ui.teComment;
@@ -111,8 +118,12 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 
 	//"General"-tab
 	ui.leFileName->setClearButtonEnabled(true);
-	ui.bOpen->setIcon( QIcon::fromTheme("document-open") );
+	ui.bOpen->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	ui.leFileName->setCompleter(new QCompleter(new QFileSystemModel, this));
+#else
 	ui.leFileName->setCompleter(new QCompleter(new QDirModel, this));
+#endif
 
 	//"Symbol"-tab
 	symbolWidget = new SymbolWidget(ui.tSymbol);
@@ -122,7 +133,7 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 
 	//"Edit Image"-tab
 	auto* editTabLayout = static_cast<QGridLayout*>(ui.tEdit->layout());
-	editTabLayout->setContentsMargins(2,2,2,2);
+	editTabLayout->setContentsMargins(2, 2, 2, 2);
 	editTabLayout->setHorizontalSpacing(2);
 	editTabLayout->setVerticalSpacing(4);
 
@@ -133,12 +144,12 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 
 	ssSaturation = new SpanSlider(Qt::Horizontal, ui.tEdit);
 	ssSaturation->setToolTip(i18n("Select the range for the saturation.\nEverything outside of this range will be set to white."));
-	ssSaturation->setRange(0,100);
+	ssSaturation->setRange(0, 100);
 	editTabLayout->addWidget(ssSaturation, 5, 2);
 
 	ssValue = new SpanSlider(Qt::Horizontal, ui.tEdit);
 	ssValue->setToolTip(i18n("Select the range for the value, the degree of lightness of the color.\nEverything outside of this range will be set to white."));
-	ssValue->setRange(0,100);
+	ssValue->setRange(0, 100);
 	editTabLayout->addWidget(ssValue, 7, 2);
 
 	ssIntensity = new SpanSlider(Qt::Horizontal, ui.tEdit);
@@ -147,16 +158,21 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 	editTabLayout->addWidget(ssIntensity, 9, 2);
 
 	ssForeground = new SpanSlider(Qt::Horizontal, ui.tEdit);
-	ssForeground->setToolTip(i18n("Select the range for the colors that are not part of the background color.\nEverything outside of this range will be set to white."));
+	ssForeground->setToolTip(
+		i18n("Select the range for the colors that are not part of the background color.\nEverything outside of this range will be set to white."));
 	ssForeground->setRange(0, 100);
 	editTabLayout->addWidget(ssForeground, 11, 2);
 
-	ui.cbGraphType->addItem(i18n("Cartesian (x, y)"));
-	ui.cbGraphType->addItem(i18n("Polar (x, y°)"));
-	ui.cbGraphType->addItem(i18n("Polar (x, y(rad))"));
-	ui.cbGraphType->addItem(i18n("Logarithmic (ln(x), y)"));
-	ui.cbGraphType->addItem(i18n("Logarithmic (x, ln(y))"));
-	ui.cbGraphType->addItem(i18n("Ternary (x, y, z)"));
+	ui.cbGraphType->addItem(i18n("Cartesian (x, y)"), (int)DatapickerImage::GraphType::Linear);
+	ui.cbGraphType->addItem(i18n("Polar (x, y°)"), (int)DatapickerImage::GraphType::PolarInDegree);
+	ui.cbGraphType->addItem(i18n("Polar (x, y(rad))"), (int)DatapickerImage::GraphType::PolarInRadians);
+	ui.cbGraphType->addItem(i18n("Logarithmic (ln(x), ln(y))"), (int)DatapickerImage::GraphType::LnXY);
+	ui.cbGraphType->addItem(i18n("Logarithmic (ln(x), y)"), (int)DatapickerImage::GraphType::LnX);
+	ui.cbGraphType->addItem(i18n("Logarithmic (x, ln(y))"), (int)DatapickerImage::GraphType::LnY);
+	ui.cbGraphType->addItem(i18n("Logarithmic (log(x), log(y))"), (int)DatapickerImage::GraphType::Log10XY);
+	ui.cbGraphType->addItem(i18n("Logarithmic (log(x), y)"), (int)DatapickerImage::GraphType::Log10X);
+	ui.cbGraphType->addItem(i18n("Logarithmic (x, log(y))"), (int)DatapickerImage::GraphType::Log10Y);
+	ui.cbGraphType->addItem(i18n("Ternary (x, y, z)"), (int)DatapickerImage::GraphType::Ternary);
 
 	ui.lTernaryScale->setHidden(true);
 	ui.sbTernaryScale->setHidden(true);
@@ -171,9 +187,9 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 	ui.cbPlotImageType->addItem(i18n("Original Image"));
 	ui.cbPlotImageType->addItem(i18n("Processed Image"));
 
-	QString valueFile = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/colorchooser/colorchooser_value.xpm");
-	QString hueFile = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/colorchooser/colorchooser_hue.xpm");
-	QString saturationFile = QStandardPaths::locate(QStandardPaths::AppDataLocation, "pics/colorchooser/colorchooser_saturation.xpm");
+	QString valueFile = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("pics/colorchooser/colorchooser_value.xpm"));
+	QString hueFile = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("pics/colorchooser/colorchooser_hue.xpm"));
+	QString saturationFile = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("pics/colorchooser/colorchooser_saturation.xpm"));
 
 	gvHue = new HistogramView(ui.tEdit, ImageEditor::colorAttributeMax(DatapickerImage::ColorAttributes::Hue));
 	gvHue->setToolTip(i18n("Select the range for the hue.\nEverything outside of this range will be set to white."));
@@ -187,7 +203,7 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 
 	gvValue = new HistogramView(ui.tEdit, ImageEditor::colorAttributeMax(DatapickerImage::ColorAttributes::Value));
 	gvValue->setToolTip(i18n("Select the range for the value, the degree of lightness of the color.\nEverything outside of this range will be set to white."));
-	editTabLayout->addWidget(gvValue, 6,2);
+	editTabLayout->addWidget(gvValue, 6, 2);
 	gvValue->setScalePixmap(valueFile);
 
 	gvIntensity = new HistogramView(ui.tEdit, ImageEditor::colorAttributeMax(DatapickerImage::ColorAttributes::Intensity));
@@ -196,14 +212,15 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 	gvIntensity->setScalePixmap(valueFile);
 
 	gvForeground = new HistogramView(ui.tEdit, ImageEditor::colorAttributeMax(DatapickerImage::ColorAttributes::Foreground));
-	gvForeground->setToolTip(i18n("Select the range for the colors that are not part of the background color.\nEverything outside of this range will be set to white."));
+	gvForeground->setToolTip(
+		i18n("Select the range for the colors that are not part of the background color.\nEverything outside of this range will be set to white."));
 	editTabLayout->addWidget(gvForeground, 10, 2);
 	gvForeground->setScalePixmap(valueFile);
 
 	DatapickerImageWidget::updateLocale();
 
-	//SLOTS
-	//general
+	// SLOTS
+	// general
 	connect(ui.leName, &QLineEdit::textChanged, this, &DatapickerImageWidget::nameChanged);
 	connect(ui.teComment, &QTextEdit::textChanged, this, &DatapickerImageWidget::commentChanged);
 	connect(ui.bOpen, &QPushButton::clicked, this, &DatapickerImageWidget::selectFile);
@@ -211,57 +228,42 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent) : BaseDock(parent)
 	connect(ui.leFileName, &QLineEdit::textChanged, this, &DatapickerImageWidget::fileNameChanged);
 
 	// edit image
-	connect(ui.cbPlotImageType, QOverload<int>::of(&QComboBox::currentIndexChanged),
-			this, &DatapickerImageWidget::plotImageTypeChanged);
-	connect(ui.sbRotation, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::rotationChanged);
+	connect(ui.cbPlotImageType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &DatapickerImageWidget::plotImageTypeChanged);
+	connect(ui.sbRotation, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::rotationChanged);
 	connect(ssIntensity, &SpanSlider::spanChanged, this, &DatapickerImageWidget::intensitySpanChanged);
 	connect(ssIntensity, &SpanSlider::spanChanged, gvIntensity, &HistogramView::setSpan);
 	connect(ssForeground, &SpanSlider::spanChanged, this, &DatapickerImageWidget::foregroundSpanChanged);
-	connect(ssForeground, &SpanSlider::spanChanged, gvForeground, &HistogramView::setSpan );
+	connect(ssForeground, &SpanSlider::spanChanged, gvForeground, &HistogramView::setSpan);
 	connect(ssHue, &SpanSlider::spanChanged, this, &DatapickerImageWidget::hueSpanChanged);
-	connect(ssHue, &SpanSlider::spanChanged, gvHue, &HistogramView::setSpan );
+	connect(ssHue, &SpanSlider::spanChanged, gvHue, &HistogramView::setSpan);
 	connect(ssSaturation, &SpanSlider::spanChanged, this, &DatapickerImageWidget::saturationSpanChanged);
-	connect(ssSaturation, &SpanSlider::spanChanged, gvSaturation, &HistogramView::setSpan );
+	connect(ssSaturation, &SpanSlider::spanChanged, gvSaturation, &HistogramView::setSpan);
 	connect(ssValue, &SpanSlider::spanChanged, this, &DatapickerImageWidget::valueSpanChanged);
-	connect(ssValue, &SpanSlider::spanChanged, gvValue, &HistogramView::setSpan );
-	connect(ui.sbMinSegmentLength, QOverload<int>::of(&QSpinBox::valueChanged),
-			this, &DatapickerImageWidget::minSegmentLengthChanged);
-	connect(ui.sbPointSeparation, QOverload<int>::of(&QSpinBox::valueChanged),
-			this, &DatapickerImageWidget::pointSeparationChanged);
+	connect(ssValue, &SpanSlider::spanChanged, gvValue, &HistogramView::setSpan);
+	connect(ui.sbMinSegmentLength, QOverload<int>::of(&QSpinBox::valueChanged), this, &DatapickerImageWidget::minSegmentLengthChanged);
+	connect(ui.sbPointSeparation, QOverload<int>::of(&QSpinBox::valueChanged), this, &DatapickerImageWidget::pointSeparationChanged);
 
-	//axis point
-	connect(ui.cbGraphType, QOverload<int>::of(&QComboBox::currentIndexChanged),
-			this, &DatapickerImageWidget::graphTypeChanged);
-	connect(ui.sbTernaryScale, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::ternaryScaleChanged);
-	connect(ui.sbPositionX1, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionY1, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionX2, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionY2, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionX3, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionY3, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionZ1, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionZ2, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
-	connect(ui.sbPositionZ3, QOverload<double>::of(&QDoubleSpinBox::valueChanged),
-			this, &DatapickerImageWidget::logicalPositionChanged);
+	// axis point
+	connect(ui.cbGraphType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &DatapickerImageWidget::graphTypeChanged);
+	connect(ui.sbTernaryScale, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::ternaryScaleChanged);
+	connect(ui.sbPositionX1, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionY1, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionX2, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionY2, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionX3, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionY3, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionZ1, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionZ2, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.sbPositionZ3, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
 
 	connect(ui.chbSymbolVisible, &QCheckBox::clicked, this, &DatapickerImageWidget::pointsVisibilityChanged);
 }
 
 void DatapickerImageWidget::setImages(QList<DatapickerImage*> list) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	m_imagesList = list;
 	m_image = list.first();
-	m_aspect = list.first()->parentAspect();
+	setAspects(list);
 
 	if (list.size() == 1) {
 		ui.lName->setEnabled(true);
@@ -296,14 +298,14 @@ void DatapickerImageWidget::setImages(QList<DatapickerImage*> list) {
 	connect(m_image, &DatapickerImage::settingsChanged, this, &DatapickerImageWidget::imageEditorSettingsChanged);
 	connect(m_image, &DatapickerImage::minSegmentLengthChanged, this, &DatapickerImageWidget::imageMinSegmentLengthChanged);
 	connect(m_image, &DatapickerImage::pointVisibilityChanged, this, &DatapickerImageWidget::symbolVisibleChanged);
+	connect(m_image, QOverload<int>::of(&DatapickerImage::referencePointSelected), this, &DatapickerImageWidget::imageReferencePointSelected);
 
 	handleWidgetActions();
 	updateSymbolWidgets();
-	m_initializing = false;
 }
 
 void DatapickerImageWidget::handleWidgetActions() {
-	QString fileName =  ui.leFileName->text().trimmed();
+	QString fileName = ui.leFileName->text().trimmed();
 	bool b = !fileName.isEmpty();
 	ui.tEdit->setEnabled(b);
 	ui.cbGraphType->setEnabled(b);
@@ -318,7 +320,7 @@ void DatapickerImageWidget::handleWidgetActions() {
 	ui.sbPointSeparation->setEnabled(b);
 
 	if (b) {
-		//upload histogram to view
+		// upload histogram to view
 		gvIntensity->bins = m_image->intensityBins;
 		gvForeground->bins = m_image->foregroundBins;
 		gvHue->bins = m_image->hueBins;
@@ -328,7 +330,7 @@ void DatapickerImageWidget::handleWidgetActions() {
 }
 
 void DatapickerImageWidget::updateLocale() {
-	SET_NUMBER_LOCALE
+	const auto numberLocale = QLocale();
 	ui.sbRotation->setLocale(numberLocale);
 	ui.sbPositionX1->setLocale(numberLocale);
 	ui.sbPositionX2->setLocale(numberLocale);
@@ -351,8 +353,7 @@ void DatapickerImageWidget::selectFile() {
 }
 
 void DatapickerImageWidget::fileNameChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	handleWidgetActions();
 
@@ -364,9 +365,9 @@ void DatapickerImageWidget::fileNameChanged() {
 		image->setFileName(fileName);
 }
 
-void DatapickerImageWidget::graphTypeChanged() {
+void DatapickerImageWidget::graphTypeChanged(int index) {
 	auto points = m_image->axisPoints();
-	points.type = DatapickerImage::GraphType(ui.cbGraphType->currentIndex());
+	points.type = static_cast<DatapickerImage::GraphType>(ui.cbGraphType->itemData(index).toInt());
 
 	const bool ternary = (points.type == DatapickerImage::GraphType::Ternary);
 	ui.lTernaryScale->setVisible(ternary);
@@ -378,17 +379,19 @@ void DatapickerImageWidget::graphTypeChanged() {
 	ui.sbPositionZ2->setVisible(ternary);
 	ui.sbPositionZ3->setVisible(ternary);
 
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
-	if (ui.cbGraphType->currentIndex() == 3) { //"Logarithmic (ln(x), y)"
+	if (points.type == DatapickerImage::GraphType::LnXY || points.type == DatapickerImage::GraphType::LnX || points.type == DatapickerImage::GraphType::Log10XY
+		|| points.type == DatapickerImage::GraphType::Log10X) {
 		if (points.logicalPos[0].x() == 0.0f)
 			points.logicalPos[0].setX(0.01f);
 		if (points.logicalPos[1].x() == 0.0f)
 			points.logicalPos[1].setX(0.01f);
 		if (points.logicalPos[2].x() == 0.0f)
 			points.logicalPos[2].setX(0.01f);
-	} else if (ui.cbGraphType->currentIndex() == 4) { //"Logarithmic (x, ln(y))"
+	}
+	if (points.type == DatapickerImage::GraphType::LnXY || points.type == DatapickerImage::GraphType::LnY || points.type == DatapickerImage::GraphType::Log10XY
+		|| points.type == DatapickerImage::GraphType::Log10Y) {
 		if (points.logicalPos[0].y() == 0.0f)
 			points.logicalPos[0].setY(0.01f);
 		if (points.logicalPos[1].y() == 0.0f)
@@ -402,8 +405,7 @@ void DatapickerImageWidget::graphTypeChanged() {
 }
 
 void DatapickerImageWidget::ternaryScaleChanged(double value) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	DatapickerImage::ReferencePoints points = m_image->axisPoints();
 	points.ternaryScale = value;
@@ -413,8 +415,7 @@ void DatapickerImageWidget::ternaryScaleChanged(double value) {
 }
 
 void DatapickerImageWidget::logicalPositionChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	auto points = m_image->axisPoints();
 	points.logicalPos[0].setX(ui.sbPositionX1->value());
@@ -427,22 +428,19 @@ void DatapickerImageWidget::logicalPositionChanged() {
 	points.logicalPos[1].setZ(ui.sbPositionZ2->value());
 	points.logicalPos[2].setZ(ui.sbPositionZ3->value());
 
-	const Lock lock(m_initializing);
 	for (auto* image : m_imagesList)
 		image->setAxisPoints(points);
 }
 
 void DatapickerImageWidget::pointsVisibilityChanged(bool state) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* image : m_imagesList)
 		image->setPointVisibility(state);
 }
 
 void DatapickerImageWidget::intensitySpanChanged(int lowerLimit, int upperLimit) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	auto settings = m_image->settings();
 	settings.intensityThresholdHigh = upperLimit;
@@ -452,8 +450,7 @@ void DatapickerImageWidget::intensitySpanChanged(int lowerLimit, int upperLimit)
 }
 
 void DatapickerImageWidget::foregroundSpanChanged(int lowerLimit, int upperLimit) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	auto settings = m_image->settings();
 	settings.foregroundThresholdHigh = upperLimit;
@@ -463,8 +460,7 @@ void DatapickerImageWidget::foregroundSpanChanged(int lowerLimit, int upperLimit
 }
 
 void DatapickerImageWidget::hueSpanChanged(int lowerLimit, int upperLimit) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	auto settings = m_image->settings();
 	settings.hueThresholdHigh = upperLimit;
@@ -474,8 +470,7 @@ void DatapickerImageWidget::hueSpanChanged(int lowerLimit, int upperLimit) {
 }
 
 void DatapickerImageWidget::saturationSpanChanged(int lowerLimit, int upperLimit) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	auto settings = m_image->settings();
 	settings.saturationThresholdHigh = upperLimit;
@@ -485,8 +480,7 @@ void DatapickerImageWidget::saturationSpanChanged(int lowerLimit, int upperLimit
 }
 
 void DatapickerImageWidget::valueSpanChanged(int lowerLimit, int upperLimit) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	auto settings = m_image->settings();
 	settings.valueThresholdHigh = upperLimit;
@@ -496,32 +490,28 @@ void DatapickerImageWidget::valueSpanChanged(int lowerLimit, int upperLimit) {
 }
 
 void DatapickerImageWidget::plotImageTypeChanged(int index) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* image : m_imagesList)
 		image->setPlotImageType(DatapickerImage::PlotImageType(index));
 }
 
 void DatapickerImageWidget::rotationChanged(double value) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_RETURN_NO_LOCK;
 
 	for (auto* image : m_imagesList)
 		image->setRotationAngle(value);
 }
 
 void DatapickerImageWidget::minSegmentLengthChanged(int value) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* image : m_imagesList)
 		image->setminSegmentLength(value);
 }
 
 void DatapickerImageWidget::pointSeparationChanged(int value) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* image : m_imagesList)
 		image->setPointSeparation(value);
@@ -531,22 +521,19 @@ void DatapickerImageWidget::pointSeparationChanged(int value) {
 //******** SLOTs for changes triggered in DatapickerImage ***********
 //*******************************************************************
 void DatapickerImageWidget::imageFileNameChanged(const QString& name) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	ui.leFileName->setText(name);
-	m_initializing = false;
 }
 
 void DatapickerImageWidget::imageRotationAngleChanged(float angle) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	ui.sbRotation->setValue(angle);
-	m_initializing = false;
 }
 
 void DatapickerImageWidget::imageAxisPointsChanged(const DatapickerImage::ReferencePoints& axisPoints) {
-	if (m_initializing)return;
-	const Lock lock(m_initializing);
-	m_initializing = true;
-	ui.cbGraphType->setCurrentIndex((int) axisPoints.type);
+	CONDITIONAL_LOCK_RETURN;
+	int index = ui.cbGraphType->findData((int)axisPoints.type);
+	ui.cbGraphType->setCurrentIndex(index);
 	ui.sbTernaryScale->setValue(axisPoints.ternaryScale);
 	ui.sbPositionX1->setValue(axisPoints.logicalPos[0].x());
 	ui.sbPositionY1->setValue(axisPoints.logicalPos[0].y());
@@ -557,11 +544,10 @@ void DatapickerImageWidget::imageAxisPointsChanged(const DatapickerImage::Refere
 	ui.sbPositionZ1->setValue(axisPoints.logicalPos[0].z());
 	ui.sbPositionZ2->setValue(axisPoints.logicalPos[1].z());
 	ui.sbPositionZ3->setValue(axisPoints.logicalPos[2].z());
-	m_initializing = false;
 }
 
 void DatapickerImageWidget::imageEditorSettingsChanged(const DatapickerImage::EditorSettings& settings) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	ssIntensity->setSpan(settings.intensityThresholdLow, settings.intensityThresholdHigh);
 	ssForeground->setSpan(settings.foregroundThresholdLow, settings.foregroundThresholdHigh);
 	ssHue->setSpan(settings.hueThresholdLow, settings.hueThresholdHigh);
@@ -572,13 +558,11 @@ void DatapickerImageWidget::imageEditorSettingsChanged(const DatapickerImage::Ed
 	gvHue->setSpan(settings.hueThresholdLow, settings.hueThresholdHigh);
 	gvSaturation->setSpan(settings.saturationThresholdLow, settings.saturationThresholdHigh);
 	gvValue->setSpan(settings.valueThresholdLow, settings.valueThresholdHigh);
-	m_initializing = false;
 }
 
 void DatapickerImageWidget::imageMinSegmentLengthChanged(const int value) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	ui.sbMinSegmentLength->setValue(value);
-	m_initializing = false;
 }
 
 void DatapickerImageWidget::updateSymbolWidgets() {
@@ -590,9 +574,14 @@ void DatapickerImageWidget::updateSymbolWidgets() {
 }
 
 void DatapickerImageWidget::symbolVisibleChanged(bool on) {
-	m_initializing = true;
+	CONDITIONAL_LOCK_RETURN;
 	ui.chbSymbolVisible->setChecked(on);
-	m_initializing = false;
+}
+
+void DatapickerImageWidget::imageReferencePointSelected(int index) {
+	ui.rbRefPoint1->setChecked(index == 0);
+	ui.rbRefPoint2->setChecked(index == 1);
+	ui.rbRefPoint3->setChecked(index == 2);
 }
 
 //**********************************************************
@@ -602,15 +591,17 @@ void DatapickerImageWidget::load() {
 	if (!m_image)
 		return;
 
-	m_initializing = true;
-	ui.leFileName->setText( m_image->fileName() );
+	// No lock, because it is done already in the caller function
+	ui.leFileName->setText(m_image->fileName());
 
-	//highlight the text field for the background image red if an image is used and cannot be found
+	// highlight the text field for the background image red if an image is used and cannot be found
 	const QString& fileName = m_image->fileName();
 	bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
 	GuiTools::highlight(ui.leFileName, invalid);
 
-	ui.cbGraphType->setCurrentIndex((int) m_image->axisPoints().type);
+	imageReferencePointSelected(m_image->currentSelectedReferencePoint());
+
+	ui.cbGraphType->setCurrentIndex((int)m_image->axisPoints().type);
 	ui.sbTernaryScale->setValue(m_image->axisPoints().ternaryScale);
 	ui.sbPositionX1->setValue(m_image->axisPoints().logicalPos[0].x());
 	ui.sbPositionY1->setValue(m_image->axisPoints().logicalPos[0].y());
@@ -621,7 +612,7 @@ void DatapickerImageWidget::load() {
 	ui.sbPositionZ1->setValue(m_image->axisPoints().logicalPos[0].z());
 	ui.sbPositionZ2->setValue(m_image->axisPoints().logicalPos[1].z());
 	ui.sbPositionZ3->setValue(m_image->axisPoints().logicalPos[2].z());
-	ui.cbPlotImageType->setCurrentIndex((int) m_image->plotImageType());
+	ui.cbPlotImageType->setCurrentIndex((int)m_image->plotImageType());
 	ssIntensity->setSpan(m_image->settings().intensityThresholdLow, m_image->settings().intensityThresholdHigh);
 	ssForeground->setSpan(m_image->settings().foregroundThresholdLow, m_image->settings().foregroundThresholdHigh);
 	ssHue->setSpan(m_image->settings().hueThresholdLow, m_image->settings().hueThresholdHigh);
@@ -634,6 +625,5 @@ void DatapickerImageWidget::load() {
 	gvValue->setSpan(m_image->settings().valueThresholdLow, m_image->settings().valueThresholdHigh);
 	ui.sbPointSeparation->setValue(m_image->pointSeparation());
 	ui.sbMinSegmentLength->setValue(m_image->minSegmentLength());
-	ui.chbSymbolVisible->setChecked( m_image->pointVisibility() );
-	m_initializing = false;
+	ui.chbSymbolVisible->setChecked(m_image->pointVisibility());
 }
