@@ -1,11 +1,11 @@
 /*
-    File                 : CorrelationTest.cpp
-    Project              : LabPlot
-    Description          : Tests for data correlation
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : CorrelationTest.cpp
+	Project              : LabPlot
+	Description          : Tests for data correlation
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "CorrelationTest.h"
@@ -16,34 +16,34 @@
 
 void CorrelationTest::testLinear() {
 	// data
-	QVector<int> xData = {1,2,3,4};
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<int> xData = {1, 2, 3, 4};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setXDataColumn(&xDataColumn);
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -70,33 +70,33 @@ void CorrelationTest::testLinear() {
 void CorrelationTest::testLinear2() {
 	// data
 	QVector<int> xData = {1, 2, 3};
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setXDataColumn(&xDataColumn);
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -119,29 +119,29 @@ void CorrelationTest::testLinear2() {
 
 void CorrelationTest::testLinear_noX() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -152,7 +152,7 @@ void CorrelationTest::testLinear_noX() {
 	QCOMPARE(np, 7);
 
 	for (int i = 0; i < np; i++)
-		QCOMPARE(resultXDataColumn->valueAt(i), (double)(i-np/2));
+		QCOMPARE(resultXDataColumn->valueAt(i), (double)(i - np / 2));
 
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(0));
 	FuzzyCompare(resultYDataColumn->valueAt(0), 0., 1.e-15);
@@ -167,34 +167,34 @@ void CorrelationTest::testLinear_noX() {
 
 void CorrelationTest::testLinear_swapped() {
 	// data
-	QVector<int> xData = {1,2,3,4};
-	QVector<double> yData = {0,1.,.5};
-	QVector<double> y2Data = {1.,2.,3.,4.};
+	QVector<int> xData = {1, 2, 3, 4};
+	QVector<double> yData = {0, 1., .5};
+	QVector<double> y2Data = {1., 2., 3., 4.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setXDataColumn(&xDataColumn);
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -222,35 +222,35 @@ void CorrelationTest::testLinear_swapped() {
 
 void CorrelationTest::testCircular() {
 	// data
-	QVector<int> xData = {1,2,3,4};
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<int> xData = {1, 2, 3, 4};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setXDataColumn(&xDataColumn);
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.type = nsl_corr_type_circular;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -275,35 +275,35 @@ void CorrelationTest::testCircular() {
 
 void CorrelationTest::testCircular2() {
 	// data
-	QVector<int> xData = {1,2,3};
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<int> xData = {1, 2, 3};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setXDataColumn(&xDataColumn);
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.type = nsl_corr_type_circular;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -328,30 +328,30 @@ void CorrelationTest::testCircular2() {
 
 void CorrelationTest::testLinear_biased() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.normalize = nsl_corr_norm_biased;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -370,7 +370,7 @@ void CorrelationTest::testLinear_biased() {
 	FuzzyCompare(resultYDataColumn->valueAt(0), 0., 1.e-15);
 	QCOMPARE(resultYDataColumn->valueAt(1), 0.125);
 	QCOMPARE(resultYDataColumn->valueAt(2), .5);
-	QCOMPARE(resultYDataColumn->valueAt(3), 3.5/4.);
+	QCOMPARE(resultYDataColumn->valueAt(3), 3.5 / 4.);
 	QCOMPARE(resultYDataColumn->valueAt(4), 1.25);
 	QCOMPARE(resultYDataColumn->valueAt(5), 1.);
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(6));
@@ -379,30 +379,30 @@ void CorrelationTest::testLinear_biased() {
 
 void CorrelationTest::testLinear2_biased() {
 	// data
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.normalize = nsl_corr_norm_biased;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -417,39 +417,39 @@ void CorrelationTest::testLinear2_biased() {
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(2));
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(3));
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(4));
-	QCOMPARE(resultYDataColumn->valueAt(0), 1./6.);
-	QCOMPARE(resultYDataColumn->valueAt(1), 2./3.);
-	QCOMPARE(resultYDataColumn->valueAt(2), 7./6.);
+	QCOMPARE(resultYDataColumn->valueAt(0), 1. / 6.);
+	QCOMPARE(resultYDataColumn->valueAt(1), 2. / 3.);
+	QCOMPARE(resultYDataColumn->valueAt(2), 7. / 6.);
 	QCOMPARE(resultYDataColumn->valueAt(3), 1.);
 	FuzzyCompare(resultYDataColumn->valueAt(4), 0., 1.e-15);
 }
 
 void CorrelationTest::testLinear_unbiased() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.normalize = nsl_corr_norm_unbiased;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -468,39 +468,39 @@ void CorrelationTest::testLinear_unbiased() {
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(6));
 	FuzzyCompare(resultYDataColumn->valueAt(0), 0., 1.e-15);
 	QCOMPARE(resultYDataColumn->valueAt(1), 0.25);
-	QCOMPARE(resultYDataColumn->valueAt(2), 2./3.);
-	QCOMPARE(resultYDataColumn->valueAt(3), 3.5/4.);
-	QCOMPARE(resultYDataColumn->valueAt(4), 5./3.);
+	QCOMPARE(resultYDataColumn->valueAt(2), 2. / 3.);
+	QCOMPARE(resultYDataColumn->valueAt(3), 3.5 / 4.);
+	QCOMPARE(resultYDataColumn->valueAt(4), 5. / 3.);
 	QCOMPARE(resultYDataColumn->valueAt(5), 2.);
 	FuzzyCompare(resultYDataColumn->valueAt(6), 0., 2.e-15);
 }
 
 void CorrelationTest::testLinear2_unbiased() {
 	// data
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.normalize = nsl_corr_norm_unbiased;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -517,37 +517,37 @@ void CorrelationTest::testLinear2_unbiased() {
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(4));
 	QCOMPARE(resultYDataColumn->valueAt(0), 0.5);
 	QCOMPARE(resultYDataColumn->valueAt(1), 1.);
-	QCOMPARE(resultYDataColumn->valueAt(2), 7./6.);
+	QCOMPARE(resultYDataColumn->valueAt(2), 7. / 6.);
 	QCOMPARE(resultYDataColumn->valueAt(3), 1.5);
 	FuzzyCompare(resultYDataColumn->valueAt(4), 0., 1.e-15);
 }
 
 void CorrelationTest::testLinear_coeff() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.normalize = nsl_corr_norm_coeff;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -566,40 +566,40 @@ void CorrelationTest::testLinear_coeff() {
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(6));
 	FuzzyCompare(resultYDataColumn->valueAt(0), 0., 1.e-15);
 	double norm = sqrt(30) * sqrt(1.25);
-	QCOMPARE(resultYDataColumn->valueAt(1), 0.5/norm);
-	QCOMPARE(resultYDataColumn->valueAt(2), 2./norm);
-	QCOMPARE(resultYDataColumn->valueAt(3), 3.5/norm);
-	QCOMPARE(resultYDataColumn->valueAt(4), 5./norm);
-	QCOMPARE(resultYDataColumn->valueAt(5), 4./norm);
+	QCOMPARE(resultYDataColumn->valueAt(1), 0.5 / norm);
+	QCOMPARE(resultYDataColumn->valueAt(2), 2. / norm);
+	QCOMPARE(resultYDataColumn->valueAt(3), 3.5 / norm);
+	QCOMPARE(resultYDataColumn->valueAt(4), 5. / norm);
+	QCOMPARE(resultYDataColumn->valueAt(5), 4. / norm);
 	FuzzyCompare(resultYDataColumn->valueAt(6), 0., 2.e-15);
 }
 
 void CorrelationTest::testLinear2_coeff() {
 	// data
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.normalize = nsl_corr_norm_coeff;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -614,41 +614,41 @@ void CorrelationTest::testLinear2_coeff() {
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(2));
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(3));
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(4));
-	double norm = sqrt(14.)*sqrt(1.25);
-	QCOMPARE(resultYDataColumn->valueAt(0), .5/norm);
-	QCOMPARE(resultYDataColumn->valueAt(1), 2./norm);
-	QCOMPARE(resultYDataColumn->valueAt(2), 3.5/norm);
-	QCOMPARE(resultYDataColumn->valueAt(3), 3./norm);
+	double norm = sqrt(14.) * sqrt(1.25);
+	QCOMPARE(resultYDataColumn->valueAt(0), .5 / norm);
+	QCOMPARE(resultYDataColumn->valueAt(1), 2. / norm);
+	QCOMPARE(resultYDataColumn->valueAt(2), 3.5 / norm);
+	QCOMPARE(resultYDataColumn->valueAt(3), 3. / norm);
 	FuzzyCompare(resultYDataColumn->valueAt(4), 0., 1.e-15);
 }
 
 void CorrelationTest::testCircular_coeff() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.type = nsl_corr_type_circular;
 	correlationData.normalize = nsl_corr_norm_coeff;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -673,31 +673,31 @@ void CorrelationTest::testCircular_coeff() {
 
 void CorrelationTest::testCircular2_coeff() {
 	// data
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.type = nsl_corr_type_circular;
 	correlationData.normalize = nsl_corr_norm_coeff;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -722,30 +722,30 @@ void CorrelationTest::testCircular2_coeff() {
 
 void CorrelationTest::testLinear_samplingInterval() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.samplingInterval = 0.1;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -757,7 +757,7 @@ void CorrelationTest::testLinear_samplingInterval() {
 
 	for (int i = 0; i < np; i++) {
 		DEBUG(std::setprecision(15) << resultXDataColumn->valueAt(i));
-		QCOMPARE(resultXDataColumn->valueAt(i), (double) (i-np/2) * correlationData.samplingInterval);
+		QCOMPARE(resultXDataColumn->valueAt(i), (double)(i - np / 2) * correlationData.samplingInterval);
 	}
 
 	DEBUG(std::setprecision(15) << resultYDataColumn->valueAt(0));
@@ -773,30 +773,30 @@ void CorrelationTest::testLinear_samplingInterval() {
 
 void CorrelationTest::testLinear2_samplingInterval() {
 	// data
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.samplingInterval = 0.1;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -808,7 +808,7 @@ void CorrelationTest::testLinear2_samplingInterval() {
 
 	for (int i = 0; i < np; i++) {
 		DEBUG(std::setprecision(15) << resultXDataColumn->valueAt(i));
-		QCOMPARE(resultXDataColumn->valueAt(i), (double) (i-np/2) * correlationData.samplingInterval);
+		QCOMPARE(resultXDataColumn->valueAt(i), (double)(i - np / 2) * correlationData.samplingInterval);
 	}
 
 	QCOMPARE(resultYDataColumn->valueAt(0), 0.5);
@@ -821,31 +821,31 @@ void CorrelationTest::testLinear2_samplingInterval() {
 
 void CorrelationTest::testCircular_samplingInterval() {
 	// data
-	QVector<double> yData = {1.,2.,3.,4.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3., 4.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.type = nsl_corr_type_circular;
 	correlationData.samplingInterval = 0.1;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -857,7 +857,7 @@ void CorrelationTest::testCircular_samplingInterval() {
 
 	for (int i = 0; i < np; i++) {
 		DEBUG(std::setprecision(15) << resultXDataColumn->valueAt(i));
-		QCOMPARE(resultXDataColumn->valueAt(i), (double) i * correlationData.samplingInterval);
+		QCOMPARE(resultXDataColumn->valueAt(i), (double)i * correlationData.samplingInterval);
 	}
 
 	QCOMPARE(resultYDataColumn->valueAt(0), 2.);
@@ -868,31 +868,31 @@ void CorrelationTest::testCircular_samplingInterval() {
 
 void CorrelationTest::testCircular2_samplingInterval() {
 	// data
-	QVector<double> yData = {1.,2.,3.};
-	QVector<double> y2Data = {0,1.,.5};
+	QVector<double> yData = {1., 2., 3.};
+	QVector<double> y2Data = {0, 1., .5};
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare the correlation
+	// prepare the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	correlationData.type = nsl_corr_type_circular;
 	correlationData.samplingInterval = 0.1;
 	correlationCurve.setCorrelationData(correlationData);
 
-	//perform the correlation
+	// perform the correlation
 	correlationCurve.recalculate();
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(correlationResult.available, true);
 	QCOMPARE(correlationResult.valid, true);
 
@@ -904,7 +904,7 @@ void CorrelationTest::testCircular2_samplingInterval() {
 
 	for (int i = 0; i < np; i++) {
 		DEBUG(std::setprecision(15) << resultXDataColumn->valueAt(i));
-		QCOMPARE(resultXDataColumn->valueAt(i), (double) i * correlationData.samplingInterval);
+		QCOMPARE(resultXDataColumn->valueAt(i), (double)i * correlationData.samplingInterval);
 	}
 
 	QCOMPARE(resultYDataColumn->valueAt(0), 2.);
@@ -917,33 +917,33 @@ void CorrelationTest::testPerformance() {
 	QVector<double> yData, y2Data;
 #ifdef HAVE_FFTW3
 	const int N = 1e6;
-#else	// GSL is much slower
+#else // GSL is much slower
 	const int N = 5e4;
 #endif
-	for (int i = 0;  i < N; i++) {
+	for (int i = 0; i < N; i++) {
 		yData.append(i % 100);
 		y2Data.append(i % 10);
 	}
 
-	//data source columns
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	Column y2DataColumn("y2", AbstractColumn::ColumnMode::Double);
+	Column y2DataColumn(QStringLiteral("y2"), AbstractColumn::ColumnMode::Double);
 	y2DataColumn.replaceValues(0, y2Data);
 
-	XYCorrelationCurve correlationCurve("correlation");
+	XYCorrelationCurve correlationCurve(QStringLiteral("correlation"));
 	correlationCurve.setYDataColumn(&yDataColumn);
 	correlationCurve.setY2DataColumn(&y2DataColumn);
 
-	//prepare and perform the correlation
+	// prepare and perform the correlation
 	XYCorrelationCurve::CorrelationData correlationData = correlationCurve.correlationData();
 	QBENCHMARK {
 		// triggers recalculate()
 		correlationCurve.setCorrelationData(correlationData);
 	}
 
-	//check the results
+	// check the results
 	const XYCorrelationCurve::CorrelationResult& correlationResult = correlationCurve.correlationResult();
 
 	QCOMPARE(correlationResult.available, true);
@@ -952,7 +952,7 @@ void CorrelationTest::testPerformance() {
 	const AbstractColumn* resultXDataColumn = correlationCurve.xColumn();
 
 	const int np = resultXDataColumn->rowCount();
-	QCOMPARE(np, 2*N - 1);
+	QCOMPARE(np, 2 * N - 1);
 }
 
 QTEST_MAIN(CorrelationTest)
