@@ -1,12 +1,12 @@
 /*
-    File                 : AsciiFilterTest.h
-    Project              : LabPlot
-    Description          : Tests for the ascii filter
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : AsciiFilterTest.h
+	Project              : LabPlot
+	Description          : Tests for the ascii filter
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef ASCIIFILTERTEST_H
 #define ASCIIFILTERTEST_H
@@ -18,7 +18,7 @@ class AsciiFilterTest : public CommonTest {
 	Q_OBJECT
 
 private Q_SLOTS:
-	//empty and sparse files
+	// empty and sparse files
 	void testEmptyFileAppend();
 	void testEmptyFilePrepend();
 	void testEmptyFileReplace();
@@ -29,7 +29,7 @@ private Q_SLOTS:
 	void testSparseFile02();
 	void testSparseFile03();
 
-	//header handling
+	// header handling
 	void testHeader01();
 	void testHeader02();
 	void testHeader03();
@@ -39,8 +39,12 @@ private Q_SLOTS:
 	void testHeader07();
 	void testHeader07a();
 	void testHeader08();
+	void testHeader09();
+	void testHeader10();
+	void testHeader11();
+	void testHeader11a();
 
-	//read ranges
+	// read ranges
 	void testColumnRange00();
 	void testColumnRange01();
 	void testColumnRange02();
@@ -55,25 +59,43 @@ private Q_SLOTS:
 
 	void testRowColumnRange00();
 
-	//different separators
+	// different separators
 
-	//qouted strings
+	// qouted strings
 	void testQuotedStrings00();
 	void testQuotedStrings01();
 	void testQuotedStrings02();
 	void testQuotedStrings03();
+	void testQuotedStrings04();
+	void testQuotedStrings05();
 
-	//different locales
+	// different locales
 
-	//handling of NANs
+	// handling of NANs
 
-	//automatically skip comments
+	// automatically skip comments
 	void testComments00();
 	void testComments01();
 	void testComments02();
 
-	//datetime data
+	// datetime data
 	void testDateTime00();
 	void testDateTimeHex();
+
+	// matrix import
+	void testMatrixHeader();
+
+	// benchmarks
+
+	void benchDoubleImport_data();
+	// this is called multiple times (warm-up of BENCHMARK)
+	// see https://stackoverflow.com/questions/36916962/qtest-executes-test-case-twic
+	void benchDoubleImport();
+	void benchDoubleImport_cleanup(); // delete data
+
+private:
+	QString benchDataFileName;
+	const size_t lines = 1e6;
+	static const int paths = 5;
 };
 #endif
