@@ -1,12 +1,12 @@
 /*
-    File                 : MultiRangeTest.h
-    Project              : LabPlot
-    Description          : Tests for project imports
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : MultiRangeTest.h
+	Project              : LabPlot
+	Description          : Tests for project imports
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef MULTIRANGETEST_H
 #define MULTIRANGETEST_H
@@ -49,5 +49,14 @@ private Q_SLOTS:
 
 	void autoScaleYAfterZoomInX();
 	void autoScaleXAfterZoomInY();
+
+	void baseDockSetAspects_NoPlotRangeChange();
+
+	void mouseWheelXAxisApplyToAllX();
+	void mouseWheelTanCurveApplyToAllX();
+	void mouseWheelXAxisApplyToSelected();
+
+	void axisMouseMoveApplyToAllX();
+	void axisMouseMoveApplyToSelection();
 };
 #endif
